@@ -8,9 +8,9 @@ set -o errexit
 # A Dance of Fire and Ice
 ###
 
-script_version=20240530.1
+script_version=20241021.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='a-dance-of-fire-and-ice'
 GAME_NAME='A Dance of Fire and Ice'
@@ -21,12 +21,10 @@ ARCHIVE_BASE_1_SIZE='2069741'
 ARCHIVE_BASE_1_VERSION='2.6.3-itch.2023.12.16'
 ARCHIVE_BASE_1_URL='https://fizzd.itch.io/a-dance-of-fire-and-ice'
 
-## ./play.it 2.29 does not have support for multiple archives sharing a same name.
-## cf. https://forge.dotslashplay.it/play.it/scripts/-/issues/355
-#ARCHIVE_BASE_0_NAME='a-dance-of-fire-and-ice-linux.zip'
-#ARCHIVE_BASE_0_MD5='caf90b5416730395963e26aeb76c1155'
-#ARCHIVE_BASE_0_SIZE='965475'
-#ARCHIVE_BASE_0_VERSION='2.5.0-itch.2023.06.20'
+ARCHIVE_BASE_0_NAME='a-dance-of-fire-and-ice-linux.zip'
+ARCHIVE_BASE_0_MD5='caf90b5416730395963e26aeb76c1155'
+ARCHIVE_BASE_0_SIZE='965475'
+ARCHIVE_BASE_0_VERSION='2.5.0-itch.2023.06.20'
 
 UNITY3D_NAME='ADanceOfFireAndIce'
 ## The game will crash on launch if libsteam_api.so is not available.
@@ -41,11 +39,9 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -56,6 +52,9 @@ libpulse.so.0
 librt.so.1
 libz.so.1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -79,8 +78,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -101,6 +105,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
