@@ -8,9 +8,9 @@ set -o errexit
 # Age of Mythology
 ###
 
-script_version=20240503.1
+script_version=20241124.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='age-of-mythology'
 GAME_NAME='Age of Mythology'
@@ -42,6 +42,7 @@ georgiab.ttf
 georgiai.ttf
 georgia.ttf
 georgiaz.ttf'
+## TODO: An explicit list of files should be set
 CONTENT_GAME_DATA_FILES='
 *'
 CONTENT_DOC_DATA_PATH='.'
@@ -68,14 +69,14 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN_DEPS_DEMO="$PKG_DATA_ID_DEMO"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -99,8 +100,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -915,6 +921,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
