@@ -7,13 +7,84 @@ set -o errexit
 # Baldur's Gate 3
 ###
 
-script_version=20240703.1
+script_version=20250104.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='baldurs-gate-3'
 GAME_NAME='Baldurʼs Gate Ⅲ'
 
+ARCHIVE_BASE_PATCH7_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035).exe'
+ARCHIVE_BASE_PATCH7_0_MD5='4731f40c3ba5a04baa46f83954a11dc8'
+ARCHIVE_BASE_PATCH7_0_TYPE='innosetup'
+ARCHIVE_BASE_PATCH7_0_PART1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-1.bin'
+ARCHIVE_BASE_PATCH7_0_PART1_MD5='71c4af7da8ef005e18d387565dd21b16'
+ARCHIVE_BASE_PATCH7_0_PART2_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-2.bin'
+ARCHIVE_BASE_PATCH7_0_PART2_MD5='b1ed5b656dd0fa53a60abca188966470'
+ARCHIVE_BASE_PATCH7_0_PART3_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-3.bin'
+ARCHIVE_BASE_PATCH7_0_PART3_MD5='d7dad117c9e7af9e3b86e660ab5bb7b5'
+ARCHIVE_BASE_PATCH7_0_PART4_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-4.bin'
+ARCHIVE_BASE_PATCH7_0_PART4_MD5='ae61e0a0c6124f61d343745d0fe10d57'
+ARCHIVE_BASE_PATCH7_0_PART5_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-5.bin'
+ARCHIVE_BASE_PATCH7_0_PART5_MD5='816405148684c3669784239e2cd26b02'
+ARCHIVE_BASE_PATCH7_0_PART6_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-6.bin'
+ARCHIVE_BASE_PATCH7_0_PART6_MD5='5391fcf18b77fadaf13e685e9a142b22'
+ARCHIVE_BASE_PATCH7_0_PART7_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-7.bin'
+ARCHIVE_BASE_PATCH7_0_PART7_MD5='e307ae4805537a15dcb9859be3556f4d'
+ARCHIVE_BASE_PATCH7_0_PART8_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-8.bin'
+ARCHIVE_BASE_PATCH7_0_PART8_MD5='fd5efa18847fa4c941e4b42219ad03dc'
+ARCHIVE_BASE_PATCH7_0_PART9_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-9.bin'
+ARCHIVE_BASE_PATCH7_0_PART9_MD5='0622bdb104ca1512d4a0078ad991d1ea'
+ARCHIVE_BASE_PATCH7_0_PART10_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-10.bin'
+ARCHIVE_BASE_PATCH7_0_PART10_MD5='e3f4fe11ecde3b0be12791db9eb41f67'
+ARCHIVE_BASE_PATCH7_0_PART11_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-11.bin'
+ARCHIVE_BASE_PATCH7_0_PART11_MD5='65629494b10a2e44d4b32febaedd67e1'
+ARCHIVE_BASE_PATCH7_0_PART12_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-12.bin'
+ARCHIVE_BASE_PATCH7_0_PART12_MD5='0d39d5fb7094ed2507525056edc96658'
+ARCHIVE_BASE_PATCH7_0_PART13_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-13.bin'
+ARCHIVE_BASE_PATCH7_0_PART13_MD5='e88517daedf8393b25441534603ceac1'
+ARCHIVE_BASE_PATCH7_0_PART14_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-14.bin'
+ARCHIVE_BASE_PATCH7_0_PART14_MD5='63c4c9a9b8fa4a28cf47a828e6791fc6'
+ARCHIVE_BASE_PATCH7_0_PART15_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-15.bin'
+ARCHIVE_BASE_PATCH7_0_PART15_MD5='198ee0e4bc27d4e69ec979c177f39e9f'
+ARCHIVE_BASE_PATCH7_0_PART16_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-16.bin'
+ARCHIVE_BASE_PATCH7_0_PART16_MD5='89fc96eff7849886532f52689177a7a3'
+ARCHIVE_BASE_PATCH7_0_PART17_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-17.bin'
+ARCHIVE_BASE_PATCH7_0_PART17_MD5='c44b6b7b2a65b08558d5e7a0dbd15b53'
+ARCHIVE_BASE_PATCH7_0_PART18_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-18.bin'
+ARCHIVE_BASE_PATCH7_0_PART18_MD5='3257064cdb862e995db3bcb637602efd'
+ARCHIVE_BASE_PATCH7_0_PART19_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-19.bin'
+ARCHIVE_BASE_PATCH7_0_PART19_MD5='277c3b78d305362642e2610f96b18773'
+ARCHIVE_BASE_PATCH7_0_PART20_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-20.bin'
+ARCHIVE_BASE_PATCH7_0_PART20_MD5='a474dc343c2984f22ad1cd67741583ab'
+ARCHIVE_BASE_PATCH7_0_PART21_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-21.bin'
+ARCHIVE_BASE_PATCH7_0_PART21_MD5='36b777303e40ce40afd533572dc5b669'
+ARCHIVE_BASE_PATCH7_0_PART22_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-22.bin'
+ARCHIVE_BASE_PATCH7_0_PART22_MD5='a3424984840c0d342c420861cafb610e'
+ARCHIVE_BASE_PATCH7_0_PART23_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-23.bin'
+ARCHIVE_BASE_PATCH7_0_PART23_MD5='37ee123135f0a0d5664c3ad123a14323'
+ARCHIVE_BASE_PATCH7_0_PART24_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-24.bin'
+ARCHIVE_BASE_PATCH7_0_PART24_MD5='a293911fe03fc6510d2ded8d1926e88e'
+ARCHIVE_BASE_PATCH7_0_PART25_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-25.bin'
+ARCHIVE_BASE_PATCH7_0_PART25_MD5='a5ed151d731fffc6721774ceddfe9dc6'
+ARCHIVE_BASE_PATCH7_0_PART26_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-26.bin'
+ARCHIVE_BASE_PATCH7_0_PART26_MD5='7a2b2564e8ca4289729e29f1dd7eb330'
+ARCHIVE_BASE_PATCH7_0_PART27_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-27.bin'
+ARCHIVE_BASE_PATCH7_0_PART27_MD5='6e7e8555e2c041ec6c76702dc82651eb'
+ARCHIVE_BASE_PATCH7_0_PART28_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-28.bin'
+ARCHIVE_BASE_PATCH7_0_PART28_MD5='4c0f2b5bbbfa525769977b316348b4de'
+ARCHIVE_BASE_PATCH7_0_PART29_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-29.bin'
+ARCHIVE_BASE_PATCH7_0_PART29_MD5='45bce06db81d8452f97833ecf69d1385'
+ARCHIVE_BASE_PATCH7_0_PART30_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-30.bin'
+ARCHIVE_BASE_PATCH7_0_PART30_MD5='5c499c0e5ae46ad2ccf56d231aa73743'
+ARCHIVE_BASE_PATCH7_0_PART31_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-31.bin'
+ARCHIVE_BASE_PATCH7_0_PART31_MD5='ede42db8ed1db940449a4a9e1cd2c276'
+ARCHIVE_BASE_PATCH7_0_PART32_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-32.bin'
+ARCHIVE_BASE_PATCH7_0_PART32_MD5='4209e5bdcc87061a22236b28759eba18'
+ARCHIVE_BASE_PATCH7_0_SIZE='151199932'
+ARCHIVE_BASE_PATCH7_0_VERSION='4.1.1.6072089-gog77035'
+ARCHIVE_BASE_PATCH7_0_URL='https://www.gog.com/game/baldurs_gate_iii'
+
 ARCHIVE_BASE_PATCH6_1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.5022896_-_patch_patch6_hotfix9__(64bit)_(72479).exe'
 ARCHIVE_BASE_PATCH6_1_MD5='a68f1a0edcf026a1095c20efe1fa6edc'
 ARCHIVE_BASE_PATCH6_1_TYPE='innosetup'
@@ -83,77 +154,6 @@ ARCHIVE_BASE_PATCH6_1_PART32_NAME='setup_baldurs_gate_3_release_-_v4.1.1.5022896
 ARCHIVE_BASE_PATCH6_1_PART32_MD5='181d4fc84ee71980b1dce7d04003f5bf'
 ARCHIVE_BASE_PATCH6_1_SIZE='149637909'
 ARCHIVE_BASE_PATCH6_1_VERSION='4.1.1.5022896-gog72479'
-ARCHIVE_BASE_PATCH6_1_URL='https://www.gog.com/game/baldurs_gate_iii'
-
-ARCHIVE_BASE_PATCH6_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689).exe'
-ARCHIVE_BASE_PATCH6_0_MD5='1adeda86e51f6dd711059c27e8d5224f'
-ARCHIVE_BASE_PATCH6_0_TYPE='innosetup'
-ARCHIVE_BASE_PATCH6_0_PART1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-1.bin'
-ARCHIVE_BASE_PATCH6_0_PART1_MD5='c4274fcae2412d61045b986fa1368ed4'
-ARCHIVE_BASE_PATCH6_0_PART2_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-2.bin'
-ARCHIVE_BASE_PATCH6_0_PART2_MD5='d69c73883f75b5e40888b6bb218fb5fd'
-ARCHIVE_BASE_PATCH6_0_PART3_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-3.bin'
-ARCHIVE_BASE_PATCH6_0_PART3_MD5='fb8254fc7e30d46c6150dcf065651a1e'
-ARCHIVE_BASE_PATCH6_0_PART4_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-4.bin'
-ARCHIVE_BASE_PATCH6_0_PART4_MD5='304db0f5a987953c987eca014544fd56'
-ARCHIVE_BASE_PATCH6_0_PART5_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-5.bin'
-ARCHIVE_BASE_PATCH6_0_PART5_MD5='417ef6d694d4247f6d71e60ee0e90a65'
-ARCHIVE_BASE_PATCH6_0_PART6_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-6.bin'
-ARCHIVE_BASE_PATCH6_0_PART6_MD5='8c8a6f514debdd9088fe303c1297ab06'
-ARCHIVE_BASE_PATCH6_0_PART7_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-7.bin'
-ARCHIVE_BASE_PATCH6_0_PART7_MD5='7eeebee2ce06232bd75370172bdbb3ec'
-ARCHIVE_BASE_PATCH6_0_PART8_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-8.bin'
-ARCHIVE_BASE_PATCH6_0_PART8_MD5='70b3c3910424e753c49effc573fb52cd'
-ARCHIVE_BASE_PATCH6_0_PART9_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-9.bin'
-ARCHIVE_BASE_PATCH6_0_PART9_MD5='4ee21874b53da4039d946b2c8dcde9ea'
-ARCHIVE_BASE_PATCH6_0_PART10_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-10.bin'
-ARCHIVE_BASE_PATCH6_0_PART10_MD5='2f0403a69a7e968ab52c89aca56ffee7'
-ARCHIVE_BASE_PATCH6_0_PART11_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-11.bin'
-ARCHIVE_BASE_PATCH6_0_PART11_MD5='8168954995979ba3259ef515ac1399e6'
-ARCHIVE_BASE_PATCH6_0_PART12_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-12.bin'
-ARCHIVE_BASE_PATCH6_0_PART12_MD5='b1ed340641bb988cfe412c9c1f729f12'
-ARCHIVE_BASE_PATCH6_0_PART13_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-13.bin'
-ARCHIVE_BASE_PATCH6_0_PART13_MD5='831e762e66bcf2cf20a8434f35d1cc27'
-ARCHIVE_BASE_PATCH6_0_PART14_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-14.bin'
-ARCHIVE_BASE_PATCH6_0_PART14_MD5='be44bad0b9eb5cf649e3568f473b1331'
-ARCHIVE_BASE_PATCH6_0_PART15_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-15.bin'
-ARCHIVE_BASE_PATCH6_0_PART15_MD5='2140db0a5068b86d329bc55c26d4e822'
-ARCHIVE_BASE_PATCH6_0_PART16_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-16.bin'
-ARCHIVE_BASE_PATCH6_0_PART16_MD5='ed03595ca67160d089c305fb4c9bde3d'
-ARCHIVE_BASE_PATCH6_0_PART17_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-17.bin'
-ARCHIVE_BASE_PATCH6_0_PART17_MD5='0a0b02e5ba1a6079a038e0437afd1f2f'
-ARCHIVE_BASE_PATCH6_0_PART18_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-18.bin'
-ARCHIVE_BASE_PATCH6_0_PART18_MD5='aeb62197de4f69c0a019c391f3a7e3c3'
-ARCHIVE_BASE_PATCH6_0_PART19_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-19.bin'
-ARCHIVE_BASE_PATCH6_0_PART19_MD5='7fcf7864a1118e818c7de8362a88e5d2'
-ARCHIVE_BASE_PATCH6_0_PART20_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-20.bin'
-ARCHIVE_BASE_PATCH6_0_PART20_MD5='08cb9545c8f7e032a3dbabb6a24a363c'
-ARCHIVE_BASE_PATCH6_0_PART21_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-21.bin'
-ARCHIVE_BASE_PATCH6_0_PART21_MD5='fb6376493dba115a7c674899fddf28ce'
-ARCHIVE_BASE_PATCH6_0_PART22_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-22.bin'
-ARCHIVE_BASE_PATCH6_0_PART22_MD5='c4e8ac5364bc37eba2df4915439085f8'
-ARCHIVE_BASE_PATCH6_0_PART23_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-23.bin'
-ARCHIVE_BASE_PATCH6_0_PART23_MD5='a894d6a54bdc26ca8bcefd2554dedec9'
-ARCHIVE_BASE_PATCH6_0_PART24_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-24.bin'
-ARCHIVE_BASE_PATCH6_0_PART24_MD5='b422de0996ffb51c75ff00cf167c79cd'
-ARCHIVE_BASE_PATCH6_0_PART25_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-25.bin'
-ARCHIVE_BASE_PATCH6_0_PART25_MD5='4149e5c36d40b7bb0d00a1e99990ae2f'
-ARCHIVE_BASE_PATCH6_0_PART26_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-26.bin'
-ARCHIVE_BASE_PATCH6_0_PART26_MD5='da645662e22d6a56408c002c1a21d80e'
-ARCHIVE_BASE_PATCH6_0_PART27_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-27.bin'
-ARCHIVE_BASE_PATCH6_0_PART27_MD5='2e9e7ad933f31a6932a03cc96683996e'
-ARCHIVE_BASE_PATCH6_0_PART28_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-28.bin'
-ARCHIVE_BASE_PATCH6_0_PART28_MD5='534def45ff6461622c6ad00b1896064c'
-ARCHIVE_BASE_PATCH6_0_PART29_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-29.bin'
-ARCHIVE_BASE_PATCH6_0_PART29_MD5='969580653831dd9300a0140f956ba075'
-ARCHIVE_BASE_PATCH6_0_PART30_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-30.bin'
-ARCHIVE_BASE_PATCH6_0_PART30_MD5='bd384da9ed9589b42afe2bafdf16f84d'
-ARCHIVE_BASE_PATCH6_0_PART31_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-31.bin'
-ARCHIVE_BASE_PATCH6_0_PART31_MD5='6947e03d8f686bdde5e384b7b3443a30'
-ARCHIVE_BASE_PATCH6_0_PART32_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-32.bin'
-ARCHIVE_BASE_PATCH6_0_PART32_MD5='c47aeb4934f076c85240bc5e1d42a59c'
-ARCHIVE_BASE_PATCH6_0_SIZE='149344069'
-ARCHIVE_BASE_PATCH6_0_VERSION='4.1.1.4890942-gog71689'
 
 ARCHIVE_BASE_PATCH5_1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408).exe'
 ARCHIVE_BASE_PATCH5_1_MD5='41d296389ec755596846312c290188ba'
@@ -221,72 +221,6 @@ ARCHIVE_BASE_PATCH5_1_PART30_MD5='9d1e8c2dde7c7e8d7be9684a1d2936dc'
 ARCHIVE_BASE_PATCH5_1_SIZE='144316256'
 ARCHIVE_BASE_PATCH5_1_VERSION='4.1.1.4494476-gog70408'
 
-ARCHIVE_BASE_PATCH5_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888).exe'
-ARCHIVE_BASE_PATCH5_0_MD5='6862e7a492de45b737d78e08c281a511'
-ARCHIVE_BASE_PATCH5_0_TYPE='innosetup'
-ARCHIVE_BASE_PATCH5_0_PART1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-1.bin'
-ARCHIVE_BASE_PATCH5_0_PART1_MD5='186c358ea2dc870e028ec0673a6365e3'
-ARCHIVE_BASE_PATCH5_0_PART2_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-2.bin'
-ARCHIVE_BASE_PATCH5_0_PART2_MD5='5cce05c8723bed050cda429c0f6c04e1'
-ARCHIVE_BASE_PATCH5_0_PART3_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-3.bin'
-ARCHIVE_BASE_PATCH5_0_PART3_MD5='d83a39fcd16e69d1279f265b4f01f9b5'
-ARCHIVE_BASE_PATCH5_0_PART4_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-4.bin'
-ARCHIVE_BASE_PATCH5_0_PART4_MD5='66d9b2aebad820e832e831634c0a7330'
-ARCHIVE_BASE_PATCH5_0_PART5_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-5.bin'
-ARCHIVE_BASE_PATCH5_0_PART5_MD5='68c8cdafb45c97a0cd1690d168862100'
-ARCHIVE_BASE_PATCH5_0_PART6_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-6.bin'
-ARCHIVE_BASE_PATCH5_0_PART6_MD5='1f70e6253abca8e03b16e9249ce4debd'
-ARCHIVE_BASE_PATCH5_0_PART7_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-7.bin'
-ARCHIVE_BASE_PATCH5_0_PART7_MD5='46af9f6c04b624c5049beee3dffc9696'
-ARCHIVE_BASE_PATCH5_0_PART8_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-8.bin'
-ARCHIVE_BASE_PATCH5_0_PART8_MD5='8f746939ff4e6407b78aa2f43dfc6392'
-ARCHIVE_BASE_PATCH5_0_PART9_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-9.bin'
-ARCHIVE_BASE_PATCH5_0_PART9_MD5='758b43451029e2f63ed1dbb9c987461b'
-ARCHIVE_BASE_PATCH5_0_PART10_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-10.bin'
-ARCHIVE_BASE_PATCH5_0_PART10_MD5='5d19fc102d11834f08cf6c1f0b925ea0'
-ARCHIVE_BASE_PATCH5_0_PART11_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-11.bin'
-ARCHIVE_BASE_PATCH5_0_PART11_MD5='a34ccbb9196795da458df88d16f29001'
-ARCHIVE_BASE_PATCH5_0_PART12_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-12.bin'
-ARCHIVE_BASE_PATCH5_0_PART12_MD5='4a0b02ed0fe0e213050ba36ca2c1e9bf'
-ARCHIVE_BASE_PATCH5_0_PART13_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-13.bin'
-ARCHIVE_BASE_PATCH5_0_PART13_MD5='4bba114b9fd38dc3b0c15aee4a7badc7'
-ARCHIVE_BASE_PATCH5_0_PART14_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-14.bin'
-ARCHIVE_BASE_PATCH5_0_PART14_MD5='26fab2816e6a90c46b26666a6c9825cc'
-ARCHIVE_BASE_PATCH5_0_PART15_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-15.bin'
-ARCHIVE_BASE_PATCH5_0_PART15_MD5='0c2e8f809fce1dc30d003512eeb9bdf5'
-ARCHIVE_BASE_PATCH5_0_PART16_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-16.bin'
-ARCHIVE_BASE_PATCH5_0_PART16_MD5='eb11c87799b0870c09dff97cd7d5d721'
-ARCHIVE_BASE_PATCH5_0_PART17_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-17.bin'
-ARCHIVE_BASE_PATCH5_0_PART17_MD5='679670d1c9e4b80cc4b7e1e8cd46b24a'
-ARCHIVE_BASE_PATCH5_0_PART18_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-18.bin'
-ARCHIVE_BASE_PATCH5_0_PART18_MD5='c01feb0bdf8b7677af42575c16cea2b3'
-ARCHIVE_BASE_PATCH5_0_PART19_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-19.bin'
-ARCHIVE_BASE_PATCH5_0_PART19_MD5='7f9b210f8afc3320bead9637edb882ac'
-ARCHIVE_BASE_PATCH5_0_PART20_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-20.bin'
-ARCHIVE_BASE_PATCH5_0_PART20_MD5='b4bc49e1a36c10cf1ad64665300f3d3a'
-ARCHIVE_BASE_PATCH5_0_PART21_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-21.bin'
-ARCHIVE_BASE_PATCH5_0_PART21_MD5='aa7c335e7ffc0bcda16d19817e7d2e32'
-ARCHIVE_BASE_PATCH5_0_PART22_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-22.bin'
-ARCHIVE_BASE_PATCH5_0_PART22_MD5='5d6cef68c2e0067d2aac4b891ddc15fe'
-ARCHIVE_BASE_PATCH5_0_PART23_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-23.bin'
-ARCHIVE_BASE_PATCH5_0_PART23_MD5='b7596a74a8d17ba53041f4cb65e7c275'
-ARCHIVE_BASE_PATCH5_0_PART24_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-24.bin'
-ARCHIVE_BASE_PATCH5_0_PART24_MD5='ee7278a6d7ddc74f9e84350c007d83f4'
-ARCHIVE_BASE_PATCH5_0_PART25_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-25.bin'
-ARCHIVE_BASE_PATCH5_0_PART25_MD5='5f53ee4b9c609e0e2033c24349c7c08f'
-ARCHIVE_BASE_PATCH5_0_PART26_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-26.bin'
-ARCHIVE_BASE_PATCH5_0_PART26_MD5='8bcc1faddcc9dbaea2181d6407944e91'
-ARCHIVE_BASE_PATCH5_0_PART27_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-27.bin'
-ARCHIVE_BASE_PATCH5_0_PART27_MD5='4be5806c0d26719004cf3c7f447a9adb'
-ARCHIVE_BASE_PATCH5_0_PART28_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-28.bin'
-ARCHIVE_BASE_PATCH5_0_PART28_MD5='2acf6acde88c6c7e38d2d018b9777321'
-ARCHIVE_BASE_PATCH5_0_PART29_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-29.bin'
-ARCHIVE_BASE_PATCH5_0_PART29_MD5='c02adb5c2f3492580e4b2264d678bbec'
-ARCHIVE_BASE_PATCH5_0_PART30_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-30.bin'
-ARCHIVE_BASE_PATCH5_0_PART30_MD5='9d686af3f1622d30a4636d97614a0e12'
-ARCHIVE_BASE_PATCH5_0_SIZE='144082412'
-ARCHIVE_BASE_PATCH5_0_VERSION='4.1.1.4251417-gog69888'
-
 ARCHIVE_BASE_PATCH4_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995).exe'
 ARCHIVE_BASE_PATCH4_0_MD5='ab6267432b272ff880127131e7b2f5f3'
 ARCHIVE_BASE_PATCH4_0_TYPE='innosetup'
@@ -478,7 +412,6 @@ ARCHIVE_BASE_PATCH2_0_PART29_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3700362
 ARCHIVE_BASE_PATCH2_0_PART29_MD5='2e4c222aabc70fd6068ad8834aaa7b2c'
 ARCHIVE_BASE_PATCH2_0_SIZE='145464212'
 ARCHIVE_BASE_PATCH2_0_VERSION='4.1.1.3700362-gog67336'
-ARCHIVE_BASE_PATCH2_0_URL='https://www.gog.com/game/baldurs_gate_iii'
 
 ARCHIVE_BASE_PATCH1_0_NAME='setup_baldurs_gate_3_live_-_v4.1.1.3669438_-_patch_patch1_data_fix_(64bit)_(67052).exe'
 ARCHIVE_BASE_PATCH1_0_MD5='09401cf3b960c56032b9c8d5492d2316'
@@ -668,6 +601,8 @@ CONTENT_GAME_DATA_PATCH5_FILES='
 data/patch5_hotfix*.pak'
 CONTENT_GAME_DATA_PATCH6_FILES='
 data/patch6_hotfix*.pak'
+CONTENT_GAME_DATA_PATCH7_FILES='
+data/patch7_hotfix*.pak'
 CONTENT_GAME_DATA_FILES='
 data/assets.pak
 data/day0.pak
@@ -705,14 +640,10 @@ data/patch3.pak'
 WINE_PERSISTENT_DIRECTORIES="
 users/\${USER}/AppData/Local/Larian Studios/Baldur's Gate 3"
 ## mfc140u.dll is required.
+## TODO: Check if this is still required with current WINE
 WINE_WINETRICKS_VERBS='mfc140'
 
 APP_MAIN_EXE='bin/bg3.exe'
-## Run the game binary from its parent directory.
-APP_MAIN_PRERUN='# Run the game binary from its parent directory
-cd "$(dirname "$APP_EXE")"
-APP_EXE=$(basename "$APP_EXE")
-'
 
 PACKAGES_LIST_BASE='
 PKG_BIN
@@ -733,31 +664,37 @@ PKG_DATA_TEXTURES_8
 PKG_DATA_TEXTURES_9
 PKG_DATA_TEXTURES_10
 PKG_DATA_TEXTURES_11
-PKG_DATA_TEXTURES_12
 PKG_DATA'
 PACKAGES_LIST_PATCH0="$PACKAGES_LIST_BASE
 PKG_DATA_PATCH0"
-PACKAGES_LIST_PATCH1="$PACKAGES_LIST_PATCH0
+PACKAGES_LIST_PATCH1="$PACKAGES_LIST_BASE
+PKG_DATA_PATCH0
 PKG_DATA_PATCH1"
-PACKAGES_LIST_PATCH2="$PACKAGES_LIST_PATCH1
+PACKAGES_LIST_PATCH2="$PACKAGES_LIST_BASE
+PKG_DATA_PATCH0
+PKG_DATA_PATCH1
 PKG_DATA_PATCH2"
-PACKAGES_LIST_PATCH3="$PACKAGES_LIST_PATCH2
+PACKAGES_LIST_PATCH3="$PACKAGES_LIST_BASE
+PKG_DATA_PATCH0
+PKG_DATA_PATCH1
+PKG_DATA_PATCH2
 PKG_DATA_PATCH3"
-## Archives patch0*.pak, patch1*.pak, patch2*.pak and patch3*.pak are dropped with the patch 4 release.
 PACKAGES_LIST_PATCH4="$PACKAGES_LIST_BASE
 PKG_DATA_PATCH4"
-## Archives patch4*.pak are dropped with the patch 5 release.
 PACKAGES_LIST_PATCH5="$PACKAGES_LIST_BASE
+PKG_DATA_TEXTURES_12
 PKG_DATA_PATCH5"
-## Archives patch5*.pak are dropped with the patch 6 release.
 PACKAGES_LIST_PATCH6="$PACKAGES_LIST_BASE
+PKG_DATA_TEXTURES_12
 PKG_DATA_PATCH6"
+PACKAGES_LIST_PATCH7="$PACKAGES_LIST_BASE
+PKG_DATA_TEXTURES_12
+PKG_DATA_PATCH7"
 
-PKG_L10N_COMMON_ID="${GAME_ID}-l10n-common"
-PKG_L10N_COMMON_DESCRIPTION='localizations - shared files'
-
-PKG_L10N_VOICES_ID="${GAME_ID}-l10n-voices"
-PKG_L10N_VOICES_DESCRIPTION="$PKG_L10N_DESCRIPTION - voices"
+PKG_BIN_ARCH='64'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N
+PKG_DATA'
 
 PKG_L10N_ID="${GAME_ID}-l10n"
 PKG_L10N_EN_ID="${PKG_L10N_ID}-en"
@@ -768,20 +705,65 @@ PKG_L10N_EN_PROVIDES="$PKG_L10N_PROVIDES"
 PKG_L10N_FR_PROVIDES="$PKG_L10N_PROVIDES"
 PKG_L10N_EN_DESCRIPTION='English localization'
 PKG_L10N_FR_DESCRIPTION='French localization'
-PKG_L10N_DEPS="$PKG_L10N_COMMON_ID $PKG_L10N_VOICES_ID"
-PKG_L10N_EN_DEPS="$PKG_L10N_DEPS"
-PKG_L10N_FR_DEPS="$PKG_L10N_DEPS"
+PKG_L10N_DEPENDENCIES_SIBLINGS='
+PKG_L10N_COMMON
+PKG_L10N_VOICES'
+PKG_L10N_EN_DEPENDENCIES_SIBLINGS="$PKG_L10N_DEPENDENCIES_SIBLINGS"
+PKG_L10N_FR_DEPENDENCIES_SIBLINGS="$PKG_L10N_DEPENDENCIES_SIBLINGS"
+
+PKG_L10N_COMMON_ID="${PKG_L10N_ID}-common"
+PKG_L10N_COMMON_DESCRIPTION='localizations - shared files'
+
+PKG_L10N_VOICES_ID="${PKG_L10N_ID}-voices"
+PKG_L10N_VOICES_DESCRIPTION='localizations - voices'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
+PKG_DATA_DEPENDENCIES_SIBLINGS='
+PKG_DATA_MODELS
+PKG_DATA_SOUNDS
+PKG_DATA_TEXTURES_1
+PKG_DATA_TEXTURES_2
+PKG_DATA_TEXTURES_3
+PKG_DATA_TEXTURES_4
+PKG_DATA_TEXTURES_5
+PKG_DATA_TEXTURES_6
+PKG_DATA_TEXTURES_7
+PKG_DATA_TEXTURES_8
+PKG_DATA_TEXTURES_9
+PKG_DATA_TEXTURES_10
+PKG_DATA_TEXTURES_11'
+PKG_DATA_DEPENDENCIES_SIBLINGS_PATCH0="$PKG_DATA_DEPENDENCIES_SIBLINGS
+PKG_DATA_PATCH0"
+PKG_DATA_DEPENDENCIES_SIBLINGS_PATCH1="$PKG_DATA_DEPENDENCIES_SIBLINGS
+PKG_DATA_PATCH0
+PKG_DATA_PATCH1"
+PKG_DATA_DEPENDENCIES_SIBLINGS_PATCH2="$PKG_DATA_DEPENDENCIES_SIBLINGS
+PKG_DATA_PATCH0
+PKG_DATA_PATCH1
+PKG_DATA_PATCH2"
+PKG_DATA_DEPENDENCIES_SIBLINGS_PATCH3="$PKG_DATA_DEPENDENCIES_SIBLINGS
+PKG_DATA_PATCH0
+PKG_DATA_PATCH1
+PKG_DATA_PATCH2
+PKG_DATA_PATCH3"
+PKG_DATA_DEPENDENCIES_SIBLINGS_PATCH4="$PKG_DATA_DEPENDENCIES_SIBLINGS
+PKG_DATA_PATCH4"
+PKG_DATA_DEPENDENCIES_SIBLINGS_PATCH5="$PKG_DATA_DEPENDENCIES_SIBLINGS
+PKG_DATA_TEXTURES_12
+PKG_DATA_PATCH5"
+PKG_DATA_DEPENDENCIES_SIBLINGS_PATCH6="$PKG_DATA_DEPENDENCIES_SIBLINGS
+PKG_DATA_TEXTURES_12
+PKG_DATA_PATCH6"
+PKG_DATA_DEPENDENCIES_SIBLINGS_PATCH7="$PKG_DATA_DEPENDENCIES_SIBLINGS
+PKG_DATA_TEXTURES_12
+PKG_DATA_PATCH7"
 
 PKG_DATA_MODELS_ID="${PKG_DATA_ID}-models"
 PKG_DATA_MODELS_DESCRIPTION="$PKG_DATA_DESCRIPTION - models"
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_MODELS_ID"
 
 PKG_DATA_SOUNDS_ID="${PKG_DATA_ID}-sounds"
 PKG_DATA_SOUNDS_DESCRIPTION="$PKG_DATA_DESCRIPTION - sounds"
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_SOUNDS_ID"
 
 PKG_DATA_TEXTURES_ID="${PKG_DATA_ID}-textures"
 PKG_DATA_TEXTURES_1_ID="${PKG_DATA_TEXTURES_ID}-1"
@@ -809,19 +791,6 @@ PKG_DATA_TEXTURES_9_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 9"
 PKG_DATA_TEXTURES_10_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 10"
 PKG_DATA_TEXTURES_11_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 11"
 PKG_DATA_TEXTURES_12_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 12"
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_TEXTURES_1_ID $PKG_DATA_TEXTURES_2_ID $PKG_DATA_TEXTURES_3_ID $PKG_DATA_TEXTURES_4_ID $PKG_DATA_TEXTURES_5_ID $PKG_DATA_TEXTURES_6_ID $PKG_DATA_TEXTURES_7_ID $PKG_DATA_TEXTURES_8_ID $PKG_DATA_TEXTURES_9_ID $PKG_DATA_TEXTURES_10_ID $PKG_DATA_TEXTURES_11_ID $PKG_DATA_TEXTURES_12_ID"
-## Only 11 texture packages are required prior to patch 5.
-PACKAGES_LIST_PATCH4=$(printf '%s' "$PACKAGES_LIST_PATCH4" | grep --invert-match 'PKG_DATA_TEXTURES_12')
-PACKAGES_LIST_PATCH3="$PACKAGES_LIST_PATCH4"
-PACKAGES_LIST_PATCH2="$PACKAGES_LIST_PATCH4"
-PACKAGES_LIST_PATCH1="$PACKAGES_LIST_PATCH4"
-PACKAGES_LIST_PATCH0="$PACKAGES_LIST_PATCH4"
-PKG_DATA_TEXTURES_11_PROVIDES_PATCH4="${PKG_DATA_TEXTURES_11_PROVIDES:-}
-$PKG_DATA_TEXTURES_12_ID"
-PKG_DATA_TEXTURES_11_PROVIDES_PATCH3="$PKG_DATA_TEXTURES_11_PROVIDES_PATCH4"
-PKG_DATA_TEXTURES_11_PROVIDES_PATCH2="$PKG_DATA_TEXTURES_11_PROVIDES_PATCH4"
-PKG_DATA_TEXTURES_11_PROVIDES_PATCH1="$PKG_DATA_TEXTURES_11_PROVIDES_PATCH4"
-PKG_DATA_TEXTURES_11_PROVIDES_PATCH0="$PKG_DATA_TEXTURES_11_PROVIDES_PATCH4"
 
 PKG_DATA_PATCH0_ID="${PKG_DATA_ID}-patch0"
 PKG_DATA_PATCH1_ID="${PKG_DATA_ID}-patch1"
@@ -830,6 +799,7 @@ PKG_DATA_PATCH3_ID="${PKG_DATA_ID}-patch3"
 PKG_DATA_PATCH4_ID="${PKG_DATA_ID}-patch4"
 PKG_DATA_PATCH5_ID="${PKG_DATA_ID}-patch5"
 PKG_DATA_PATCH6_ID="${PKG_DATA_ID}-patch6"
+PKG_DATA_PATCH7_ID="${PKG_DATA_ID}-patch7"
 PKG_DATA_PATCH0_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch0"
 PKG_DATA_PATCH1_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch1"
 PKG_DATA_PATCH2_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch2"
@@ -837,13 +807,7 @@ PKG_DATA_PATCH3_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch3"
 PKG_DATA_PATCH4_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch4"
 PKG_DATA_PATCH5_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch5"
 PKG_DATA_PATCH6_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch6"
-PKG_DATA_DEPS_PATCH0="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH0_ID"
-PKG_DATA_DEPS_PATCH1="$PKG_DATA_DEPS_PATCH0 $PKG_DATA_PATCH1_ID"
-PKG_DATA_DEPS_PATCH2="$PKG_DATA_DEPS_PATCH1 $PKG_DATA_PATCH2_ID"
-PKG_DATA_DEPS_PATCH3="$PKG_DATA_DEPS_PATCH2 $PKG_DATA_PATCH3_ID"
-PKG_DATA_DEPS_PATCH4="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH4_ID"
-PKG_DATA_DEPS_PATCH5="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH5_ID"
-PKG_DATA_DEPS_PATCH6="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH6_ID"
+PKG_DATA_PATCH7_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch7"
 ## Archives patch0*.pak, patch1*.pak, patch2*.pak and patch3*.pak are dropped with the patch 4 release.
 PKG_DATA_PATCH4_PROVIDES="
 $PKG_DATA_PATCH0_ID
@@ -858,9 +822,9 @@ $PKG_DATA_PATCH4_ID"
 ## Archives patch5*.pak are dropped with the patch 6 release.
 PKG_DATA_PATCH6_PROVIDES="$PKG_DATA_PATCH5_PROVIDES
 $PKG_DATA_PATCH5_ID"
-
-PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
+## Archives patch6*.pak are dropped with the patch 7 release.
+PKG_DATA_PATCH7_PROVIDES="$PKG_DATA_PATCH6_PROVIDES
+$PKG_DATA_PATCH6_ID"
 
 # Load common functions
 
@@ -885,8 +849,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -915,12 +884,20 @@ content_inclusion_default
 
 # Write launchers
 
+## Run the game binary from its parent directory
+game_exec_line() {
+	cat <<- 'EOF'
+	cd bin
+	$(wine_command) bg3.exe "$@"
+	EOF
+}
+
 launchers_generation 'PKG_BIN'
 
 # Build packages
 
 packages_generation
-case "${LANG%_*}" in
+case "$(messages_language)" in
 	('fr')
 		message='version %s :'
 		lang_en='anglaise'
@@ -935,13 +912,19 @@ esac
 printf '\n'
 ## English localization
 printf "$message" "$lang_en"
+## Silence a ShellCheck false positive, word splitting is expected here
+## SC2046 (warning): Quote this to prevent word splitting.
+# shellcheck disable=SC2046
 print_instructions $(packages_list | sed 's/PKG_L10N_FR//')
 ## French localization
 printf "$message" "$lang_fr"
+## Silence a ShellCheck false positive, word splitting is expected here
+## SC2046 (warning): Quote this to prevent word splitting.
+# shellcheck disable=SC2046
 print_instructions $(packages_list | sed 's/PKG_L10N_EN//')
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
