@@ -12,9 +12,9 @@ set -o errexit
 # - The Exile
 ###
 
-script_version=20240531.1
+script_version=20241123.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='cultist-simulator'
 GAME_NAME='Cultist Simulator'
@@ -38,6 +38,16 @@ EXPANSION_NAME_EXILE='The Exile'
 
 ## Perpetual Edition
 
+ARCHIVE_BASE_PERPETUAL_9_NAME='cultist_simulator_perpetual_edition_content_2024_7_b_3_77913.sh'
+ARCHIVE_BASE_PERPETUAL_9_MD5='653f6b60b6587db9b24e850daf25e045'
+ARCHIVE_BASE_PERPETUAL_9_SIZE='897'
+ARCHIVE_BASE_PERPETUAL_9_VERSION='2024.07.b.3-gog77913'
+
+ARCHIVE_BASE_PERPETUAL_8_NAME='cultist_simulator_perpetual_edition_content_2024_5_a_3_74582.sh'
+ARCHIVE_BASE_PERPETUAL_8_MD5='0150fa2617c138697f8b05b9c659e76e'
+ARCHIVE_BASE_PERPETUAL_8_SIZE='897'
+ARCHIVE_BASE_PERPETUAL_8_VERSION='2024.05.a.3-gog74582'
+
 ARCHIVE_BASE_PERPETUAL_7_NAME='cultist_simulator_perpetual_edition_content_2023_12_s_5_71509.sh'
 ARCHIVE_BASE_PERPETUAL_7_MD5='ba64a839ed79df208e346e45705028c7'
 ARCHIVE_BASE_PERPETUAL_7_SIZE='897'
@@ -80,11 +90,21 @@ ARCHIVE_BASE_PERPETUAL_0_VERSION='2022.03.n.1-gog54418'
 
 ## The Dancer
 
+ARCHIVE_BASE_DANCER_9_NAME='cultist_simulator_the_dancer_2024_7_b_3_77913.sh'
+ARCHIVE_BASE_DANCER_9_MD5='f9304991269fb79b8fa80a0d8ca55baa'
+ARCHIVE_BASE_DANCER_9_SIZE='1178'
+ARCHIVE_BASE_DANCER_9_VERSION='2024.07.b.3-gog77913'
+ARCHIVE_BASE_DANCER_9_URL='https://www.gog.com/game/cultist_simulator_the_dancer'
+
+ARCHIVE_BASE_DANCER_8_NAME='cultist_simulator_the_dancer_2024_5_a_3_74582.sh'
+ARCHIVE_BASE_DANCER_8_MD5='033bb0945379a41d711ab7d8b23c9230'
+ARCHIVE_BASE_DANCER_8_SIZE='1178'
+ARCHIVE_BASE_DANCER_8_VERSION='2024.05.a.3-gog74582'
+
 ARCHIVE_BASE_DANCER_7_NAME='cultist_simulator_the_dancer_2023_12_s_5_71509.sh'
 ARCHIVE_BASE_DANCER_7_MD5='7411914a034e8f059f2f78b1476101d2'
 ARCHIVE_BASE_DANCER_7_SIZE='1178'
 ARCHIVE_BASE_DANCER_7_VERSION='2023.12.s.5-gog71509'
-ARCHIVE_BASE_DANCER_7_URL='https://www.gog.com/game/cultist_simulator_the_dancer'
 
 ARCHIVE_BASE_DANCER_6_NAME='cultist_simulator_the_dancer_2023_12_s_4_71175.sh'
 ARCHIVE_BASE_DANCER_6_MD5='5a33ee82ccc822bc5a249288093e315a'
@@ -123,11 +143,21 @@ ARCHIVE_BASE_DANCER_0_VERSION='2022.03.n.1-gog54418'
 
 ## The Ghoul
 
+ARCHIVE_BASE_GHOUL_9_NAME='cultist_simulator_the_ghoul_2024_7_b_3_77913.sh'
+ARCHIVE_BASE_GHOUL_9_MD5='51397b535a1a70d49eb63019d7a385ff'
+ARCHIVE_BASE_GHOUL_9_SIZE='1163'
+ARCHIVE_BASE_GHOUL_9_VERSION='2024.07.b.3-gog77913'
+ARCHIVE_BASE_GHOUL_9_URL='https://www.gog.com/game/cultist_simulator_the_ghoul'
+
+ARCHIVE_BASE_GHOUL_8_NAME='cultist_simulator_the_ghoul_2024_5_a_3_74582.sh'
+ARCHIVE_BASE_GHOUL_8_MD5='c142d2c03bba7cfb84dd54742a1c02ee'
+ARCHIVE_BASE_GHOUL_8_SIZE='1163'
+ARCHIVE_BASE_GHOUL_8_VERSION='2024.05.a.3-gog74582'
+
 ARCHIVE_BASE_GHOUL_7_NAME='cultist_simulator_the_ghoul_2023_12_s_5_71509.sh'
 ARCHIVE_BASE_GHOUL_7_MD5='8185ddbb6681d90a233078d959188c2e'
 ARCHIVE_BASE_GHOUL_7_SIZE='1163'
 ARCHIVE_BASE_GHOUL_7_VERSION='2023.12.s.5-gog71509'
-ARCHIVE_BASE_GHOUL_7_URL='https://www.gog.com/game/cultist_simulator_the_ghoul'
 
 ARCHIVE_BASE_GHOUL_6_NAME='cultist_simulator_the_ghoul_2023_12_s_4_71175.sh'
 ARCHIVE_BASE_GHOUL_6_MD5='ff6fdc10d98aea9e260522521112d176'
@@ -166,11 +196,21 @@ ARCHIVE_BASE_GHOUL_0_VERSION='2022.03.n.1-gog54418'
 
 ## The Priest
 
+ARCHIVE_BASE_PRIEST_9_NAME='cultist_simulator_the_priest_2024_7_b_3_77913.sh'
+ARCHIVE_BASE_PRIEST_9_MD5='4e5b1868e6f14fbb31ccfda6c3e14667'
+ARCHIVE_BASE_PRIEST_9_SIZE='1238'
+ARCHIVE_BASE_PRIEST_9_VERSION='2024.07.b.3-gog77913'
+ARCHIVE_BASE_PRIEST_9_URL='https://www.gog.com/game/cultist_simulator_the_priest'
+
+ARCHIVE_BASE_PRIEST_8_NAME='cultist_simulator_the_priest_2024_5_a_3_74582.sh'
+ARCHIVE_BASE_PRIEST_8_MD5='efa3f7d478e0083e51f83db79c787efa'
+ARCHIVE_BASE_PRIEST_8_SIZE='1238'
+ARCHIVE_BASE_PRIEST_8_VERSION='2024.05.a.3-gog74582'
+
 ARCHIVE_BASE_PRIEST_7_NAME='cultist_simulator_the_priest_2023_12_s_5_71509.sh'
 ARCHIVE_BASE_PRIEST_7_MD5='0b5d5436b8853cfc3a100404070779c8'
 ARCHIVE_BASE_PRIEST_7_SIZE='1238'
 ARCHIVE_BASE_PRIEST_7_VERSION='2023.12.s.5-gog71509'
-ARCHIVE_BASE_PRIEST_7_URL='https://www.gog.com/game/cultist_simulator_the_priest'
 
 ARCHIVE_BASE_PRIEST_6_NAME='cultist_simulator_the_priest_2023_12_s_4_71175.sh'
 ARCHIVE_BASE_PRIEST_6_MD5='84f26baca8a0219e3b11f6f91fca3bb9'
@@ -209,11 +249,21 @@ ARCHIVE_BASE_PRIEST_0_VERSION='2022.03.n.1-gog54418'
 
 ## The Exile
 
+ARCHIVE_BASE_EXILE_9_NAME='cultist_simulator_the_exile_2024_7_b_3_77913.sh'
+ARCHIVE_BASE_EXILE_9_MD5='dda93215acba7d7aeeedb9f356830ffb'
+ARCHIVE_BASE_EXILE_9_SIZE='5482'
+ARCHIVE_BASE_EXILE_9_VERSION='2024.07.b.3-gog77913'
+ARCHIVE_BASE_EXILE_9_URL='https://www.gog.com/game/cultist_simulator_the_exile'
+
+ARCHIVE_BASE_EXILE_8_NAME='cultist_simulator_the_exile_2024_5_a_3_74582.sh'
+ARCHIVE_BASE_EXILE_8_MD5='0617fc6bb9dc85982e33ef203bce039a'
+ARCHIVE_BASE_EXILE_8_SIZE='5482'
+ARCHIVE_BASE_EXILE_8_VERSION='2024.05.a.3-gog74582'
+
 ARCHIVE_BASE_EXILE_7_NAME='cultist_simulator_the_exile_2023_12_s_5_71509.sh'
 ARCHIVE_BASE_EXILE_7_MD5='b8ec4b2021be5b82b4d1bea8f85e2275'
 ARCHIVE_BASE_EXILE_7_SIZE='5482'
 ARCHIVE_BASE_EXILE_7_VERSION='2023.12.s.5-gog71509'
-ARCHIVE_BASE_EXILE_7_URL='https://www.gog.com/game/cultist_simulator_the_exile'
 
 ARCHIVE_BASE_EXILE_6_NAME='cultist_simulator_the_exile_2023_12_s_4_71175.sh'
 ARCHIVE_BASE_EXILE_6_MD5='4848d25ba494b3ce05199c14b3fb7cdb'
@@ -255,7 +305,10 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 CS_Data'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
@@ -280,8 +333,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -297,6 +355,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
