@@ -7,18 +7,28 @@ set -o errexit
 # Cultist Simulator
 ###
 
-script_version=20240531.1
+script_version=20241123.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='cultist-simulator'
 GAME_NAME='Cultist Simulator'
 
+ARCHIVE_BASE_19_NAME='cultist_simulator_2024_7_b_3_77913.sh'
+ARCHIVE_BASE_19_MD5='7dec8c03b9f2ec9136ead667cfd4fb73'
+ARCHIVE_BASE_19_SIZE='707969'
+ARCHIVE_BASE_19_VERSION='2024.07.b.3-gog77913'
+ARCHIVE_BASE_19_URL='https://www.gog.com/game/cultist_simulator'
+
+ARCHIVE_BASE_18_NAME='cultist_simulator_2024_5_a_3_74582.sh'
+ARCHIVE_BASE_18_MD5='4a6d4118f5545f95119a0f6fedcf1e16'
+ARCHIVE_BASE_18_SIZE='707816'
+ARCHIVE_BASE_18_VERSION='2024.05.a.3-gog74582'
+
 ARCHIVE_BASE_17_NAME='cultist_simulator_2023_12_s_5_71509.sh'
 ARCHIVE_BASE_17_MD5='7e5fd05666c22c1b44401525e2fd24f1'
 ARCHIVE_BASE_17_SIZE='707815'
 ARCHIVE_BASE_17_VERSION='2023.12.s.5-gog71509'
-ARCHIVE_BASE_17_URL='https://www.gog.com/game/cultist_simulator'
 
 ARCHIVE_BASE_16_NAME='cultist_simulator_2023_12_s_4_71175.sh'
 ARCHIVE_BASE_16_MD5='b34cef2cea237aff1b4ff33fe6acdece'
@@ -121,11 +131,9 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -135,6 +143,9 @@ libpthread.so.0
 librt.so.1
 libz.so.1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -158,8 +169,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -172,14 +188,14 @@ content_inclusion_default
 # Write launchers
 
 launchers_generation 'PKG_BIN'
+
+# Build packages
+
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
