@@ -11,9 +11,9 @@ set -o errexit
 # - The Color of Madness
 ###
 
-script_version=20240605.1
+script_version=20241021.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='darkest-dungeon'
 GAME_NAME='Darkest Dungeon'
@@ -164,7 +164,10 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 dlc'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
@@ -189,8 +192,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -206,6 +214,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
