@@ -7,9 +7,9 @@ set -o errexit
 # Darkest Dungeon
 ###
 
-script_version=20240605.1
+script_version=20241103.3
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='darkest-dungeon'
 GAME_NAME='Darkest Dungeon'
@@ -116,20 +116,25 @@ README.linux'
 APP_MAIN_EXE_BIN32='darkest.bin.x86'
 APP_MAIN_EXE_BIN64='darkest.bin.x86_64'
 APP_MAIN_ICON='Icon.bmp'
+## Prevent a game crash when using the Wayland video backend of SDL
+APP_MAIN_PRERUN='
+# Prevent a game crash when using the Wayland video backend of SDL
+if [ "${SDL_VIDEODRIVER:-}" = "wayland" ]; then
+	unset SDL_VIDEODRIVER
+fi
+'
 
 PACKAGES_LIST='
 PKG_BIN64
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -143,9 +148,13 @@ libstdc++.so.6'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Fix icon background transparency
 
-SCRIPT_DEPS="${SCRIPT_DEPS:-} convert"
+REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
+convert"
 
 # Load common functions
 
@@ -170,8 +179,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -204,6 +218,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
