@@ -7,23 +7,41 @@ set -o errexit
 # Diablo 1
 ###
 
-script_version=20240530.1
+script_version=20250211.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='diablo-1'
 GAME_NAME='Diablo'
 
 # Archives
 
-## Diablo 1 (base game)
+## Diablo 1 (game data)
+
+ARCHIVE_BASE_8_NAME='setup_diablo_1.09_hellfire_v4_(78466).exe'
+ARCHIVE_BASE_8_MD5='c4d36192c35eb5f34faa1d97aae34455'
+ARCHIVE_BASE_8_TYPE='innosetup'
+ARCHIVE_BASE_8_SIZE='845401'
+ARCHIVE_BASE_8_VERSION='1.09-gog78466'
+ARCHIVE_BASE_8_URL='https://www.gog.com/game/diablo'
+
+ARCHIVE_BASE_7_NAME='setup_diablo_1.09_hellfire_v3_(78106).exe'
+ARCHIVE_BASE_7_MD5='b8d5a38fd4b21311853f19559c2ebfee'
+ARCHIVE_BASE_7_TYPE='innosetup'
+ARCHIVE_BASE_7_SIZE='845020'
+ARCHIVE_BASE_7_VERSION='1.09-gog78106'
+
+ARCHIVE_BASE_6_NAME='setup_diablo_1.09_hellfire_v2_(30037).exe'
+ARCHIVE_BASE_6_MD5='2b8f0eafc528a56452b0008dde4151a8'
+ARCHIVE_BASE_6_TYPE='innosetup'
+ARCHIVE_BASE_6_SIZE='843414'
+ARCHIVE_BASE_6_VERSION='1.09-gog30037'
 
 ARCHIVE_BASE_5_NAME='setup_diablo_1.09_hellfire_v2_(30038).exe'
 ARCHIVE_BASE_5_MD5='e70187d92fa120771db99dfa81679cfc'
 ARCHIVE_BASE_5_TYPE='innosetup'
 ARCHIVE_BASE_5_SIZE='850000'
 ARCHIVE_BASE_5_VERSION='1.09-gog30038'
-ARCHIVE_BASE_5_URL='https://www.gog.com/game/diablo'
 
 ARCHIVE_BASE_4_NAME='setup_diablo_1.09_v6_(28378).exe'
 ARCHIVE_BASE_4_MD5='588ab50c1ef25abb682b86ea4306ea50'
@@ -55,12 +73,19 @@ ARCHIVE_BASE_0_TYPE='innosetup'
 ARCHIVE_BASE_0_SIZE='680000'
 ARCHIVE_BASE_0_VERSION='1.09-gog27873'
 
-## DevilutionX 1.5.2
+## DevilutionX
+
+ARCHIVE_REQUIRED_DEVILUTIONX_1_NAME='devilutionx-x86_64-linux-gnu.tar.xz'
+ARCHIVE_REQUIRED_DEVILUTIONX_1_MD5='f5b953adfbc9ea206a7fb393d6a45299'
+ARCHIVE_REQUIRED_DEVILUTIONX_1_SIZE='39601'
+ARCHIVE_REQUIRED_DEVILUTIONX_1_VERSION='1.5.4'
+ARCHIVE_REQUIRED_DEVILUTIONX_1_URL='https://github.com/diasurgical/devilutionX/releases/tag/1.5.4'
 
 ARCHIVE_REQUIRED_DEVILUTIONX_0_NAME='devilutionx-linux-x86_64.tar.xz'
-ARCHIVE_REQUIRED_DEVILUTIONX_0_MD5='3aea64fad536cded6b11e035d0e235a8'
-ARCHIVE_REQUIRED_DEVILUTIONX_0_SIZE='38427'
-ARCHIVE_REQUIRED_DEVILUTIONX_0_URL='https://github.com/diasurgical/devilutionX/releases/tag/1.5.2'
+ARCHIVE_REQUIRED_DEVILUTIONX_0_MD5='36dce8b296aabcefac2dcd3e7bd2a5c7'
+ARCHIVE_REQUIRED_DEVILUTIONX_0_SIZE='39208'
+ARCHIVE_REQUIRED_DEVILUTIONX_0_VERSION='1.5.3'
+ARCHIVE_REQUIRED_DEVILUTIONX_0_URL='https://github.com/diasurgical/devilutionX/releases/tag/1.5.3'
 
 
 CONTENT_PATH_DEFAULT='.'
@@ -82,22 +107,20 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
-libdl.so.2
-libgcc_s.so.1
 libm.so.6
 libpthread.so.0
-librt.so.1
 libSDL2-2.0.so.0
 libSDL2_image-2.0.so.0
 libz.so.1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -121,13 +144,21 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Check for the presence of required extra archives
+# Run the default initialization actions
+
+initialization_default "$@"
+
+# Check for the presence of the archive providing the game engine
 
 archive_initialize_required \
 	'ARCHIVE_DEVILUTIONX' \
+	'ARCHIVE_REQUIRED_DEVILUTIONX_1' \
 	'ARCHIVE_REQUIRED_DEVILUTIONX_0'
+## TODO: Update the version string based on the engine build
+##       cf. https://forge.dotslashplay.it/play.it/play.it/-/issues/550
 
 # Extract game data
 
@@ -136,13 +167,13 @@ archive_extraction 'ARCHIVE_DEVILUTIONX'
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## Delete unwanted files.
+	# Delete unwanted files
 	rm --force --recursive \
 		'dx' \
 		'hellfire' \
 		'tmp'
 
-	## Rename documentation files.
+	# Rename documentation files
 	mv 'license.txt' 'license.diablo-1.txt'
 	mv 'readme.txt' 'readme.diablo-1.txt'
 	mv 'README.txt' 'readme.devilutionx.txt'
@@ -164,6 +195,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
