@@ -9,9 +9,9 @@ set -o errexit
 # Faster Than Light
 ###
 
-script_version=20240711.1
+script_version=20241027.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='faster-than-light'
 GAME_NAME='FTL: Faster Than Light'
@@ -87,11 +87,9 @@ exe_icon.bmp
 ftl.dat'
 CONTENT_DOC_DATA_FILES='
 licenses'
-CONTENT_DOC0_DATA_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/.."
-CONTENT_DOC0_DATA_PATH_HUMBLE_2="${CONTENT_PATH_DEFAULT_HUMBLE_2}/.."
+CONTENT_DOC0_DATA_RELATIVE_PATH='..'
 CONTENT_DOC0_DATA_FILES='
-*.html 
-*.txt'
+FTL_README.html'
 
 APP_MAIN_EXE_BIN64='FTL.amd64'
 APP_MAIN_EXE_BIN32='FTL.x86'
@@ -151,8 +149,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -174,6 +177,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
