@@ -7,9 +7,9 @@ set -o errexit
 # Freelancer
 ###
 
-script_version=20240503.1
+script_version=20241124.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='freelancer'
 GAME_NAME='Freelancer'
@@ -25,7 +25,7 @@ ARCHIVE_BASE_DEMO_EN_0_SIZE='450000'
 ARCHIVE_BASE_DEMO_EN_0_URL='https://archive.org/details/freelancer_demo'
 
 CONTENT_PATH_DEFAULT='.'
-CONTENT_GAME_BIN_PATH="${CONTENT_PATH_DEFAULT}/game"
+CONTENT_GAME_BIN_RELATIVE_PATH='game'
 CONTENT_GAME_BIN_FILES='
 exe/freelancer.exe'
 CONTENT_GAME0_BIN_PATH='cab1'
@@ -120,28 +120,29 @@ PKG_BIN
 PKG_L10N
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
+PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
+deinterlace
+video/x-ms-asf'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_L10N_ID="${GAME_ID}-l10n"
-PKG_L10N_ID_DEMO="${GAME_ID_DEMO}-l10n"
+PKG_L10N_BASE_ID="${GAME_ID}-l10n"
+PKG_L10N_BASE_ID_DEMO="${GAME_ID_DEMO}-l10n"
+PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
+PKG_L10N_ID_DEMO_EN="${PKG_L10N_BASE_ID_DEMO}-en"
 PKG_L10N_PROVIDES="
-$PKG_L10N_ID"
+$PKG_L10N_BASE_ID"
 PKG_L10N_PROVIDES_DEMO="
-$PKG_L10N_ID_DEMO"
-PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
-PKG_L10N_ID_DEMO_EN="${PKG_L10N_ID_DEMO}-en"
+$PKG_L10N_BASE_ID_DEMO"
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_DEMO_EN='English localization'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
-PKG_BIN_DEPS_DEMO="$PKG_L10N_ID_DEMO $PKG_DATA_ID_DEMO"
-PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
-deinterlace
-video/x-ms-asf'
-
 ## TODO: Prevent the game from messing up with the desktop gamma values.
 
 # Load common functions
@@ -167,8 +168,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -201,6 +207,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
