@@ -4,12 +4,12 @@
 set -o errexit
 
 ###
-# Goblins 5
+# Gobliiins 5: L'invasion des Morglotons
 ###
 
-script_version=20240730.1
+script_version=20250103.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='goblins-5'
 GAME_ID_PART1="${GAME_ID}-part-1"
@@ -35,26 +35,22 @@ ARCHIVE_BASE_DEMO_0_VERSION='1.0-itch.2023.11.17'
 ARCHIVE_BASE_DEMO_0_URL='https://pierre-gilhodes.itch.io/gobliiins5'
 
 CONTENT_PATH_DEFAULT='.'
-CONTENT_GAME_PART1_FILES='
-Gobliiins5-Part1.ags
-audio.vox
+CONTENT_GAME_COMMON_FILES='
+acsetup.cfg
 English.tra
-acsetup.cfg'
-CONTENT_GAME_PART2_FILES='
-Gobliiins5-Part2.ags
-audio.vox
-English.tra
-acsetup.cfg'
-CONTENT_GAME_PART3_FILES='
-Gobliiins5-Part3.ags
-audio.vox
-English.tra
-acsetup.cfg'
-CONTENT_GAME_PART4_FILES='
-Gobliiins5-Part4.ags
-audio.vox
-English.tra
-acsetup.cfg'
+audio.vox'
+CONTENT_GAME_PART1_FILES="
+$CONTENT_GAME_COMMON_FILES
+Gobliiins5-Part1.ags"
+CONTENT_GAME_PART2_FILES="
+$CONTENT_GAME_COMMON_FILES
+Gobliiins5-Part2.ags"
+CONTENT_GAME_PART3_FILES="
+$CONTENT_GAME_COMMON_FILES
+Gobliiins5-Part3.ags"
+CONTENT_GAME_PART4_FILES="
+$CONTENT_GAME_COMMON_FILES
+Gobliiins5-Part4.ags"
 
 APP_MAIN_SCUMMID_PART1='ags:gobliiins5-1'
 APP_MAIN_SCUMMID_PART2='ags:gobliiins5-2'
@@ -96,14 +92,18 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract and include data
 
 archive_extraction_default
 
 ## Each game part is handled one at a time to prevent unwanted file overwrites.
-
 case "$(current_archive)" in
 	('ARCHIVE_BASE_DEMO_'*)
 		## The game demo only includes the first part of the game.
@@ -114,7 +114,7 @@ case "$(current_archive)" in
 		)"
 	;;
 	(*)
-		## Allow the content inclusion message to be shown multiple times.
+		## Allow the content inclusion message to be shown multiple times
 		information_content_inclusion() {
 			local messages_language message
 			messages_language=$(messages_language)
@@ -136,6 +136,7 @@ case "$(current_archive)" in
 			set_current_package 'PKG_PART1'
 			path_game_data
 		)"
+		rm "$ARCHIVE_PART1_PATH"
 		
 		ARCHIVE_PART2_PATH="${PLAYIT_WORKDIR}/gamedata/Gobliiins5-Part2.zip"
 		archive_extraction 'ARCHIVE_PART2'
@@ -144,6 +145,7 @@ case "$(current_archive)" in
 			set_current_package 'PKG_PART2'
 			path_game_data
 		)"
+		rm "$ARCHIVE_PART2_PATH"
 		
 		ARCHIVE_PART3_PATH="${PLAYIT_WORKDIR}/gamedata/Gobliiins5-Part3.zip"
 		archive_extraction 'ARCHIVE_PART3'
@@ -152,6 +154,7 @@ case "$(current_archive)" in
 			set_current_package 'PKG_PART3'
 			path_game_data
 		)"
+		rm "$ARCHIVE_PART3_PATH"
 		
 		ARCHIVE_PART4_PATH="${PLAYIT_WORKDIR}/gamedata/Gobliiins5-Part4.zip"
 		archive_extraction 'ARCHIVE_PART4'
@@ -160,9 +163,9 @@ case "$(current_archive)" in
 			set_current_package 'PKG_PART4'
 			path_game_data
 		)"
+		rm "$ARCHIVE_PART4_PATH"
 	;;
 esac
-
 rm --force --recursive "${PLAYIT_WORKDIR}/gamedata"
 
 # Write launchers
@@ -189,6 +192,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
