@@ -11,9 +11,9 @@ set -o errexit
 # - Goblins 3
 ###
 
-script_version=20240605.2
+script_version=20241123.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID_GOB1='goblins-1'
 GAME_NAME_GOB1='Gobliiins'
@@ -64,7 +64,7 @@ ARCHIVE_BASE_GOB3_FR_0_URL='https://www.gog.com/game/gobliiins_pack'
 CONTENT_PATH_DEFAULT='.'
 CONTENT_GAME_L10N_FILES_GOB3='
 ??gob3.itk'
-CONTENT_GAME_FLOPPY_PATH="${CONTENT_PATH_DEFAULT}/fdd"
+CONTENT_GAME_FLOPPY_RELATIVE_PATH='fdd'
 CONTENT_GAME_FLOPPY_FILES='
 *.stk'
 CONTENT_GAME_CDROM_FILES='
@@ -186,8 +186,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -206,10 +211,10 @@ case "$(current_archive)" in
 	('ARCHIVE_BASE_GOB3_'*)
 		game_exec_line() {
 			cat <<- 'EOF'
-			if [ -e "${PATH_GAME}/frgob3.itk" ]; then
-			    scummvm --language=fr --path="$PATH_GAME" "$@" "$SCUMMVM_ID"
-			elif [ -e "${PATH_GAME}/usgob3.itk" ]; then
-			    scummvm --language=us --path="$PATH_GAME" "$@" "$SCUMMVM_ID"
+			if [ -e "${PATH_GAME_DATA}/frgob3.itk" ]; then
+			    scummvm --language=fr --path="$PATH_GAME_DATA" "$@" "$SCUMMVM_ID"
+			elif [ -e "${PATH_GAME_DATA}/usgob3.itk" ]; then
+			    scummvm --language=us --path="$PATH_GAME_DATA" "$@" "$SCUMMVM_ID"
 			fi
 			EOF
 		}
@@ -220,14 +225,7 @@ launchers_generation 'PKG_CDROM'
 # Build packages
 
 packages_generation
-packages_list_floppy='PKG_FLOPPY PKG_COMMON'
-packages_list_cdrom='PKG_CDROM PKG_COMMON'
-case "$(current_archive)" in
-	('ARCHIVE_BASE_GOB3_'*)
-		packages_list_cdrom="$packages_list_cdrom PKG_L10N"
-	;;
-esac
-case "${LANG%_*}" in
+case "$(messages_language)" in
 	('fr')
 		version_string='version %s :'
 		version_floppy='disquette'
@@ -241,12 +239,19 @@ case "${LANG%_*}" in
 esac
 printf '\n'
 printf "$version_string" "$version_floppy"
-print_instructions $packages_list_floppy
+print_instructions 'PKG_FLOPPY' 'PKG_COMMON'
 printf "$version_string" "$version_cdrom"
-print_instructions $packages_list_cdrom
+case "$(current_archive)" in
+	('ARCHIVE_BASE_GOB3_'*)
+		print_instructions 'PKG_CDROM' 'PKG_L10N' 'PKG_COMMON'
+	;;
+	(*)
+		print_instructions 'PKG_CDROM' 'PKG_COMMON'
+	;;
+esac
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
