@@ -9,9 +9,9 @@ set -o errexit
 # - Forgotten Gods
 ###
 
-script_version=20240628.1
+script_version=20250211.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='grim-dawn'
 GAME_NAME='Grim Dawn'
@@ -26,6 +26,31 @@ EXPANSION_NAME_GODS='Forgotten Gods'
 
 ## Ashes of Malmouth
 
+ARCHIVE_BASE_ASHES_9_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.1.5a_(79771).exe'
+ARCHIVE_BASE_ASHES_9_MD5='978c79a533de6d7553044534d6085bdc'
+ARCHIVE_BASE_ASHES_9_TYPE='innosetup'
+ARCHIVE_BASE_ASHES_9_PART1_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.1.5a_(79771)-1.bin'
+ARCHIVE_BASE_ASHES_9_PART1_MD5='d4f7ef400d31a460d0c671b6d0fdd9fe'
+ARCHIVE_BASE_ASHES_9_SIZE='2511022'
+ARCHIVE_BASE_ASHES_9_VERSION='1.2.1.5a-gog79771'
+ARCHIVE_BASE_ASHES_9_URL='https://www.gog.com/game/grim_dawn_ashes_of_malmouth'
+
+ARCHIVE_BASE_ASHES_8_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.1.4_hotfix_1_(78646).exe'
+ARCHIVE_BASE_ASHES_8_MD5='e4b981d5a960f465fedd6c25e47434a5'
+ARCHIVE_BASE_ASHES_8_TYPE='innosetup'
+ARCHIVE_BASE_ASHES_8_PART1_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.1.4_hotfix_1_(78646)-1.bin'
+ARCHIVE_BASE_ASHES_8_PART1_MD5='8f0261ab3eabece7ef4a6667964ba1d0'
+ARCHIVE_BASE_ASHES_8_SIZE='2510794'
+ARCHIVE_BASE_ASHES_8_VERSION='1.2.1.4-gog78646'
+
+ARCHIVE_BASE_ASHES_7_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.1.2_(74537).exe'
+ARCHIVE_BASE_ASHES_7_MD5='24e439773a3b6935e766110b0ec80fff'
+ARCHIVE_BASE_ASHES_7_TYPE='innosetup'
+ARCHIVE_BASE_ASHES_7_PART1_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.1.2_(74537)-1.bin'
+ARCHIVE_BASE_ASHES_7_PART1_MD5='164321d7ecee354a62dc77b57a9088a0'
+ARCHIVE_BASE_ASHES_7_SIZE='2510434'
+ARCHIVE_BASE_ASHES_7_VERSION='1.2.1.2-gog74537'
+
 ARCHIVE_BASE_ASHES_6_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.1.1_(74365).exe'
 ARCHIVE_BASE_ASHES_6_MD5='01617f6a1fae6a2d8cd68061a4b7ed71'
 ARCHIVE_BASE_ASHES_6_TYPE='innosetup'
@@ -33,7 +58,6 @@ ARCHIVE_BASE_ASHES_6_PART1_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.1.1_(74
 ARCHIVE_BASE_ASHES_6_PART1_MD5='d687516b6ab638161aa0f8bd47416b66'
 ARCHIVE_BASE_ASHES_6_SIZE='2508370'
 ARCHIVE_BASE_ASHES_6_VERSION='1.2.1.1-gog74365'
-ARCHIVE_BASE_ASHES_6_URL='https://www.gog.com/game/grim_dawn_ashes_of_malmouth'
 
 ARCHIVE_BASE_ASHES_5_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.0.5a_(71558).exe'
 ARCHIVE_BASE_ASHES_5_MD5='459923324f4f32779885fe03f192fe3a'
@@ -85,6 +109,31 @@ ARCHIVE_BASE_ASHES_0_VERSION='1.1.9.8-gog65199'
 
 ## Forgotten Gods
 
+ARCHIVE_BASE_GODS_9_NAME='setup_grim_dawn_-_forgotten_gods_1.2.1.5a_(79771).exe'
+ARCHIVE_BASE_GODS_9_MD5='e8850233a15d8e898c53e393f6de3226'
+ARCHIVE_BASE_GODS_9_TYPE='innosetup'
+ARCHIVE_BASE_GODS_9_PART1_NAME='setup_grim_dawn_-_forgotten_gods_1.2.1.5a_(79771)-1.bin'
+ARCHIVE_BASE_GODS_9_PART1_MD5='6f5c139cd8416882627d1536e83c1ac8'
+ARCHIVE_BASE_GODS_9_SIZE='3223745'
+ARCHIVE_BASE_GODS_9_VERSION='1.2.1.5a-gog79771'
+ARCHIVE_BASE_GODS_9_URL='https://www.gog.com/game/grim_dawn_forgotten_gods'
+
+ARCHIVE_BASE_GODS_8_NAME='setup_grim_dawn_-_forgotten_gods_1.2.1.4_hotfix_1_(78646).exe'
+ARCHIVE_BASE_GODS_8_MD5='e1718e47e7e3efb5b7e30720237d7ca0'
+ARCHIVE_BASE_GODS_8_TYPE='innosetup'
+ARCHIVE_BASE_GODS_8_PART1_NAME='setup_grim_dawn_-_forgotten_gods_1.2.1.4_hotfix_1_(78646)-1.bin'
+ARCHIVE_BASE_GODS_8_PART1_MD5='e2d2f437f6cabf93953d280443a37fed'
+ARCHIVE_BASE_GODS_8_SIZE='3222704'
+ARCHIVE_BASE_GODS_8_VERSION='1.2.1.4-gog78646'
+
+ARCHIVE_BASE_GODS_7_NAME='setup_grim_dawn_-_forgotten_gods_1.2.1.2_(74537).exe'
+ARCHIVE_BASE_GODS_7_MD5='2d71e98f2aafdd7096b7f1b30279a7d5'
+ARCHIVE_BASE_GODS_7_TYPE='innosetup'
+ARCHIVE_BASE_GODS_7_PART1_NAME='setup_grim_dawn_-_forgotten_gods_1.2.1.2_(74537)-1.bin'
+ARCHIVE_BASE_GODS_7_PART1_MD5='430063cc53a07cd77ac491bb22c85e3b'
+ARCHIVE_BASE_GODS_7_SIZE='3220867'
+ARCHIVE_BASE_GODS_7_VERSION='1.2.1.2-gog74537'
+
 ARCHIVE_BASE_GODS_6_NAME='setup_grim_dawn_-_forgotten_gods_1.2.1.1_(74365).exe'
 ARCHIVE_BASE_GODS_6_MD5='45e52392fb4f503b2078ddf6af6a3411'
 ARCHIVE_BASE_GODS_6_TYPE='innosetup'
@@ -92,7 +141,6 @@ ARCHIVE_BASE_GODS_6_PART1_NAME='setup_grim_dawn_-_forgotten_gods_1.2.1.1_(74365)
 ARCHIVE_BASE_GODS_6_PART1_MD5='195f5f735715d9ae59080774d0a98bd0'
 ARCHIVE_BASE_GODS_6_SIZE='3221131'
 ARCHIVE_BASE_GODS_6_VERSION='1.2.1.1-gog74365'
-ARCHIVE_BASE_GODS_6_URL='https://www.gog.com/game/grim_dawn_forgotten_gods'
 
 ARCHIVE_BASE_GODS_5_NAME='setup_grim_dawn_-_forgotten_gods_1.2.0.5a_(71558).exe'
 ARCHIVE_BASE_GODS_5_MD5='f4e80fca2102e244a47a218171c0f336'
@@ -148,8 +196,14 @@ CONTENT_GAME_MAIN_FILES='
 gdx?
 survivalmode?'
 
-PKG_MAIN_DEPS="$GAME_ID"
-PKG_MAIN_DEPS_GODS="${PKG_MAIN_DEPS:-} ${GAME_ID}-${EXPANSION_ID_ASHES}"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_ASH_ID="${GAME_ID}-${EXPANSION_ID_ASHES}"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
+PKG_MAIN_DEPENDENCIES_SIBLINGS_GODS="$PKG_MAIN_DEPENDENCIES_SIBLINGS
+PKG_ASH"
 
 # Load common functions
 
@@ -174,8 +228,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -191,6 +250,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
