@@ -8,9 +8,9 @@ set -o errexit
 # Human Resource Machine
 ###
 
-script_version=20240528.1
+script_version=20241027.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='human-resource-machine'
 GAME_NAME='Human Resource Machine'
@@ -34,18 +34,18 @@ ARCHIVE_BASE_GOG_0_VERSION='1.0.8262-gog2.0.0.2'
 
 CONTENT_PATH_DEFAULT_HUMBLE='data'
 CONTENT_PATH_DEFAULT_GOG='data/noarch/game'
-CONTENT_GAME_BIN64_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/x86_64"
+CONTENT_GAME_BIN64_RELATIVE_PATH_HUMBLE='x86_64'
 CONTENT_GAME_BIN64_FILES='
 HumanResourceMachine.bin.x86_64'
-CONTENT_GAME_BIN32_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/x86"
+CONTENT_GAME_BIN32_RELATIVE_PATH_HUMBLE='x86'
 CONTENT_GAME_BIN32_FILES='
 HumanResourceMachine.bin.x86'
-CONTENT_GAME_DATA_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/noarch"
+CONTENT_GAME_DATA_RELATIVE_PATH_HUMBLE='noarch'
 CONTENT_GAME_DATA_FILES='
 shaders
 resource.pak
 icon.png'
-CONTENT_DOC_DATA_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/noarch"
+CONTENT_DOC_DATA_RELATIVE_PATH_HUMBLE='noarch'
 CONTENT_DOC_DATA_FILES='
 LICENSE.txt
 README.linux'
@@ -60,14 +60,12 @@ PKG_BIN64
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libgcc_s.so.1
@@ -81,6 +79,9 @@ libz.so.1'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -104,8 +105,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -127,6 +133,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
