@@ -8,9 +8,9 @@ set -o errexit
 # Into the Breach
 ###
 
-script_version=20240504.2
+script_version=20241027.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='into-the-breach'
 GAME_NAME='Into the Breach'
@@ -69,10 +69,7 @@ CONTENT_PATH_DEFAULT_HUMBLE='.'
 CONTENT_PATH_DEFAULT_HUMBLE_1='Into the Breach'
 CONTENT_PATH_DEFAULT_HUMBLE_0='Into the Breach Linux'
 CONTENT_PATH_DEFAULT_GOG='data/noarch/game'
-CONTENT_LIBS_BIN_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/linux_x64"
-CONTENT_LIBS_BIN_PATH_HUMBLE_1="${CONTENT_PATH_DEFAULT_HUMBLE_1}/linux_x64"
-CONTENT_LIBS_BIN_PATH_HUMBLE_0="${CONTENT_PATH_DEFAULT_HUMBLE_0}/linux_x64"
-CONTENT_LIBS_BIN_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/linux_x64"
+CONTENT_LIBS_BIN_RELATIVE_PATH='linux_x64'
 ## Using the system-provided libSDL2-2.0.so.0 instead of the shipped one triggers a segfault on a Debian Trixie/Sid.
 CONTENT_LIBS_BIN_FILES='
 libfmod.so.10
@@ -100,11 +97,9 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -115,6 +110,9 @@ libpthread.so.0
 librt.so.1
 libstdc++.so.6'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -138,8 +136,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -160,6 +163,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
