@@ -10,9 +10,9 @@ set -o errexit
 # - Monkey Island 2
 ###
 
-script_version=20240531.1
+script_version=20241121.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID_MONKEY1='monkey-island-1-special-edition'
 GAME_NAME_MONKEY1='Monkey Island 1 Special Edition: The Secret of Monkey Island'
@@ -24,14 +24,20 @@ GAME_NAME_MONKEY2='Monkey Island 2 Special Edition: LeChuckʼs Revenge'
 
 ## Monkey Island 1
 
+ARCHIVE_BASE_MONKEY1_1_NAME='setup_the_secret_of_monkey_islandtm_special_edition_1.0_(18587).exe'
+ARCHIVE_BASE_MONKEY1_1_MD5='dc463e4d640e417df53684afb9921dd1'
+ARCHIVE_BASE_MONKEY1_1_TYPE='innosetup'
+ARCHIVE_BASE_MONKEY1_1_SIZE='2594611'
+ARCHIVE_BASE_MONKEY1_1_VERSION='1.0-gog18587'
+ARCHIVE_BASE_MONKEY1_1_URL='https://www.gog.com/game/the_secret_of_monkey_island_special_edition'
+
 ARCHIVE_BASE_MONKEY1_0_NAME='setup_monkey_island_1_se_1.0_(18587).exe'
-ARCHIVE_BASE_MONKEY1_0_TYPE='innosetup'
 ARCHIVE_BASE_MONKEY1_0_MD5='ff2eaa21af8f59371583b007b439b873'
+ARCHIVE_BASE_MONKEY1_0_TYPE='innosetup'
 ARCHIVE_BASE_MONKEY1_0_PART1_NAME='setup_monkey_island_1_se_1.0_(18587)-1.bin'
 ARCHIVE_BASE_MONKEY1_0_PART1_MD5='6a3ca78328b99ae0d9d0a3d7a4fb3cd9'
 ARCHIVE_BASE_MONKEY1_0_SIZE='2600000'
 ARCHIVE_BASE_MONKEY1_0_VERSION='1.0-gog18587'
-ARCHIVE_BASE_MONKEY1_0_URL='https://www.gog.com/game/the_secret_of_monkey_island_special_edition'
 
 ## Monkey Island 2
 
@@ -44,10 +50,10 @@ ARCHIVE_BASE_MONKEY2_0_URL='https://www.gog.com/game/monkey_island_2_special_edi
 
 # Archive contents
 
-CONTENT_PATH_DEFAULT='app'
-
 ## Monkey Island 1
 
+CONTENT_PATH_DEFAULT_MONKEY1='.'
+CONTENT_PATH_DEFAULT_MONKEY1_0='app'
 CONTENT_GAME_BIN_FILES_MONKEY1='
 mise.exe'
 CONTENT_GAME_DATA_FILES_MONKEY1='
@@ -59,6 +65,7 @@ CONTENT_DOC_DATA_FILES_MONKEY1='
 
 ## Monkey Island 2
 
+CONTENT_PATH_DEFAULT_MONKEY2='app'
 CONTENT_GAME_BIN_FILES_MONKEY2='
 monkey2.exe
 lang.ini'
@@ -79,6 +86,7 @@ users/${USER}/AppData/Roaming/LucasArts/Monkey Island 2 Special Edition'
 ## 0024:err:d3dcompiler:D3DCompile2 Shader log:
 ## 0024:err:d3dcompiler:D3DCompile2     <anonymous>:7:1: E5000: syntax error, unexpected KW_SAMPLER_STATE
 ## 0024:err:d3dcompiler:D3DCompile2
+## TODO: Check if it is still required with current WINE
 WINE_WINETRICKS_VERBS='d3dcompiler_47'
 
 APP_MAIN_EXE_MONKEY1='mise.exe'
@@ -88,17 +96,17 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID_MONKEY1="${GAME_ID_MONKEY1}-data"
-PKG_DATA_ID_MONKEY2="${GAME_ID_MONKEY2}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS_MONKEY1="$PKG_DATA_ID_MONKEY1"
-PKG_BIN_DEPS_MONKEY2="$PKG_DATA_ID_MONKEY2"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
 audioconvert
 audio/x-wma, wmaversion=(int)1'
 
+PKG_DATA_ID_MONKEY1="${GAME_ID_MONKEY1}-data"
+PKG_DATA_ID_MONKEY2="${GAME_ID_MONKEY2}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -122,8 +130,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -144,6 +157,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
