@@ -7,9 +7,9 @@ set -o errexit
 # Off-World Resource Base
 ###
 
-script_version=20240720.1
+script_version=20241229.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='off-world-resource-base'
 GAME_NAME='O.R.B.: Off-World Resource Base'
@@ -53,7 +53,8 @@ readme.txt
 scen_eula.txt
 *.pdf'
 
-## The intro video and game menu fail to render unless a virtual desktop is used (WINE 9.0).
+## The intro video and game menu fail to render
+## unless a virtual desktop is used (WINE 9.0).
 WINE_VIRTUAL_DESKTOP='auto'
 
 APP_MAIN_EXE='orb.exe'
@@ -109,8 +110,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -131,6 +137,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
