@@ -7,9 +7,9 @@ set -o errexit
 # Pandora: First Contact
 ###
 
-script_version=20240504.2
+script_version=20250104.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='pandora-first-contact'
 GAME_NAME='Pandora: First Contact'
@@ -29,7 +29,7 @@ CONTENT_ICONS_FILES='
 256x256'
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
-CONTENT_LIBS_BIN_PATH="${CONTENT_PATH_DEFAULT}/Binaries"
+CONTENT_LIBS_BIN_RELATIVE_PATH='Binaries'
 CONTENT_LIBS_BIN_FILES='
 libavcodec.so.53
 libavformat.so.53
@@ -49,7 +49,7 @@ Binaries/Pandora.bin
 Binaries/PandoraServer.bin'
 CONTENT_GAME_DATA_FILES='
 Data'
-CONTENT_DOC_DATA_PATH="${CONTENT_PATH_DEFAULT}/Documents"
+CONTENT_DOC_DATA_RELATIVE_PATH='Documents'
 CONTENT_DOC_DATA_FILES='
 Dutch
 English
@@ -61,21 +61,14 @@ PandoraWebsite.url'
 
 APP_MAIN_EXE='Binaries/Pandora.bin'
 APP_MAIN_ICON='../support/icon.png'
-## Run the game binary from its parent directory
-APP_MAIN_PRERUN='# Run the game binary from its parent directory
-cd "$(dirname "$APP_EXE")"
-APP_EXE=$(basename "$APP_EXE")
-'
 
 PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libbz2.so.1
 libc.so.6
@@ -97,6 +90,9 @@ libXrandr.so.2
 libXxf86vm.so.1
 libz.so.1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -120,15 +116,20 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	# Set the required execution permissions on the server binary.
+	# Set the required execution permissions on the server binary
 	chmod 755 'Binaries/PandoraServer.bin'
 )
 
@@ -139,6 +140,14 @@ content_inclusion_default
 
 # Write launchers
 
+## Run the game binary from its parent directory
+game_exec_line() {
+	cat <<- 'EOF'
+	cd Binaries
+	./Pandora.bin "$@"
+	EOF
+}
+
 launchers_generation 'PKG_BIN'
 
 # Build packages
@@ -148,6 +157,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
