@@ -7,9 +7,9 @@ set -o errexit
 # Prince of Persia: The Sands of Time
 ###
 
-script_version=20240529.1
+script_version=20241125.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='prince-of-persia-the-sands-of-time'
 GAME_NAME='Prince of Persia: The Sands of Time'
@@ -19,7 +19,7 @@ ARCHIVE_BASE_FR_0_MD5='b71ed96b13461f56c8a47e16fbecadbb'
 ARCHIVE_BASE_FR_0_TYPE='innosetup'
 ARCHIVE_BASE_FR_0_PART1_NAME='setup_prince_of_persia_-_the_sands_of_time_181_(french)_(28548)-1.bin'
 ARCHIVE_BASE_FR_0_PART1_MD5='691e5144e34bf71ab15d45de11089b34'
-ARCHIVE_BASE_FR_0_SIZE='1500000'
+ARCHIVE_BASE_FR_0_SIZE='1408358'
 ARCHIVE_BASE_FR_0_VERSION='1.00.181-gog28548'
 ARCHIVE_BASE_FR_0_URL='https://www.gog.com/game/prince_of_persia_the_sands_of_time'
 
@@ -28,16 +28,24 @@ ARCHIVE_BASE_EN_0_MD5='008b4359cafb21dd4e437860dc23e2cf'
 ARCHIVE_BASE_EN_0_TYPE='innosetup'
 ARCHIVE_BASE_EN_0_PART1_NAME='setup_prince_of_persia_-_the_sands_of_time_181_(28548)-1.bin'
 ARCHIVE_BASE_EN_0_PART1_MD5='639fd428677dc8fb52e864422cbfe26d'
-ARCHIVE_BASE_EN_0_SIZE='1500000'
+ARCHIVE_BASE_EN_0_SIZE='1413339'
 ARCHIVE_BASE_EN_0_VERSION='1.00.181-gog28548'
 ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/prince_of_persia_the_sands_of_time'
 
 CONTENT_PATH_DEFAULT='.'
-## TODO: An explicit list of .dll files should be set.
 CONTENT_GAME_BIN_FILES='
-*.dll
-*.exe
-*.tst'
+binkw32.dll
+detectionapi.dll
+directx8tests.dll
+directx9tests.dll
+eax.dll
+mfc71.dll
+msvcp71.dll
+msvcr71.dll
+pop.exe
+princeofpersia.exe
+directxtests.tst
+systemtests.tst'
 CONTENT_GAME0_BIN_PATH='__support/app'
 ## "Hardware.ini" instead of "hardware.ini" is not a typo.
 CONTENT_GAME0_BIN_FILES='
@@ -66,8 +74,9 @@ USER_PERSISTENT_DIRECTORIES='
 profiles'
 
 APP_MAIN_EXE='princeofpersia.exe'
-## Work around fog rendering issues.
-APP_MAIN_PRERUN='# Work around fog rendering issues
+## Work around fog rendering problems
+APP_MAIN_PRERUN='
+# Work around fog rendering problems
 config_file="Hardware.ini"
 dos2unix --quiet "$config_file"
 sed \
@@ -76,10 +85,11 @@ sed \
 	"$config_file"
 unix2dos --quiet "$config_file"
 '
-## Work around override of configuration file.
-APP_MAIN_POSTRUN='# Work around override of configuration file
+## Work around an override of configuration file
+APP_MAIN_POSTRUN='
+# Work around an override of configuration file
 config_file="Hardware.ini"
-config_file_persistent="${USER_PERSISTENT_PATH}/${config_file}"
+config_file_persistent="${PATH_PERSISTENT}/${config_file}"
 if \
 	[ -f "$config_file" ] \
 	&& [ ! -h "$config_file" ]
@@ -91,15 +101,26 @@ fi
 '
 
 PACKAGES_LIST='
-PKG_L10N
 PKG_BIN
+PKG_L10N
 PKG_DATA'
 
-PKG_L10N_ID="${GAME_ID}-l10n"
-PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
-PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
+## Work around fog rendering problems
+PKG_BIN_DEPENDENCIES_COMMANDS="${PKG_BIN_DEPENDENCIES_COMMANDS:-}
+dos2unix"
+## Ensure a smooth upgrade from packages generated with pre-20231018.1 scripts.
+PKG_BIN_PROVIDES="${PKG_BIN_PROVIDES:-}
+prince-of-persia"
+
+PKG_L10N_BASE_ID="${GAME_ID}-l10n"
+PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
+PKG_L10N_ID_FR="${PKG_L10N_BASE_ID}-fr"
 PKG_L10N_PROVIDES="
-$PKG_L10N_ID"
+$PKG_L10N_BASE_ID"
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 ## Ensure a smooth upgrade from packages generated with pre-20231018.1 scripts.
@@ -112,15 +133,6 @@ PKG_DATA_DESCRIPTION='data'
 PKG_DATA_PROVIDES="${PKG_DATA_PROVIDES:-}
 prince-of-persia-data"
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
-## Work around fog rendering issues.
-PKG_BIN_DEPENDENCIES_COMMANDS="${PKG_BIN_DEPENDENCIES_COMMANDS:-}
-dos2unix"
-## Ensure a smooth upgrade from packages generated with pre-20231018.1 scripts.
-PKG_BIN_PROVIDES="${PKG_BIN_PROVIDES:-}
-prince-of-persia"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -144,26 +156,20 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
-
-	## Avoid inclusion of unwanted files.
-	rm --force --recursive \
-		'__redist' \
-		'__support/6800' \
-		'__support/nvidia' \
-		'commonappdata' \
-		'tmp'
-)
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path 'GAME0_BIN')"
 
-	## Work around case issues caused by file deletion-creation instead of in-place edition.
+	# Work around case-related problems caused by file deletion-creation instead of in-place edition
 	mv 'hardware.ini' 'Hardware.ini'
 )
 
@@ -183,6 +189,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
