@@ -8,9 +8,9 @@ set -o errexit
 # Raji: An Ancient Epic
 ###
 
-script_version=20240606.1
+script_version=20241226.3
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='raji-an-ancient-epic'
 GAME_NAME='Raji: An Ancient Epic'
@@ -62,13 +62,16 @@ CONTENT_ICONS_FILES='
 
 
 UNREALENGINE4_NAME='raji'
+UNREALENGINE4_NAME_DEMO='Raji'
 
 CONTENT_PATH_DEFAULT='.'
 CONTENT_PATH_DEFAULT_DEMO='Raji Demo v11'
 
 APP_MAIN_EXE="${UNREALENGINE4_NAME}.exe"
+APP_MAIN_EXE_DEMO="${UNREALENGINE4_NAME_DEMO}.exe"
 ## The rendering is done using Direct3D 12 by default starting with game version 1.6.0.
 ## We force Direct3D 11 instead as it is better supported by current WINE builds.
+## TODO: Check if it is still required with current WINE builds
 APP_MAIN_OPTIONS='-d3d11'
 
 PACKAGES_LIST='
@@ -106,23 +109,23 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
-
-	## Convert all file paths to lowercase.
-	tolower .
-)
 
 # Include game data
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
-## Convert icon file name for the game demo.
+## Convert icon file name for the game demo,
+## if it has been provided by the optional icons archive
 case "$(current_archive)" in
 	('ARCHIVE_BASE_DEMO_'*)
 		icon_source="$(package_path 'PKG_DATA')$(path_icons)/256x256/apps/${GAME_ID}.png"
@@ -144,6 +147,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
