@@ -7,9 +7,9 @@ set -o errexit
 # Rayman Origins
 ###
 
-script_version=20240620.1
+script_version=20241027.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='rayman-origins'
 GAME_NAME='Rayman Origins'
@@ -37,7 +37,8 @@ CONTENT_GAME_BIN_FILES='
 *.ini'
 CONTENT_GAME_DATA_FILES='
 gamedata'
-CONTENT_DOC_DATA_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/support"
+## These documentation files are not provided by the Humble Bundle archive
+CONTENT_DOC_DATA_RELATIVE_PATH_GOG='support'
 CONTENT_DOC_DATA_FILES_GOG='
 *.pdf
 *.txt'
@@ -63,15 +64,20 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-
 # Set extra tools required to extract data from the Humble Bundle archive
 
-SCRIPT_DEPS_HUMBLE="${SCRIPT_DEPS:-} dd truncate unshield"
+## Warning: REQUIREMENTS_LIST has no support for contextual values as of ./play.it 2.31
+REQUIREMENTS_LIST_HUMBLE="${REQUIREMENTS_LIST:-}
+dd
+truncate
+unshield"
 
 # Load common functions
 
@@ -96,12 +102,17 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Check for the availability of the extra tools required to extract data from the Humble Bundle archive
 
-SCRIPT_DEPS=$(context_value 'SCRIPT_DEPS')
-check_deps
+REQUIREMENTS_LIST=$(context_value 'REQUIREMENTS_LIST')
+requirements_check
 
 # Extract game data
 
@@ -158,6 +169,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
