@@ -7,9 +7,9 @@ set -o errexit
 # Reus
 ###
 
-script_version=20240606.1
+script_version=20241027.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='reus'
 GAME_NAME='Reus'
@@ -68,15 +68,11 @@ CONTENT_LIBS_FILES='
 libFontNative.so
 libmojoshader.so
 libtheorafile.so'
-CONTENT_LIBS_LIBS64_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/lib64"
-CONTENT_LIBS_LIBS64_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/lib64"
-CONTENT_LIBS_LIBS64_PATH_HUMBLE_0="${CONTENT_PATH_DEFAULT_HUMBLE_0}/lib64"
+CONTENT_LIBS_LIBS64_RELATIVE_PATH='lib64'
 CONTENT_LIBS_LIBS64_FILES="$CONTENT_LIBS_FILES
 libfmodevent64-4.44.00.so
 libfmodex64-4.44.00.so"
-CONTENT_LIBS_LIBS32_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/lib"
-CONTENT_LIBS_LIBS32_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/lib"
-CONTENT_LIBS_LIBS32_PATH_HUMBLE_0="${CONTENT_PATH_DEFAULT_HUMBLE_0}/lib"
+CONTENT_LIBS_LIBS32_RELATIVE_PATH='lib'
 CONTENT_LIBS_LIBS32_FILES="$CONTENT_LIBS_FILES
 libfmodevent-4.44.00.so
 libfmodex-4.44.00.so"
@@ -89,6 +85,8 @@ PKG_MAIN
 PKG_LIBS64
 PKG_LIBS32'
 
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_LIBS'
 PKG_MAIN_DEPENDENCIES_LIBRARIES='
 libSDL2-2.0.so.0
 libSDL2_image-2.0.so.0'
@@ -129,7 +127,6 @@ libtheoradec.so.1
 libvorbis.so.0'
 PKG_LIBS64_DEPENDENCIES_LIBRARIES="$PKG_LIBS_DEPENDENCIES_LIBRARIES"
 PKG_LIBS32_DEPENDENCIES_LIBRARIES="$PKG_LIBS_DEPENDENCIES_LIBRARIES"
-PKG_MAIN_DEPS="${PKG_MAIN_DEPS:-} $PKG_LIBS_ID"
 
 # Load common functions
 
@@ -154,8 +151,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -176,6 +178,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
