@@ -7,9 +7,9 @@ set -o errexit
 # Shadow Gambit
 ###
 
-script_version=20240606.1
+script_version=20241023.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='shadow-gambit'
 GAME_NAME='Shadow Gambit: The Cursed Crew'
@@ -147,8 +147,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -160,6 +165,46 @@ content_inclusion_default
 
 # Write launchers
 
+## Store the game prefix into the WINE prefix, instead of using a symbolic link
+## This is required for the expansions to be correctly detected
+## The generated launchers will ignore $PLAYIT_PREFIX_PATH
+launcher_path_prefix() {
+	local game_id
+	game_id=$(game_id)
+	cat <<- EOF
+	## Set the path to the volatile game prefix
+	## This launcher ignores \$PLAYIT_PREFIX_PATH
+	path_prefix() {
+	    # Store the game prefix into the WINE prefix, instead of using a symbolic link
+	    # This is required for the expansions to be correctly detected
+	    printf '%s/drive_c/%s' \\
+	        "\$PATH_WINEPREFIX" \\
+	        '$(game_id)'
+	}
+	PATH_PREFIX=\$(path_prefix)
+
+	EOF
+}
+wine_wineprefix_init_actions() {
+	cat <<- 'EOF'
+	    ## Do not link the game prefix into the WINE prefix, as its real path is already there
+
+	    ## Remove most links pointing outside of the WINE prefix
+	    rm "$WINEPREFIX/dosdevices/z:"
+	    find "$WINEPREFIX/drive_c/users/$(whoami)" -type l | while read -r directory; do
+	        rm "$directory"
+	        mkdir "$directory"
+	    done
+	    unset directory
+
+	    ## Set symbolic links to the legacy paths
+	    wineprefix_legacy_link 'AppData/Roaming' 'Application Data'
+	    wineprefix_legacy_link 'AppData/Local' 'Local Settings/Application Data'
+	    wineprefix_legacy_link 'Documents' 'My Documents'
+
+	EOF
+}
+
 launchers_generation 'PKG_BIN'
 
 # Build packages
@@ -169,6 +214,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
