@@ -7,9 +7,9 @@ set -o errexit
 # Shogo: Mobile Armor Division
 ###
 
-script_version=20240721.1
+script_version=20241230.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='shogo-mobile-armor-division'
 GAME_NAME='Shogo: Mobile Armor Division'
@@ -78,7 +78,9 @@ save'
 USER_PERSISTENT_FILES='
 *.cfg'
 
-## Without a WINE virtual desktop, mouselook can lead to erratic camera behaviour.
+## Without a WINE virtual desktop,
+## mouselook can lead to erratic camera behaviour.
+## TODO: Check if it is still happening with current WINE builds
 WINE_VIRTUAL_DESKTOP='auto'
 
 APP_MAIN_EXE='shogo.exe'
@@ -130,8 +132,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -152,6 +159,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
