@@ -1,19 +1,55 @@
 #!/bin/sh
 # SPDX-License-Identifier: BSD-2-Clause
 # SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
+# SPDX-FileCopyrightText: © 2025 BetaRays
 set -o errexit
 
 ###
 # Slay the Princess
 ###
 
-script_version=20240515.2
+script_version=20250211.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='slay-the-princess'
 GAME_NAME='Slay the Princess'
 
+GAME_ID_DEMO="${GAME_ID}-demo"
+GAME_NAME_DEMO="$GAME_NAME (demo)"
+
+## The Pristine Cut
+
+ARCHIVE_BASE_16_NAME='slay_the_princess_the_pristine_cut_the_pristine_cut_linux_1_1a_79534.sh'
+ARCHIVE_BASE_16_MD5='4b7dfeb531a7431bbd2fe84e0fc2cfde'
+ARCHIVE_BASE_16_SIZE='12700851'
+ARCHIVE_BASE_16_VERSION='1.1a-gog79534'
+ARCHIVE_BASE_16_URL='https://www.gog.com/game/slay_the_princess'
+
+ARCHIVE_BASE_15_NAME='slay_the_princess_the_pristine_cut_the_pristine_cut_linux_1_0z_77466.sh'
+ARCHIVE_BASE_15_MD5='9492a8cffbf5ab5ac79593ceb763d072'
+ARCHIVE_BASE_15_SIZE='12706022'
+ARCHIVE_BASE_15_VERSION='1.0z-gog77466'
+ARCHIVE_BASE_15_URL='https://www.gog.com/game/slay_the_princess'
+
+ARCHIVE_BASE_14_NAME='slay_the_princess_the_pristine_cut_the_pristine_cut_linux_1_0p_77354.sh'
+ARCHIVE_BASE_14_MD5='9cde15f2957c37f7679d73f3fa8eed8c'
+ARCHIVE_BASE_14_SIZE='12689218'
+ARCHIVE_BASE_14_VERSION='1.0p-gog77354'
+
+ARCHIVE_BASE_13_NAME='slay_the_princess_the_pristine_cut_the_pristine_cut_linux_1_0l_77303.sh'
+ARCHIVE_BASE_13_MD5='23fb0cd438f5936479d56846c65be179'
+ARCHIVE_BASE_13_SIZE='12684306'
+ARCHIVE_BASE_13_VERSION='1.0l-gog77303'
+
+ARCHIVE_BASE_12_NAME='slay_the_princess_the_pristine_cut_linux_1_0_77121.sh'
+ARCHIVE_BASE_12_MD5='df352f8474c406976f9cd3d87d0b9e79'
+ARCHIVE_BASE_12_SIZE='12679961'
+ARCHIVE_BASE_12_VERSION='1.0-gog77121'
+ARCHIVE_BASE_12_URL='https://www.gog.com/game/slay_the_princess'
+
+## End of Everything update
+
 ARCHIVE_BASE_11_NAME='slay_the_princess_end_of_everything_update_1_2e_scrollbar_73222.sh'
 ARCHIVE_BASE_11_MD5='f1e7f54e99ceae8aa4c1314274708b1d'
 ARCHIVE_BASE_11_SIZE='8799577'
@@ -45,6 +81,8 @@ ARCHIVE_BASE_6_MD5='950c30b1f3496691ce2560cf3d55ed07'
 ARCHIVE_BASE_6_SIZE='8799446'
 ARCHIVE_BASE_6_VERSION='1.2-gog72260'
 
+## Original builds
+
 ARCHIVE_BASE_5_NAME='slay_the_princess_linux_1_1c_release_70031.sh'
 ARCHIVE_BASE_5_MD5='d2ab1e74725c1e28f2f3a8e74347b4ee'
 ARCHIVE_BASE_5_SIZE='8362317'
@@ -75,7 +113,16 @@ ARCHIVE_BASE_0_MD5='7acf7f8093cdddff8d484aa4043e5c51'
 ARCHIVE_BASE_0_SIZE='11014500'
 ARCHIVE_BASE_0_VERSION='1.0d-gog68521'
 
+## Free demo
+
+ARCHIVE_BASE_DEMO_0_NAME='SlaythePrincessDemo-1.0-market.zip'
+ARCHIVE_BASE_DEMO_0_MD5='135628b57b5e4debbaf21680d493cd74'
+ARCHIVE_BASE_DEMO_0_SIZE='2839604'
+ARCHIVE_BASE_DEMO_0_VERSION='1.0-itch'
+ARCHIVE_BASE_DEMO_0_URL='https://blacktabbygames.itch.io/slay-the-princess'
+
 CONTENT_PATH_DEFAULT='data/noarch/game/game'
+CONTENT_PATH_DEFAULT_DEMO='game'
 CONTENT_GAME_MAIN_FILES='
 audio
 cache
@@ -83,6 +130,9 @@ gui
 images
 staging
 script_version.txt'
+CONTENT_GAME0_MAIN_FILES_DEMO='
+tl
+archive.rpa'
 CONTENT_GAME_ARCHIVE_1_FILES='
 archive.rpa.split00'
 CONTENT_GAME_ARCHIVE_2_FILES='
@@ -92,12 +142,19 @@ CONTENT_GAME0_ARCHIVE_2_FILES='
 archive.rpa.split02'
 
 APP_MAIN_TYPE='renpy'
-APP_MAIN_ICON='../../support/icon.png'
+APP_MAIN_ICON='../SlaythePrincess.exe'
+APP_MAIN_ICON_DEMO='../SlaythePrincessDemo.exe'
 
 PACKAGES_LIST='
 PKG_MAIN
 PKG_ARCHIVE_1
 PKG_ARCHIVE_2'
+PACKAGES_LIST_DEMO='
+PKG_MAIN'
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_ARCHIVE_1
+PKG_ARCHIVE_2'
 
 PKG_ARCHIVE_ID="${GAME_ID}-archive"
 PKG_ARCHIVE_1_ID="${PKG_ARCHIVE_ID}-1"
@@ -105,9 +162,8 @@ PKG_ARCHIVE_2_ID="${PKG_ARCHIVE_ID}-2"
 PKG_ARCHIVE_DESCRIPTION='archive chunks'
 PKG_ARCHIVE_1_DESCRIPTION="$PKG_ARCHIVE_DESCRIPTION - 1"
 PKG_ARCHIVE_2_DESCRIPTION="$PKG_ARCHIVE_DESCRIPTION - 2"
-PKG_MAIN_DEPS="${PKG_MAIN_DEPS:-} $PKG_ARCHIVE_1 $PKG_ARCHIVE_2"
 
-## Ensure easy upgrades from packages generated with pre-20240427.1 game scripts.
+## Ensure easy upgrades from packages generated with pre-20240427.1 game scripts
 PKG_MAIN_PROVIDES="${PKG_MAIN_PROVIDES:-}
 slay-the-princess-data"
 PKG_ARCHIVE_1_PROVIDES="${PKG_ARCHIVE_1_PROVIDES:-}
@@ -138,14 +194,31 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
 
 # Include game data
 
+## Check for the presence of the original game icon, fall back on the GOG-specific one if required
+case "$(current_archive)" in
+	('ARCHIVE_BASE_DEMO_'*)
+		# The game demo is not provided by GOG.
+	;;
+	(*)
+		if [ ! -e "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/${APP_MAIN_ICON}" ]; then
+			APP_MAIN_ICON='../../support/icon.png'
+		fi
+	;;
+esac
+
 content_inclusion_icons 'PKG_MAIN'
 content_inclusion_default
 
@@ -155,18 +228,27 @@ launchers_generation 'PKG_MAIN'
 
 # Build packages
 
-## Rebuild the huge file from its chunks.
-huge_file='archive.rpa'
-PKG_MAIN_POSTINST_RUN="$(package_postinst_actions 'PKG_MAIN')
-$(huge_file_concatenate "$huge_file")"
-PKG_MAIN_PRERM_RUN="$(package_prerm_actions 'PKG_MAIN')
-$(huge_file_delete "$huge_file")"
+case "$(current_archive)" in
+	('ARCHIVE_BASE_DEMO_'*)
+		# Prevent some properties of the full game from applying to the demo
+		unset PKG_MAIN_DEPENDENCIES_SIBLINGS
+		unset PKG_MAIN_PROVIDES
+	;;
+	(*)
+		# Rebuild the huge file from its chunks
+		huge_file='archive.rpa'
+		PKG_MAIN_POSTINST_RUN="$(package_postinst_actions 'PKG_MAIN')
+		$(huge_file_concatenate "$huge_file")"
+		PKG_MAIN_PRERM_RUN="$(package_prerm_actions 'PKG_MAIN')
+		$(huge_file_delete "$huge_file")"
+	;;
+esac
 
 packages_generation
 print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
