@@ -7,9 +7,9 @@ set -o errexit
 # Song of Farca
 ###
 
-script_version=20240530.1
+script_version=20241124.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='song-of-farca'
 GAME_NAME='Song of Farca'
@@ -40,11 +40,9 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -55,6 +53,9 @@ librt.so.1
 libstdc++.so.6
 libz.so.1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -78,8 +79,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
  
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
  
 archive_extraction_default
@@ -100,6 +106,6 @@ print_instructions
  
 # Clean up
  
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
  
 exit 0
