@@ -7,9 +7,9 @@ set -o errexit
 # Star Wars: Galactic Battlegrounds
 ###
 
-script_version=20240720.1
+script_version=20241021.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='star-wars-galactic-battlegrounds'
 GAME_NAME='Star Wars: Galactic Battlegrounds'
@@ -112,7 +112,8 @@ registry_dump_nocd_content='Windows Registry Editor Version 5.00
 CONTENT_GAME_BIN_FILES="${CONTENT_GAME_BIN_FILES:-}
 $registry_dump_nocd_file"
 APP_REGEDIT="${APP_REGEDIT:-} $registry_dump_nocd_file"
-SCRIPT_DEPS="${SCRIPT_DEPS:-} iconv"
+REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
+iconv"
 
 # Load common functions
 
@@ -137,8 +138,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -167,6 +173,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
