@@ -10,9 +10,9 @@ set -o errexit
 # - Anniversary Portraits
 ###
 
-script_version=20240721.1
+script_version=20241215.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -30,26 +30,21 @@ EXPANSION_NAME_ANNIVERSARY='Anniversary Portraits'
 
 ## Arachnoid Portrait Pack
 
+ARCHIVE_BASE_ARACHNOID_63_NAME='stellaris_arachnoid_portrait_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_ARACHNOID_63_MD5='9da0b12f862958f4af43ae7612445adb'
+ARCHIVE_BASE_ARACHNOID_63_SIZE='817'
+ARCHIVE_BASE_ARACHNOID_63_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_ARACHNOID_63_URL='https://www.gog.com/game/stellaris_galaxy_edition_upgrade_pack'
+
+ARCHIVE_BASE_ARACHNOID_62_NAME='stellaris_arachnoid_portrait_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_ARACHNOID_62_MD5='6584255df86295e64f59c6e9c1b69503'
+ARCHIVE_BASE_ARACHNOID_62_SIZE='817'
+ARCHIVE_BASE_ARACHNOID_62_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_ARACHNOID_59_NAME='stellaris_arachnoid_portrait_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_ARACHNOID_59_MD5='f753906a3ff33592d853b6634d14cfb9'
 ARCHIVE_BASE_ARACHNOID_59_SIZE='817'
 ARCHIVE_BASE_ARACHNOID_59_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_ARACHNOID_59_URL='https://www.gog.com/game/stellaris_galaxy_edition_upgrade_pack'
-
-ARCHIVE_BASE_ARACHNOID_58_NAME='stellaris_arachnoid_portrait_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_ARACHNOID_58_MD5='fd81b7db983fa6b0f2c8cbb8cec095e3'
-ARCHIVE_BASE_ARACHNOID_58_SIZE='817'
-ARCHIVE_BASE_ARACHNOID_58_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_ARACHNOID_57_NAME='stellaris_arachnoid_portrait_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_ARACHNOID_57_MD5='d76c73867ffae85db339a58000eac498'
-ARCHIVE_BASE_ARACHNOID_57_SIZE='817'
-ARCHIVE_BASE_ARACHNOID_57_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_ARACHNOID_56_NAME='stellaris_arachnoid_portrait_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_ARACHNOID_56_MD5='691d2438e0f50a8674ee2ae2d0327ea9'
-ARCHIVE_BASE_ARACHNOID_56_SIZE='817'
-ARCHIVE_BASE_ARACHNOID_56_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_ARACHNOID_55_NAME='stellaris_arachnoid_portrait_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_ARACHNOID_55_MD5='5e073b99755aa71fa8b4063e53b4335c'
@@ -113,26 +108,21 @@ ARCHIVE_BASE_ARACHNOID_22_VERSION='3.0.3-gog47193'
 
 ## Horizon Signal
 
+ARCHIVE_BASE_HORIZONSIGNAL_63_NAME='stellaris_horizon_signal_3_14_15926_78464.sh'
+ARCHIVE_BASE_HORIZONSIGNAL_63_MD5='2e1dd57ce9e7f96216b7afd9ac2ad81b'
+ARCHIVE_BASE_HORIZONSIGNAL_63_SIZE='817'
+ARCHIVE_BASE_HORIZONSIGNAL_63_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_HORIZONSIGNAL_63_URL='https://www.gog.com/game/stellaris_horizon_signal'
+
+ARCHIVE_BASE_HORIZONSIGNAL_62_NAME='stellaris_horizon_signal_3_13_2_0_76713.sh'
+ARCHIVE_BASE_HORIZONSIGNAL_62_MD5='9719994a74b4778c50a5a9a0a1390d4a'
+ARCHIVE_BASE_HORIZONSIGNAL_62_SIZE='817'
+ARCHIVE_BASE_HORIZONSIGNAL_62_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_HORIZONSIGNAL_59_NAME='stellaris_horizon_signal_3_12_5_74193.sh'
 ARCHIVE_BASE_HORIZONSIGNAL_59_MD5='e0f7d5e0308ee01cd9fd4f3bc787e1b9'
 ARCHIVE_BASE_HORIZONSIGNAL_59_SIZE='817'
 ARCHIVE_BASE_HORIZONSIGNAL_59_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_HORIZONSIGNAL_59_URL='https://www.gog.com/game/stellaris_horizon_signal'
-
-ARCHIVE_BASE_HORIZONSIGNAL_58_NAME='stellaris_horizon_signal_3_12_4_1_74025.sh'
-ARCHIVE_BASE_HORIZONSIGNAL_58_MD5='97499af5785e58b9c088c95c07d21859'
-ARCHIVE_BASE_HORIZONSIGNAL_58_SIZE='817'
-ARCHIVE_BASE_HORIZONSIGNAL_58_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_HORIZONSIGNAL_57_NAME='stellaris_horizon_signal_3_12_2_73401.sh'
-ARCHIVE_BASE_HORIZONSIGNAL_57_MD5='cadfefd4ca074d6d6d4bf0f03a4aa191'
-ARCHIVE_BASE_HORIZONSIGNAL_57_SIZE='817'
-ARCHIVE_BASE_HORIZONSIGNAL_57_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_HORIZONSIGNAL_56_NAME='stellaris_horizon_signal_3_12_1_73183.sh'
-ARCHIVE_BASE_HORIZONSIGNAL_56_MD5='5c2558b8423a6d9b6cdb68db9005a79e'
-ARCHIVE_BASE_HORIZONSIGNAL_56_SIZE='817'
-ARCHIVE_BASE_HORIZONSIGNAL_56_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_HORIZONSIGNAL_55_NAME='stellaris_horizon_signal_3_11_3_0_72561.sh'
 ARCHIVE_BASE_HORIZONSIGNAL_55_MD5='d9074aa886455537cbeffb4364164b10'
@@ -267,8 +257,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -284,6 +279,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
