@@ -13,9 +13,9 @@ set -o errexit
 # - Toxoids
 ###
 
-script_version=20240721.1
+script_version=20241215.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -42,26 +42,21 @@ EXPANSION_NAME_TOXOIDS='Toxoids Species Pack'
 
 ## Plantoids
 
+ARCHIVE_BASE_PLANTOID_60_NAME='stellaris_plantoids_species_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_PLANTOID_60_MD5='d35b66bc263d6111755f070bd9029832'
+ARCHIVE_BASE_PLANTOID_60_SIZE='837'
+ARCHIVE_BASE_PLANTOID_60_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_PLANTOID_60_URL='https://www.gog.com/game/stellaris_plantoids_species_pack'
+
+ARCHIVE_BASE_PLANTOID_59_NAME='stellaris_plantoids_species_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_PLANTOID_59_MD5='3b5da3bbc12bef1778070cb48c0d5b5e'
+ARCHIVE_BASE_PLANTOID_59_SIZE='837'
+ARCHIVE_BASE_PLANTOID_59_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_PLANTOID_56_NAME='stellaris_plantoids_species_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_PLANTOID_56_MD5='c97796440232a0afa39a793efae40c67'
 ARCHIVE_BASE_PLANTOID_56_SIZE='837'
 ARCHIVE_BASE_PLANTOID_56_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_PLANTOID_56_URL='https://www.gog.com/game/stellaris_plantoids_species_pack'
-
-ARCHIVE_BASE_PLANTOID_55_NAME='stellaris_plantoids_species_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_PLANTOID_55_MD5='270742bc4ec4b9fdb95c6e2b9859bd39'
-ARCHIVE_BASE_PLANTOID_55_SIZE='837'
-ARCHIVE_BASE_PLANTOID_55_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_PLANTOID_54_NAME='stellaris_plantoids_species_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_PLANTOID_54_MD5='733dc8f83132aa0ef864a9c05a79f928'
-ARCHIVE_BASE_PLANTOID_54_SIZE='837'
-ARCHIVE_BASE_PLANTOID_54_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_PLANTOID_53_NAME='stellaris_plantoids_species_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_PLANTOID_53_MD5='5ddf59900abe04cd2b7c940a3578f80d'
-ARCHIVE_BASE_PLANTOID_53_SIZE='837'
-ARCHIVE_BASE_PLANTOID_53_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_PLANTOID_52_NAME='stellaris_plantoids_species_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_PLANTOID_52_MD5='c301172fde38bcd14b9e7546f35e49d2'
@@ -130,26 +125,21 @@ ARCHIVE_BASE_PLANTOID_19_VERSION='3.0.3-gog47193'
 
 ## Humanoids
 
+ARCHIVE_BASE_HUMANOIDS_60_NAME='stellaris_humanoids_species_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_HUMANOIDS_60_MD5='783bfe3b3ddc324fc0b8d29b2e41a56a'
+ARCHIVE_BASE_HUMANOIDS_60_SIZE='84675'
+ARCHIVE_BASE_HUMANOIDS_60_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_HUMANOIDS_60_URL='https://www.gog.com/game/stellaris_humanoids_species_pack'
+
+ARCHIVE_BASE_HUMANOIDS_59_NAME='stellaris_humanoids_species_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_HUMANOIDS_59_MD5='ae7cc19055d5cdcad0642008cb75bd93'
+ARCHIVE_BASE_HUMANOIDS_59_SIZE='84675'
+ARCHIVE_BASE_HUMANOIDS_59_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_HUMANOIDS_56_NAME='stellaris_humanoids_species_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_HUMANOIDS_56_MD5='f7fa5900c87f3fb8cd43d9dcead97de2'
 ARCHIVE_BASE_HUMANOIDS_56_SIZE='116312'
 ARCHIVE_BASE_HUMANOIDS_56_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_HUMANOIDS_56_URL='https://www.gog.com/game/stellaris_humanoids_species_pack'
-
-ARCHIVE_BASE_HUMANOIDS_55_NAME='stellaris_humanoids_species_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_HUMANOIDS_55_MD5='001eda53219385a7c112a3f6ddaff7f9'
-ARCHIVE_BASE_HUMANOIDS_55_SIZE='116312'
-ARCHIVE_BASE_HUMANOIDS_55_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_HUMANOIDS_54_NAME='stellaris_humanoids_species_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_HUMANOIDS_54_MD5='56a8b2c43e30b779ad0352bc21f23f63'
-ARCHIVE_BASE_HUMANOIDS_54_SIZE='116312'
-ARCHIVE_BASE_HUMANOIDS_54_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_HUMANOIDS_53_NAME='stellaris_humanoids_species_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_HUMANOIDS_53_MD5='d3cbb81ac3c037f43e24f41d74f83c9f'
-ARCHIVE_BASE_HUMANOIDS_53_SIZE='116312'
-ARCHIVE_BASE_HUMANOIDS_53_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_HUMANOIDS_52_NAME='stellaris_humanoids_species_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_HUMANOIDS_52_MD5='833ef910df4b00cfb7e3177b7525bee9'
@@ -213,26 +203,21 @@ ARCHIVE_BASE_HUMANOIDS_19_VERSION='3.0.3-gog47193'
 
 ## Lithoids
 
+ARCHIVE_BASE_LITHOIDS_48_NAME='stellaris_lithoids_species_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_LITHOIDS_48_MD5='588c9fe39ff00c406bdb731808c1d43d'
+ARCHIVE_BASE_LITHOIDS_48_SIZE='25612'
+ARCHIVE_BASE_LITHOIDS_48_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_LITHOIDS_48_URL='https://www.gog.com/game/stellaris_lithoids_species_pack'
+
+ARCHIVE_BASE_LITHOIDS_47_NAME='stellaris_lithoids_species_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_LITHOIDS_47_MD5='4fba44ef615444494f99af497e4d2b5f'
+ARCHIVE_BASE_LITHOIDS_47_SIZE='25612'
+ARCHIVE_BASE_LITHOIDS_47_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_LITHOIDS_44_NAME='stellaris_lithoids_species_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_LITHOIDS_44_MD5='bc4810ff3047e688c1ec0ae0991987ae'
 ARCHIVE_BASE_LITHOIDS_44_SIZE='52603'
 ARCHIVE_BASE_LITHOIDS_44_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_LITHOIDS_44_URL='https://www.gog.com/game/stellaris_lithoids_species_pack'
-
-ARCHIVE_BASE_LITHOIDS_43_NAME='stellaris_lithoids_species_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_LITHOIDS_43_MD5='4fb488d3088126135d1fa6a2435e1165'
-ARCHIVE_BASE_LITHOIDS_43_SIZE='52603'
-ARCHIVE_BASE_LITHOIDS_43_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_LITHOIDS_42_NAME='stellaris_lithoids_species_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_LITHOIDS_42_MD5='cdd908648182b22d1ec0661f35c9e8b9'
-ARCHIVE_BASE_LITHOIDS_42_SIZE='52603'
-ARCHIVE_BASE_LITHOIDS_42_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_LITHOIDS_41_NAME='stellaris_lithoids_species_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_LITHOIDS_41_MD5='6d92087f30f2e219b11663ed3537e194'
-ARCHIVE_BASE_LITHOIDS_41_SIZE='52603'
-ARCHIVE_BASE_LITHOIDS_41_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_LITHOIDS_40_NAME='stellaris_lithoids_species_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_LITHOIDS_40_MD5='8ca00268fd2b3b4fb611b65bc2f4edb7'
@@ -296,26 +281,21 @@ ARCHIVE_BASE_LITHOIDS_7_VERSION='3.0.3-gog47193'
 
 ## Necroids
 
+ARCHIVE_BASE_NECROIDS_33_NAME='stellaris_necroids_species_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_NECROIDS_33_MD5='fea1b49566e99f4e1b008c31a85b9bd1'
+ARCHIVE_BASE_NECROIDS_33_SIZE='24881'
+ARCHIVE_BASE_NECROIDS_33_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_NECROIDS_33_URL='https://www.gog.com/game/stellaris_necroids_species_pack'
+
+ARCHIVE_BASE_NECROIDS_32_NAME='stellaris_necroids_species_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_NECROIDS_32_MD5='0d3e8d5a8614c7b327584add2c38d13b'
+ARCHIVE_BASE_NECROIDS_32_SIZE='24881'
+ARCHIVE_BASE_NECROIDS_32_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_NECROIDS_29_NAME='stellaris_necroids_species_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_NECROIDS_29_MD5='3df3d9f80ed1d79a2f0f412535b77d54'
 ARCHIVE_BASE_NECROIDS_29_SIZE='49209'
 ARCHIVE_BASE_NECROIDS_29_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_NECROIDS_29_URL='https://www.gog.com/game/stellaris_necroids_species_pack'
-
-ARCHIVE_BASE_NECROIDS_28_NAME='stellaris_necroids_species_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_NECROIDS_28_MD5='25d7cabea1f2a2c3dae4f00bbae0fd49'
-ARCHIVE_BASE_NECROIDS_28_SIZE='49209'
-ARCHIVE_BASE_NECROIDS_28_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_NECROIDS_27_NAME='stellaris_necroids_species_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_NECROIDS_27_MD5='bd3fc243e8b5f271f28e412707dc9a75'
-ARCHIVE_BASE_NECROIDS_27_SIZE='49209'
-ARCHIVE_BASE_NECROIDS_27_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_NECROIDS_26_NAME='stellaris_necroids_species_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_NECROIDS_26_MD5='a5107b771305fda5b471a28366b81d47'
-ARCHIVE_BASE_NECROIDS_26_SIZE='49209'
-ARCHIVE_BASE_NECROIDS_26_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_NECROIDS_25_NAME='stellaris_necroids_species_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_NECROIDS_25_MD5='d0f677482b688ebe46e0abf20ece8477'
@@ -359,26 +339,21 @@ ARCHIVE_BASE_NECROIDS_2_VERSION='3.4.5-gog56913'
 
 ## Aquatics
 
+ARCHIVE_BASE_AQUATICS_31_NAME='stellaris_aquatics_species_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_AQUATICS_31_MD5='9d08da8254187e23fb6334972edd881f'
+ARCHIVE_BASE_AQUATICS_31_SIZE='29883'
+ARCHIVE_BASE_AQUATICS_31_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_AQUATICS_31_URL='https://www.gog.com/game/stellaris_aquatics_species_pack'
+
+ARCHIVE_BASE_AQUATICS_30_NAME='stellaris_aquatics_species_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_AQUATICS_30_MD5='fc83fab4aa3748870d373f1fe24f0be3'
+ARCHIVE_BASE_AQUATICS_30_SIZE='29883'
+ARCHIVE_BASE_AQUATICS_30_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_AQUATICS_27_NAME='stellaris_aquatics_species_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_AQUATICS_27_MD5='0d9d2d2a38c60025b79e72011b52837c'
 ARCHIVE_BASE_AQUATICS_27_SIZE='57544'
 ARCHIVE_BASE_AQUATICS_27_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_AQUATICS_27_URL='https://www.gog.com/game/stellaris_aquatics_species_pack'
-
-ARCHIVE_BASE_AQUATICS_26_NAME='stellaris_aquatics_species_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_AQUATICS_26_MD5='d7875e26717ae5a7c86c660f0f9408d2'
-ARCHIVE_BASE_AQUATICS_26_SIZE='57544'
-ARCHIVE_BASE_AQUATICS_26_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_AQUATICS_25_NAME='stellaris_aquatics_species_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_AQUATICS_25_MD5='18bd0132d65536988134a53ce5ad1f63'
-ARCHIVE_BASE_AQUATICS_25_SIZE='57544'
-ARCHIVE_BASE_AQUATICS_25_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_AQUATICS_24_NAME='stellaris_aquatics_species_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_AQUATICS_24_MD5='f57b66ee25468393a76333676b014401'
-ARCHIVE_BASE_AQUATICS_24_SIZE='57544'
-ARCHIVE_BASE_AQUATICS_24_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_AQUATICS_23_NAME='stellaris_aquatics_species_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_AQUATICS_23_MD5='818beaf18d82951df0b1028eb0d7f78a'
@@ -422,26 +397,21 @@ ARCHIVE_BASE_AQUATICS_0_VERSION='3.4.5-gog56913'
 
 ## Toxoids
 
+ARCHIVE_BASE_TOXOIDS_24_NAME='stellaris_toxoids_species_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_TOXOIDS_24_MD5='eb217db0b1389b6e62e228fe216391ed'
+ARCHIVE_BASE_TOXOIDS_24_SIZE='21991'
+ARCHIVE_BASE_TOXOIDS_24_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_TOXOIDS_24_URL='https://www.gog.com/game/stellaris_toxoids_species_pack'
+
+ARCHIVE_BASE_TOXOIDS_23_NAME='stellaris_toxoids_species_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_TOXOIDS_23_MD5='a201f70c2f26f9945459e0a9db4a3ea6'
+ARCHIVE_BASE_TOXOIDS_23_SIZE='21991'
+ARCHIVE_BASE_TOXOIDS_23_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_TOXOIDS_20_NAME='stellaris_toxoids_species_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_TOXOIDS_20_MD5='788f0afe85d1f90c91567e3958ddcae1'
 ARCHIVE_BASE_TOXOIDS_20_SIZE='41495'
 ARCHIVE_BASE_TOXOIDS_20_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_TOXOIDS_20_URL='https://www.gog.com/game/stellaris_toxoids_species_pack'
-
-ARCHIVE_BASE_TOXOIDS_19_NAME='stellaris_toxoids_species_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_TOXOIDS_19_MD5='5ed15f2afe4197243b25a0c10c3d1f93'
-ARCHIVE_BASE_TOXOIDS_19_SIZE='41495'
-ARCHIVE_BASE_TOXOIDS_19_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_TOXOIDS_18_NAME='stellaris_toxoids_species_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_TOXOIDS_18_MD5='154d04533036338269bbfe154432bd31'
-ARCHIVE_BASE_TOXOIDS_18_SIZE='41495'
-ARCHIVE_BASE_TOXOIDS_18_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_TOXOIDS_17_NAME='stellaris_toxoids_species_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_TOXOIDS_17_MD5='43ea4a72bd0c90b37d18c472b209b097'
-ARCHIVE_BASE_TOXOIDS_17_SIZE='41495'
-ARCHIVE_BASE_TOXOIDS_17_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_TOXOIDS_16_NAME='stellaris_toxoids_species_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_TOXOIDS_16_MD5='4dc7bf366e2e84febbe88f77057c018c'
@@ -501,8 +471,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -518,6 +493,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
