@@ -12,9 +12,9 @@ set -o errexit
 # - First Contact
 ###
 
-script_version=20240721.1
+script_version=20241215.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -38,26 +38,21 @@ EXPANSION_NAME_FIRSTCONTACT='First Contact Story Pack'
 
 ## Leviathans
 
+ARCHIVE_BASE_LEVIATHANS_60_NAME='stellaris_leviathans_story_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_LEVIATHANS_60_MD5='ae80f10988cea54f567a8d9bbc34b6d9'
+ARCHIVE_BASE_LEVIATHANS_60_SIZE='58426'
+ARCHIVE_BASE_LEVIATHANS_60_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_LEVIATHANS_60_URL='https://www.gog.com/game/stellaris_leviathans_story_pack'
+
+ARCHIVE_BASE_LEVIATHANS_59_NAME='stellaris_leviathans_story_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_LEVIATHANS_59_MD5='07773ecc28478515fc25fd000941fd38'
+ARCHIVE_BASE_LEVIATHANS_59_SIZE='58426'
+ARCHIVE_BASE_LEVIATHANS_59_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_LEVIATHANS_56_NAME='stellaris_leviathans_story_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_LEVIATHANS_56_MD5='8ab8f647d2405c443ee699b1ec3e17b4'
 ARCHIVE_BASE_LEVIATHANS_56_SIZE='58426'
 ARCHIVE_BASE_LEVIATHANS_56_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_LEVIATHANS_56_URL='https://www.gog.com/game/stellaris_leviathans_story_pack'
-
-ARCHIVE_BASE_LEVIATHANS_55_NAME='stellaris_leviathans_story_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_LEVIATHANS_55_MD5='5c7db0bc37635d28e8365fca38ff3335'
-ARCHIVE_BASE_LEVIATHANS_55_SIZE='58426'
-ARCHIVE_BASE_LEVIATHANS_55_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_LEVIATHANS_54_NAME='stellaris_leviathans_story_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_LEVIATHANS_54_MD5='cac93c6dbb81c13c381701a4589f914b'
-ARCHIVE_BASE_LEVIATHANS_54_SIZE='58426'
-ARCHIVE_BASE_LEVIATHANS_54_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_LEVIATHANS_53_NAME='stellaris_leviathans_story_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_LEVIATHANS_53_MD5='fda0c7971c8c791e4498ffa019243920'
-ARCHIVE_BASE_LEVIATHANS_53_SIZE='58426'
-ARCHIVE_BASE_LEVIATHANS_53_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_LEVIATHANS_52_NAME='stellaris_leviathans_story_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_LEVIATHANS_52_MD5='bbdede0f81d260b3225f671518d6f135'
@@ -121,26 +116,21 @@ ARCHIVE_BASE_LEVIATHANS_19_VERSION='3.0.3-gog47193'
 
 ## Synthetic Dawn
 
+ARCHIVE_BASE_SYNTHETICDAWN_59_NAME='stellaris_synthetic_dawn_story_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_SYNTHETICDAWN_59_MD5='6f0eed28ff1d4ed3e0ca8a0470e04b8a'
+ARCHIVE_BASE_SYNTHETICDAWN_59_SIZE='48245'
+ARCHIVE_BASE_SYNTHETICDAWN_59_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_SYNTHETICDAWN_59_URL='https://www.gog.com/game/stellaris_synthetic_dawn_story_pack'
+
+ARCHIVE_BASE_SYNTHETICDAWN_58_NAME='stellaris_synthetic_dawn_story_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_SYNTHETICDAWN_58_MD5='2d9bc46f1afe830229ac56b7800a1aba'
+ARCHIVE_BASE_SYNTHETICDAWN_58_SIZE='48245'
+ARCHIVE_BASE_SYNTHETICDAWN_58_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_SYNTHETICDAWN_55_NAME='stellaris_synthetic_dawn_story_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_SYNTHETICDAWN_55_MD5='28f5282f2422cce01ca868a906eb499c'
 ARCHIVE_BASE_SYNTHETICDAWN_55_SIZE='48244'
 ARCHIVE_BASE_SYNTHETICDAWN_55_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_SYNTHETICDAWN_55_URL='https://www.gog.com/game/stellaris_synthetic_dawn_story_pack'
-
-ARCHIVE_BASE_SYNTHETICDAWN_54_NAME='stellaris_synthetic_dawn_story_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_SYNTHETICDAWN_54_MD5='bd346298812a39a65efbc8a9fda6c903'
-ARCHIVE_BASE_SYNTHETICDAWN_54_SIZE='48244'
-ARCHIVE_BASE_SYNTHETICDAWN_54_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_SYNTHETICDAWN_53_NAME='stellaris_synthetic_dawn_story_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_SYNTHETICDAWN_53_MD5='f1e7049e5e3e88794f8bd5935cb08e35'
-ARCHIVE_BASE_SYNTHETICDAWN_53_SIZE='48244'
-ARCHIVE_BASE_SYNTHETICDAWN_53_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_SYNTHETICDAWN_52_NAME='stellaris_synthetic_dawn_story_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_SYNTHETICDAWN_52_MD5='54a9eaf01bcdd37c8f5474fa0d0cf564'
-ARCHIVE_BASE_SYNTHETICDAWN_52_SIZE='48244'
-ARCHIVE_BASE_SYNTHETICDAWN_52_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_SYNTHETICDAWN_51_NAME='stellaris_synthetic_dawn_story_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_SYNTHETICDAWN_51_MD5='dacbf32f6358906934c4168ad06fff0d'
@@ -204,26 +194,21 @@ ARCHIVE_BASE_SYNTHETICDAWN_18_VERSION='3.0.3-gog47193'
 
 ## Distant Stars
 
+ARCHIVE_BASE_DISTANTSTARS_59_NAME='stellaris_distant_stars_story_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_DISTANTSTARS_59_MD5='1249e6a985f8cd62ecfa37a27b14e877'
+ARCHIVE_BASE_DISTANTSTARS_59_SIZE='20832'
+ARCHIVE_BASE_DISTANTSTARS_59_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_DISTANTSTARS_59_URL='https://www.gog.com/game/stellaris_distant_stars_story_pack'
+
+ARCHIVE_BASE_DISTANTSTARS_58_NAME='stellaris_distant_stars_story_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_DISTANTSTARS_58_MD5='ee7f70b07d50956b05d0eb64ae752222'
+ARCHIVE_BASE_DISTANTSTARS_58_SIZE='20832'
+ARCHIVE_BASE_DISTANTSTARS_58_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_DISTANTSTARS_55_NAME='stellaris_distant_stars_story_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_DISTANTSTARS_55_MD5='be7d046f1e0165f607e0d19cf28eddc9'
 ARCHIVE_BASE_DISTANTSTARS_55_SIZE='20832'
 ARCHIVE_BASE_DISTANTSTARS_55_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_DISTANTSTARS_55_URL='https://www.gog.com/game/stellaris_distant_stars_story_pack'
-
-ARCHIVE_BASE_DISTANTSTARS_54_NAME='stellaris_distant_stars_story_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_DISTANTSTARS_54_MD5='8be4da5035ba2d6942beb9734d934ed4'
-ARCHIVE_BASE_DISTANTSTARS_54_SIZE='20832'
-ARCHIVE_BASE_DISTANTSTARS_54_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_DISTANTSTARS_53_NAME='stellaris_distant_stars_story_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_DISTANTSTARS_53_MD5='7f4fc7d101558aeb53f0ce76d40f1ac6'
-ARCHIVE_BASE_DISTANTSTARS_53_SIZE='20832'
-ARCHIVE_BASE_DISTANTSTARS_53_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_DISTANTSTARS_52_NAME='stellaris_distant_stars_story_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_DISTANTSTARS_52_MD5='4fc5f1299cdde303204547ff089b29f9'
-ARCHIVE_BASE_DISTANTSTARS_52_SIZE='20832'
-ARCHIVE_BASE_DISTANTSTARS_52_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_DISTANTSTARS_51_NAME='stellaris_distant_stars_story_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_DISTANTSTARS_51_MD5='1c05d748caac4118b22b1e7524936427'
@@ -287,26 +272,21 @@ ARCHIVE_BASE_DISTANTSTARS_18_VERSION='3.0.3-gog47193'
 
 ## Ancient Relics
 
+ARCHIVE_BASE_ANCIENTRELICS_48_NAME='stellaris_ancient_relics_3_14_15926_78464.sh'
+ARCHIVE_BASE_ANCIENTRELICS_48_MD5='df19c65b00fa9fe93f07bd78896a7840'
+ARCHIVE_BASE_ANCIENTRELICS_48_SIZE='32739'
+ARCHIVE_BASE_ANCIENTRELICS_48_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_ANCIENTRELICS_48_URL='https://www.gog.com/game/stellaris_ancient_relics_story_pack'
+
+ARCHIVE_BASE_ANCIENTRELICS_47_NAME='stellaris_ancient_relics_3_13_2_0_76713.sh'
+ARCHIVE_BASE_ANCIENTRELICS_47_MD5='a5154d3b51af853b0c45eeb0685a7f7d'
+ARCHIVE_BASE_ANCIENTRELICS_47_SIZE='32739'
+ARCHIVE_BASE_ANCIENTRELICS_47_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_ANCIENTRELICS_44_NAME='stellaris_ancient_relics_3_12_5_74193.sh'
 ARCHIVE_BASE_ANCIENTRELICS_44_MD5='35a896e2d8a9044a15898e9f55a39d47'
 ARCHIVE_BASE_ANCIENTRELICS_44_SIZE='32739'
 ARCHIVE_BASE_ANCIENTRELICS_44_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_ANCIENTRELICS_44_URL='https://www.gog.com/game/stellaris_ancient_relics_story_pack'
-
-ARCHIVE_BASE_ANCIENTRELICS_43_NAME='stellaris_ancient_relics_3_12_4_1_74025.sh'
-ARCHIVE_BASE_ANCIENTRELICS_43_MD5='f38b960e9a6ea6bf98a5399df5835dcc'
-ARCHIVE_BASE_ANCIENTRELICS_43_SIZE='32739'
-ARCHIVE_BASE_ANCIENTRELICS_43_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_ANCIENTRELICS_42_NAME='stellaris_ancient_relics_3_12_2_73401.sh'
-ARCHIVE_BASE_ANCIENTRELICS_42_MD5='c5105c5a45acaace8b70fd534507c2e2'
-ARCHIVE_BASE_ANCIENTRELICS_42_SIZE='32739'
-ARCHIVE_BASE_ANCIENTRELICS_42_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_ANCIENTRELICS_41_NAME='stellaris_ancient_relics_3_12_1_73183.sh'
-ARCHIVE_BASE_ANCIENTRELICS_41_MD5='cfdee2034c7b1fd10644f3cb95e2fe93'
-ARCHIVE_BASE_ANCIENTRELICS_41_SIZE='32739'
-ARCHIVE_BASE_ANCIENTRELICS_41_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_ANCIENTRELICS_40_NAME='stellaris_ancient_relics_3_11_3_0_72561.sh'
 ARCHIVE_BASE_ANCIENTRELICS_40_MD5='a1468916582d7e7ad9c73ad58d2a37ec'
@@ -370,26 +350,21 @@ ARCHIVE_BASE_ANCIENTRELICS_7_VERSION='3.0.3-gog47193'
 
 ## First Contact
 
+ARCHIVE_BASE_FIRSTCONTACT_22_NAME='stellaris_first_contact_story_pack_3_14_15926_78464.sh'
+ARCHIVE_BASE_FIRSTCONTACT_22_MD5='b7e4021113960f1ca6a26db56a7d13fb'
+ARCHIVE_BASE_FIRSTCONTACT_22_SIZE='832'
+ARCHIVE_BASE_FIRSTCONTACT_22_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_FIRSTCONTACT_22_URL='https://www.gog.com/game/stellaris_first_contact_story_pack'
+
+ARCHIVE_BASE_FIRSTCONTACT_21_NAME='stellaris_first_contact_story_pack_3_13_2_0_76713.sh'
+ARCHIVE_BASE_FIRSTCONTACT_21_MD5='12877f96dc523f3328a8f8231ebb2d84'
+ARCHIVE_BASE_FIRSTCONTACT_21_SIZE='832'
+ARCHIVE_BASE_FIRSTCONTACT_21_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_FIRSTCONTACT_18_NAME='stellaris_first_contact_story_pack_3_12_5_74193.sh'
 ARCHIVE_BASE_FIRSTCONTACT_18_MD5='d3e6622881abe21c5883e5fa61988f6b'
 ARCHIVE_BASE_FIRSTCONTACT_18_SIZE='832'
 ARCHIVE_BASE_FIRSTCONTACT_18_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_FIRSTCONTACT_18_URL='https://www.gog.com/game/stellaris_first_contact_story_pack'
-
-ARCHIVE_BASE_FIRSTCONTACT_17_NAME='stellaris_first_contact_story_pack_3_12_4_1_74025.sh'
-ARCHIVE_BASE_FIRSTCONTACT_17_MD5='d6f3195ac93b8df4b61bad706779b657'
-ARCHIVE_BASE_FIRSTCONTACT_17_SIZE='832'
-ARCHIVE_BASE_FIRSTCONTACT_17_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_FIRSTCONTACT_16_NAME='stellaris_first_contact_story_pack_3_12_2_73401.sh'
-ARCHIVE_BASE_FIRSTCONTACT_16_MD5='97d442da8c602c3da7db7627eb75361d'
-ARCHIVE_BASE_FIRSTCONTACT_16_SIZE='832'
-ARCHIVE_BASE_FIRSTCONTACT_16_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_FIRSTCONTACT_15_NAME='stellaris_first_contact_story_pack_3_12_1_73183.sh'
-ARCHIVE_BASE_FIRSTCONTACT_15_MD5='7be564ef8312307a1373908d11731835'
-ARCHIVE_BASE_FIRSTCONTACT_15_SIZE='832'
-ARCHIVE_BASE_FIRSTCONTACT_15_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_FIRSTCONTACT_14_NAME='stellaris_first_contact_story_pack_3_11_3_0_72561.sh'
 ARCHIVE_BASE_FIRSTCONTACT_14_MD5='946d0530c559cc4275177143f808a4e6'
@@ -444,8 +419,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -461,6 +441,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
