@@ -12,13 +12,12 @@ set -o errexit
 # - Nemesis
 # - Overlord
 # - Galactic Paragons
-# - Astral Planes
 # - The Machine Age
 ###
 
-script_version=20240721.1
+script_version=20241215.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -44,9 +43,6 @@ EXPANSION_NAME_OVERLORD='Overlord'
 EXPANSION_ID_PARAGONS='galactic-paragons'
 EXPANSION_NAME_PARAGONS='Galactic Paragons'
 
-EXPANSION_ID_PLANES='astral-planes'
-EXPANSION_NAME_PLANES='Astral Planes'
-
 EXPANSION_ID_MACHINE='the-machine-age'
 EXPANSION_NAME_MACHINE='The Machine Age'
 
@@ -54,26 +50,21 @@ EXPANSION_NAME_MACHINE='The Machine Age'
 
 ## Utopia
 
+ARCHIVE_BASE_UTOPIA_58_NAME='stellaris_utopia_3_14_15926_78464.sh'
+ARCHIVE_BASE_UTOPIA_58_MD5='62b9c4f468f049c1943cfcda6ff8c79e'
+ARCHIVE_BASE_UTOPIA_58_SIZE='75007'
+ARCHIVE_BASE_UTOPIA_58_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_UTOPIA_58_URL='https://www.gog.com/game/stellaris_utopia'
+
+ARCHIVE_BASE_UTOPIA_57_NAME='stellaris_utopia_3_13_2_0_76713.sh'
+ARCHIVE_BASE_UTOPIA_57_MD5='12459f9b139ca756b2c19a5755e41b67'
+ARCHIVE_BASE_UTOPIA_57_SIZE='75007'
+ARCHIVE_BASE_UTOPIA_57_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_UTOPIA_54_NAME='stellaris_utopia_3_12_5_74193.sh'
 ARCHIVE_BASE_UTOPIA_54_MD5='94ce113fad5b52d0464bfa48905412cc'
 ARCHIVE_BASE_UTOPIA_54_SIZE='75007'
 ARCHIVE_BASE_UTOPIA_54_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_UTOPIA_54_URL='https://www.gog.com/game/stellaris_utopia'
-
-ARCHIVE_BASE_UTOPIA_53_NAME='stellaris_utopia_3_12_4_1_74025.sh'
-ARCHIVE_BASE_UTOPIA_53_MD5='96bfe0c26d3119ff5b82b9934e87164c'
-ARCHIVE_BASE_UTOPIA_53_SIZE='75007'
-ARCHIVE_BASE_UTOPIA_53_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_UTOPIA_52_NAME='stellaris_utopia_3_12_2_73401.sh'
-ARCHIVE_BASE_UTOPIA_52_MD5='4197f0b4e82a8af8267fc3f19e38c2de'
-ARCHIVE_BASE_UTOPIA_52_SIZE='75007'
-ARCHIVE_BASE_UTOPIA_52_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_UTOPIA_51_NAME='stellaris_utopia_3_12_1_73183.sh'
-ARCHIVE_BASE_UTOPIA_51_MD5='081f86c652cc1d32e10f1cabbc381aa8'
-ARCHIVE_BASE_UTOPIA_51_SIZE='75007'
-ARCHIVE_BASE_UTOPIA_51_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_UTOPIA_50_NAME='stellaris_utopia_3_11_3_0_72561.sh'
 ARCHIVE_BASE_UTOPIA_50_MD5='b459de0ff28f660f9f9f6a38b5963df8'
@@ -137,26 +128,21 @@ ARCHIVE_BASE_UTOPIA_17_VERSION='3.0.3-gog47193'
 
 ## Apocalypse
 
+ARCHIVE_BASE_APOCALYPSE_48_NAME='stellaris_apocalypse_3_14_15926_78464.sh'
+ARCHIVE_BASE_APOCALYPSE_48_MD5='fe095847b18e9279daca3f2eb407cc2b'
+ARCHIVE_BASE_APOCALYPSE_48_SIZE='37877'
+ARCHIVE_BASE_APOCALYPSE_48_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_APOCALYPSE_48_URL='https://www.gog.com/game/stellaris_apocalypse'
+
+ARCHIVE_BASE_APOCALYPSE_47_NAME='stellaris_apocalypse_3_13_2_0_76713.sh'
+ARCHIVE_BASE_APOCALYPSE_47_MD5='ee89fa59d427166031964f106053fd39'
+ARCHIVE_BASE_APOCALYPSE_47_SIZE='37877'
+ARCHIVE_BASE_APOCALYPSE_47_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_APOCALYPSE_44_NAME='stellaris_apocalypse_3_12_5_74193.sh'
 ARCHIVE_BASE_APOCALYPSE_44_MD5='72c6721003d27d922fd134210da8b82f'
 ARCHIVE_BASE_APOCALYPSE_44_SIZE='37877'
 ARCHIVE_BASE_APOCALYPSE_44_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_APOCALYPSE_44_URL='https://www.gog.com/game/stellaris_apocalypse'
-
-ARCHIVE_BASE_APOCALYPSE_43_NAME='stellaris_apocalypse_3_12_4_1_74025.sh'
-ARCHIVE_BASE_APOCALYPSE_43_MD5='fc4ef87d5a954ad06b501ba8c80e6a08'
-ARCHIVE_BASE_APOCALYPSE_43_SIZE='37877'
-ARCHIVE_BASE_APOCALYPSE_43_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_APOCALYPSE_42_NAME='stellaris_apocalypse_3_12_2_73401.sh'
-ARCHIVE_BASE_APOCALYPSE_42_MD5='b83089a711119965ff6b29a12e77b39c'
-ARCHIVE_BASE_APOCALYPSE_42_SIZE='37877'
-ARCHIVE_BASE_APOCALYPSE_42_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_APOCALYPSE_41_NAME='stellaris_apocalypse_3_12_1_73183.sh'
-ARCHIVE_BASE_APOCALYPSE_41_MD5='de133d9b90807895f128f9ae3f4ccd1f'
-ARCHIVE_BASE_APOCALYPSE_41_SIZE='37877'
-ARCHIVE_BASE_APOCALYPSE_41_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_APOCALYPSE_40_NAME='stellaris_apocalypse_3_11_3_0_72561.sh'
 ARCHIVE_BASE_APOCALYPSE_40_MD5='5865125d875c8ddc549b8f0f4fd79ebd'
@@ -220,26 +206,21 @@ ARCHIVE_BASE_APOCALYPSE_7_VERSION='3.0.3-gog47193'
 
 ## MegaCorp
 
+ARCHIVE_BASE_MEGACORP_45_NAME='stellaris_megacorp_3_14_15926_78464.sh'
+ARCHIVE_BASE_MEGACORP_45_MD5='a16aec518e86ad716206899230871099'
+ARCHIVE_BASE_MEGACORP_45_SIZE='90404'
+ARCHIVE_BASE_MEGACORP_45_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_MEGACORP_45_URL='https://www.gog.com/game/stellaris_megacorp'
+
+ARCHIVE_BASE_MEGACORP_44_NAME='stellaris_megacorp_3_13_2_0_76713.sh'
+ARCHIVE_BASE_MEGACORP_44_MD5='e6b76bb98c26ec597e3a37b3aa915f46'
+ARCHIVE_BASE_MEGACORP_44_SIZE='90404'
+ARCHIVE_BASE_MEGACORP_44_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_MEGACORP_41_NAME='stellaris_megacorp_3_12_5_74193.sh'
 ARCHIVE_BASE_MEGACORP_41_MD5='056684f8cabd2bff919a6f1e1b12837a'
 ARCHIVE_BASE_MEGACORP_41_SIZE='130614'
 ARCHIVE_BASE_MEGACORP_41_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_MEGACORP_41_URL='https://www.gog.com/game/stellaris_megacorp'
-
-ARCHIVE_BASE_MEGACORP_40_NAME='stellaris_megacorp_3_12_4_1_74025.sh'
-ARCHIVE_BASE_MEGACORP_40_MD5='17ebb2f17a5ec3e50d21dcb1ac945c25'
-ARCHIVE_BASE_MEGACORP_40_SIZE='130614'
-ARCHIVE_BASE_MEGACORP_40_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_MEGACORP_39_NAME='stellaris_megacorp_3_12_2_73401.sh'
-ARCHIVE_BASE_MEGACORP_39_MD5='6cebe3f755bfa8fd74f4e9941149875f'
-ARCHIVE_BASE_MEGACORP_39_SIZE='130614'
-ARCHIVE_BASE_MEGACORP_39_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_MEGACORP_38_NAME='stellaris_megacorp_3_12_1_73183.sh'
-ARCHIVE_BASE_MEGACORP_38_MD5='1521312d5bbd3097c9d107e3ecdf656e'
-ARCHIVE_BASE_MEGACORP_38_SIZE='130614'
-ARCHIVE_BASE_MEGACORP_38_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_MEGACORP_37_NAME='stellaris_megacorp_3_11_3_0_72561.sh'
 ARCHIVE_BASE_MEGACORP_37_MD5='9c9fda0324405590e48d4da9741dcdb0'
@@ -303,26 +284,21 @@ ARCHIVE_BASE_MEGACORP_4_VERSION='3.0.3-gog47193'
 
 ## Federations
 
+ARCHIVE_BASE_FEDERATIONS_40_NAME='stellaris_federations_3_14_15926_78464.sh'
+ARCHIVE_BASE_FEDERATIONS_40_MD5='11fb43cc5b19aebd6bbece34c75492c5'
+ARCHIVE_BASE_FEDERATIONS_40_SIZE='14433'
+ARCHIVE_BASE_FEDERATIONS_40_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_FEDERATIONS_40_URL='https://www.gog.com/game/stellaris_federations'
+
+ARCHIVE_BASE_FEDERATIONS_39_NAME='stellaris_federations_3_13_2_0_76713.sh'
+ARCHIVE_BASE_FEDERATIONS_39_MD5='48ff77ab8c028f6088a0c6743da2bbed'
+ARCHIVE_BASE_FEDERATIONS_39_SIZE='14433'
+ARCHIVE_BASE_FEDERATIONS_39_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_FEDERATIONS_36_NAME='stellaris_federations_3_12_5_74193.sh'
 ARCHIVE_BASE_FEDERATIONS_36_MD5='77b14499ea1a8fe7d643e3881a473d0d'
 ARCHIVE_BASE_FEDERATIONS_36_SIZE='14433'
 ARCHIVE_BASE_FEDERATIONS_36_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_FEDERATIONS_36_URL='https://www.gog.com/game/stellaris_federations'
-
-ARCHIVE_BASE_FEDERATIONS_35_NAME='stellaris_federations_3_12_4_1_74025.sh'
-ARCHIVE_BASE_FEDERATIONS_35_MD5='139d67b3847f35ca14b86bb035c7e1d7'
-ARCHIVE_BASE_FEDERATIONS_35_SIZE='14433'
-ARCHIVE_BASE_FEDERATIONS_35_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_FEDERATIONS_34_NAME='stellaris_federations_3_12_2_73401.sh'
-ARCHIVE_BASE_FEDERATIONS_34_MD5='d91b8fba53cf45f1b43a82d9536756a4'
-ARCHIVE_BASE_FEDERATIONS_34_SIZE='14433'
-ARCHIVE_BASE_FEDERATIONS_34_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_FEDERATIONS_33_NAME='stellaris_federations_3_12_1_73183.sh'
-ARCHIVE_BASE_FEDERATIONS_33_MD5='7e73dee5ac683a0f1862c6e775d3a8b3'
-ARCHIVE_BASE_FEDERATIONS_33_SIZE='14433'
-ARCHIVE_BASE_FEDERATIONS_33_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_FEDERATIONS_32_NAME='stellaris_federations_3_11_3_0_72561.sh'
 ARCHIVE_BASE_FEDERATIONS_32_MD5='de18cbab731d65f25fcc58ea98a16a12'
@@ -376,26 +352,21 @@ ARCHIVE_BASE_FEDERATIONS_1_VERSION='3.2.2-gog51685'
 
 ## Nemesis
 
+ARCHIVE_BASE_NEMESIS_27_NAME='stellaris_nemesis_3_14_15926_78464.sh'
+ARCHIVE_BASE_NEMESIS_27_MD5='d950bf759ba6311143b1be3ec6811fd7'
+ARCHIVE_BASE_NEMESIS_27_SIZE='38539'
+ARCHIVE_BASE_NEMESIS_27_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_NEMESIS_27_URL='https://www.gog.com/game/stellaris_nemesis'
+
+ARCHIVE_BASE_NEMESIS_26_NAME='stellaris_nemesis_3_13_2_0_76713.sh'
+ARCHIVE_BASE_NEMESIS_26_MD5='3ab5141b829c7747c4622b92789fbe43'
+ARCHIVE_BASE_NEMESIS_26_SIZE='38539'
+ARCHIVE_BASE_NEMESIS_26_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_NEMESIS_23_NAME='stellaris_nemesis_3_12_5_74193.sh'
 ARCHIVE_BASE_NEMESIS_23_MD5='30187118ff7f8fed4db3b453f2b1a467'
 ARCHIVE_BASE_NEMESIS_23_SIZE='38539'
 ARCHIVE_BASE_NEMESIS_23_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_NEMESIS_23_URL='https://www.gog.com/game/stellaris_nemesis'
-
-ARCHIVE_BASE_NEMESIS_22_NAME='stellaris_nemesis_3_12_4_1_74025.sh'
-ARCHIVE_BASE_NEMESIS_22_MD5='c4cf716d5ba5aa6a4b508cc7cdaa6404'
-ARCHIVE_BASE_NEMESIS_22_SIZE='38539'
-ARCHIVE_BASE_NEMESIS_22_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_NEMESIS_21_NAME='stellaris_nemesis_3_12_2_73401.sh'
-ARCHIVE_BASE_NEMESIS_21_MD5='b820e1b7dde6e5e210f5adbd25406ac4'
-ARCHIVE_BASE_NEMESIS_21_SIZE='38539'
-ARCHIVE_BASE_NEMESIS_21_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_NEMESIS_20_NAME='stellaris_nemesis_3_12_1_73183.sh'
-ARCHIVE_BASE_NEMESIS_20_MD5='32c943bc6f3cdd266135c1a7c7479e83'
-ARCHIVE_BASE_NEMESIS_20_SIZE='38539'
-ARCHIVE_BASE_NEMESIS_20_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_NEMESIS_19_NAME='stellaris_nemesis_3_11_3_0_72561.sh'
 ARCHIVE_BASE_NEMESIS_19_MD5='a6380543924bf1479101511337238f29'
@@ -429,26 +400,21 @@ ARCHIVE_BASE_NEMESIS_0_VERSION='3.6.1-gog60754'
 
 ## Overlord
 
+ARCHIVE_BASE_OVERLORD_22_NAME='stellaris_overlord_3_14_15926_78464.sh'
+ARCHIVE_BASE_OVERLORD_22_MD5='cbc6247838f41c5d8f78c6fb6dba8ac4'
+ARCHIVE_BASE_OVERLORD_22_SIZE='99860'
+ARCHIVE_BASE_OVERLORD_22_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_OVERLORD_22_URL='https://www.gog.com/game/stellaris_overlord'
+
+ARCHIVE_BASE_OVERLORD_21_NAME='stellaris_overlord_3_13_2_0_76713.sh'
+ARCHIVE_BASE_OVERLORD_21_MD5='dbf1a321e0fe23a463030e436dafcda2'
+ARCHIVE_BASE_OVERLORD_21_SIZE='99860'
+ARCHIVE_BASE_OVERLORD_21_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_OVERLORD_18_NAME='stellaris_overlord_3_12_5_74193.sh'
 ARCHIVE_BASE_OVERLORD_18_MD5='62f8f8bf6a5f9774bd1fb036d73e2843'
 ARCHIVE_BASE_OVERLORD_18_SIZE='99860'
 ARCHIVE_BASE_OVERLORD_18_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_OVERLORD_18_URL='https://www.gog.com/game/stellaris_overlord'
-
-ARCHIVE_BASE_OVERLORD_17_NAME='stellaris_overlord_3_12_4_1_74025.sh'
-ARCHIVE_BASE_OVERLORD_17_MD5='564f44f5d624199fe16f95eed29c0f13'
-ARCHIVE_BASE_OVERLORD_17_SIZE='99860'
-ARCHIVE_BASE_OVERLORD_17_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_OVERLORD_16_NAME='stellaris_overlord_3_12_2_73401.sh'
-ARCHIVE_BASE_OVERLORD_16_MD5='a9ecb4c919b3427cea15408d87bc1e55'
-ARCHIVE_BASE_OVERLORD_16_SIZE='99860'
-ARCHIVE_BASE_OVERLORD_16_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_OVERLORD_15_NAME='stellaris_overlord_3_12_1_73183.sh'
-ARCHIVE_BASE_OVERLORD_15_MD5='05da07a47a13cb9d937c9d175e589416'
-ARCHIVE_BASE_OVERLORD_15_SIZE='99860'
-ARCHIVE_BASE_OVERLORD_15_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_OVERLORD_14_NAME='stellaris_overlord_3_11_3_0_72561.sh'
 ARCHIVE_BASE_OVERLORD_14_MD5='dd8189cd8134fc866c374864d0700b83'
@@ -472,26 +438,21 @@ ARCHIVE_BASE_OVERLORD_2_VERSION='3.8.4.1-gog65337'
 
 ## Galactic Paragons
 
+ARCHIVE_BASE_PARAGONS_22_NAME='stellaris_galactic_paragons_3_14_15926_78464.sh'
+ARCHIVE_BASE_PARAGONS_22_MD5='fd01b388fa76e46e8739a70d26c682f0'
+ARCHIVE_BASE_PARAGONS_22_SIZE='832'
+ARCHIVE_BASE_PARAGONS_22_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_PARAGONS_22_URL='https://www.gog.com/game/stellaris_galactic_paragons'
+
+ARCHIVE_BASE_PARAGONS_21_NAME='stellaris_galactic_paragons_3_13_2_0_76713.sh'
+ARCHIVE_BASE_PARAGONS_21_MD5='ce85a2dffe8e2f5dc5fd691622d96518'
+ARCHIVE_BASE_PARAGONS_21_SIZE='832'
+ARCHIVE_BASE_PARAGONS_21_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_PARAGONS_18_NAME='stellaris_galactic_paragons_3_12_5_74193.sh'
 ARCHIVE_BASE_PARAGONS_18_MD5='00b9ebf125e6812ccd02840db3f7bcd7'
 ARCHIVE_BASE_PARAGONS_18_SIZE='832'
 ARCHIVE_BASE_PARAGONS_18_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_PARAGONS_18_URL='https://www.gog.com/game/stellaris_galactic_paragons'
-
-ARCHIVE_BASE_PARAGONS_17_NAME='stellaris_galactic_paragons_3_12_4_1_74025.sh'
-ARCHIVE_BASE_PARAGONS_17_MD5='c6344de2edf30bb6318347691fe2f762'
-ARCHIVE_BASE_PARAGONS_17_SIZE='832'
-ARCHIVE_BASE_PARAGONS_17_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_PARAGONS_16_NAME='stellaris_galactic_paragons_3_12_2_73401.sh'
-ARCHIVE_BASE_PARAGONS_16_MD5='45f99ab73623db6cce5923efa2923706'
-ARCHIVE_BASE_PARAGONS_16_SIZE='832'
-ARCHIVE_BASE_PARAGONS_16_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_PARAGONS_15_NAME='stellaris_galactic_paragons_3_12_1_73183.sh'
-ARCHIVE_BASE_PARAGONS_15_MD5='321f865bacc45ccde7a44b91b21ead42'
-ARCHIVE_BASE_PARAGONS_15_SIZE='832'
-ARCHIVE_BASE_PARAGONS_15_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_PARAGONS_14_NAME='stellaris_galactic_paragons_3_11_3_0_72561.sh'
 ARCHIVE_BASE_PARAGONS_14_MD5='ee6878f407ab24721974463a3c957d68'
@@ -513,61 +474,23 @@ ARCHIVE_BASE_PARAGONS_2_MD5='e47a7ab7c264021f49b8419e1aedc580'
 ARCHIVE_BASE_PARAGONS_2_SIZE='1200'
 ARCHIVE_BASE_PARAGONS_2_VERSION='3.8.4.1-gog65337'
 
-## Astral Planes
-
-ARCHIVE_BASE_PLANES_12_NAME='stellaris_astral_planes_3_12_5_74193.sh'
-ARCHIVE_BASE_PLANES_12_MD5='8cbaaaa68306cc90effacd2510cbe089'
-ARCHIVE_BASE_PLANES_12_SIZE='46789'
-ARCHIVE_BASE_PLANES_12_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_PLANES_12_URL='https://www.gog.com/game/stellaris_astral_planes'
-
-ARCHIVE_BASE_PLANES_11_NAME='stellaris_astral_planes_3_12_4_1_74025.sh'
-ARCHIVE_BASE_PLANES_11_MD5='1a7e9e9209d740c9a53aede66dcbc6c4'
-ARCHIVE_BASE_PLANES_11_SIZE='46789'
-ARCHIVE_BASE_PLANES_11_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_PLANES_10_NAME='stellaris_astral_planes_3_12_2_73401.sh'
-ARCHIVE_BASE_PLANES_10_MD5='c56ae7693d57798e6165d822c568a648'
-ARCHIVE_BASE_PLANES_10_SIZE='46789'
-ARCHIVE_BASE_PLANES_10_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_PLANES_9_NAME='stellaris_astral_planes_3_12_1_73183.sh'
-ARCHIVE_BASE_PLANES_9_MD5='ac2897874c86f0ca6f22c3c09f321c8e'
-ARCHIVE_BASE_PLANES_9_SIZE='46789'
-ARCHIVE_BASE_PLANES_9_VERSION='3.12.1-gog73183'
-
-ARCHIVE_BASE_PLANES_8_NAME='stellaris_astral_planes_3_11_3_0_72561.sh'
-ARCHIVE_BASE_PLANES_8_MD5='7d43cac5e6dd18238fff6f06b82be7c1'
-ARCHIVE_BASE_PLANES_8_SIZE='46789'
-ARCHIVE_BASE_PLANES_8_VERSION='3.11.3-gog72561'
-
-ARCHIVE_BASE_PLANES_5_NAME='stellaris_astral_planes_3_10_4_70670.sh'
-ARCHIVE_BASE_PLANES_5_MD5='fab105e52dffbf0ec425d4cedf89feae'
-ARCHIVE_BASE_PLANES_5_SIZE='46789'
-ARCHIVE_BASE_PLANES_5_VERSION='3.10.4-gog70670'
-
 ## The Machine Age
 
+ARCHIVE_BASE_MACHINE_7_NAME='stellaris_the_machine_age_3_14_15926_78464.sh'
+ARCHIVE_BASE_MACHINE_7_MD5='ab74106e42a9b5525ae852ca27b7020f'
+ARCHIVE_BASE_MACHINE_7_SIZE='100390'
+ARCHIVE_BASE_MACHINE_7_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_MACHINE_7_URL='https://www.gog.com/game/stellaris_the_machine_age'
+
+ARCHIVE_BASE_MACHINE_6_NAME='stellaris_the_machine_age_3_13_2_0_76713.sh'
+ARCHIVE_BASE_MACHINE_6_MD5='113ee29d7d37fc5de99f1716114a12f3'
+ARCHIVE_BASE_MACHINE_6_SIZE='100390'
+ARCHIVE_BASE_MACHINE_6_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_MACHINE_3_NAME='stellaris_the_machine_age_3_12_5_74193.sh'
 ARCHIVE_BASE_MACHINE_3_MD5='06614dbbb8a94b20449f6a3a6f863347'
 ARCHIVE_BASE_MACHINE_3_SIZE='118726'
 ARCHIVE_BASE_MACHINE_3_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_MACHINE_3_URL='https://www.gog.com/game/stellaris_the_machine_age'
-
-ARCHIVE_BASE_MACHINE_2_NAME='stellaris_the_machine_age_3_12_4_1_74025.sh'
-ARCHIVE_BASE_MACHINE_2_MD5='b6a0b8fff344a7454f28321f5c135ea1'
-ARCHIVE_BASE_MACHINE_2_SIZE='118726'
-ARCHIVE_BASE_MACHINE_2_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_MACHINE_1_NAME='stellaris_the_machine_age_3_12_2_73401.sh'
-ARCHIVE_BASE_MACHINE_1_MD5='9ddc20ef2c06daac40bffeaf838c1f3b'
-ARCHIVE_BASE_MACHINE_1_SIZE='118726'
-ARCHIVE_BASE_MACHINE_1_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_MACHINE_0_NAME='stellaris_the_machine_age_3_12_1_73183.sh'
-ARCHIVE_BASE_MACHINE_0_MD5='7f56b69dd740fadc6a640b6e2a135e0a'
-ARCHIVE_BASE_MACHINE_0_SIZE='118726'
-ARCHIVE_BASE_MACHINE_0_VERSION='3.12.1-gog73183'
 
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
@@ -602,8 +525,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -619,6 +547,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
