@@ -7,33 +7,28 @@ set -o errexit
 # Stellaris
 ###
 
-script_version=20240721.1
+script_version=20250227.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
 
+ARCHIVE_BASE_59_NAME='stellaris_3_14_15926_78464.sh'
+ARCHIVE_BASE_59_MD5='0e93163e55e8bddbcdfd6c7c9c0307bd'
+ARCHIVE_BASE_59_SIZE='20344787'
+ARCHIVE_BASE_59_VERSION='3.14.15926-gog78464'
+ARCHIVE_BASE_59_URL='https://www.gog.com/game/stellaris'
+
+ARCHIVE_BASE_58_NAME='stellaris_3_13_2_0_76713.sh'
+ARCHIVE_BASE_58_MD5='e8a71267c39846f3fa51a7f14f0d2177'
+ARCHIVE_BASE_58_SIZE='19165769'
+ARCHIVE_BASE_58_VERSION='3.13.2-gog76713'
+
 ARCHIVE_BASE_55_NAME='stellaris_3_12_5_74193.sh'
 ARCHIVE_BASE_55_MD5='bb1b18f25732a09a6f257554a1d98375'
 ARCHIVE_BASE_55_SIZE='18792782'
 ARCHIVE_BASE_55_VERSION='3.12.5-gog74193'
-ARCHIVE_BASE_55_URL='https://www.gog.com/game/stellaris'
-
-ARCHIVE_BASE_54_NAME='stellaris_3_12_4_1_74025.sh'
-ARCHIVE_BASE_54_MD5='1e8b5cf1ed842230893beec4794ada09'
-ARCHIVE_BASE_54_SIZE='18917681'
-ARCHIVE_BASE_54_VERSION='3.12.4-gog74025'
-
-ARCHIVE_BASE_53_NAME='stellaris_3_12_2_73401.sh'
-ARCHIVE_BASE_53_MD5='7e58c45097f67a90eb6a877c1c6068c5'
-ARCHIVE_BASE_53_SIZE='18775413'
-ARCHIVE_BASE_53_VERSION='3.12.2-gog73401'
-
-ARCHIVE_BASE_52_NAME='stellaris_3_12_1_73183.sh'
-ARCHIVE_BASE_52_MD5='063a3f3b021dd095ac80c4e832dc9c9f'
-ARCHIVE_BASE_52_SIZE='18860653'
-ARCHIVE_BASE_52_VERSION='3.12.1-gog73183'
 
 ARCHIVE_BASE_51_NAME='stellaris_3_11_3_0_72561.sh'
 ARCHIVE_BASE_51_MD5='a03584bd08d67544607fade70c8cb157'
@@ -132,8 +127,17 @@ ChangeLog.txt
 ChangeLogBlank.txt
 checksum_manifest.txt
 ThirdPartyLicenses.txt'
+CONTENT_GAME_MULTIPLAYER_FILES='
+launcher-assets
+livepp
+pdx_launcher
+pdx_online_assets
+dowser
+launcher-installer-linux_2024.14
+pdx_core_test
+launcher-settings.json'
 
-## TODO: Check why a symlinks farm prefix can not be used.
+## TODO: Check why a symlinks farm prefix can not be used
 APP_MAIN_PREFIX_TYPE='none'
 APP_MAIN_EXE='stellaris'
 APP_MAIN_ICON='gfx/exe_icon.bmp'
@@ -142,7 +146,8 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA_MODELS_SHIPS
 PKG_DATA_MODELS
-PKG_DATA'
+PKG_DATA
+PKG_MULTIPLAYER'
 
 PKG_BIN_ARCH='64'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
@@ -155,6 +160,7 @@ libGL.so.1
 libm.so.6
 libpthread.so.0
 libresolv.so.2
+libSDL2-2.0.so.0
 libstdc++.so.6
 libuuid.so.1
 libX11.so.6
@@ -173,6 +179,20 @@ PKG_DATA_MODELS_SHIPS'
 PKG_DATA_MODELS_SHIPS_ID="${PKG_DATA_MODELS_ID}-ships"
 PKG_DATA_MODELS_SHIPS_DESCRIPTION="${PKG_DATA_MODELS_DESCRIPTION} - ships"
 
+PKG_MULTIPLAYER_ID="${GAME_ID}-multiplayer"
+PKG_MULTIPLAYER_DESCRIPTION='Paradox launcher'
+PKG_MULTIPLAYER_ARCH='64'
+PKG_MULTIPLAYER_DEPENDENCIES_SIBLINGS='
+PKG_BIN'
+PKG_MULTIPLAYER_DEPENDENCIES_LIBRARIES='
+libc.so.6
+libdl.so.2
+libgcc_s.so.1
+libm.so.6
+libpthread.so.0
+libstdc++.so.6
+libX11.so.6'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -196,20 +216,16 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
-
-	## Prevent inclusion of the Paradox launcher.
-	rm --force --recursive \
-		'libPDXBrowser_IPC.so' \
-		launcher-* \
-		pdx_*
-)
 
 # Include game data
 
@@ -218,15 +234,9 @@ content_inclusion_default
 
 # Write launchers
 
-## Force the use of system-provided SDL.
-path_libraries_system=$(
-	set_current_package 'PKG_BIN'
-	path_libraries_system
-)
+## Force the use of system-provided SDL
 APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
-# Force the use of system-provided SDL.
-export SDL_DYNAMIC_API='${path_libraries_system}/libSDL2-2.0.so.0'
-"
+$(launcher_tweak_sdl_override)"
 
 launchers_generation 'PKG_BIN'
 
@@ -237,6 +247,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
