@@ -8,9 +8,9 @@ set -o errexit
 # Sunless Sea
 ###
 
-script_version=20240528.1
+script_version=20241021.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='sunless-sea'
 GAME_NAME='Sunless Sea'
@@ -117,21 +117,12 @@ PKG_BIN64
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_ID_GOG_ZUBMARINER="${PKG_DATA_ID}-zubmariner"
-PKG_DATA_PROVIDES="
-$PKG_DATA_ID"
-PKG_DATA_DESCRIPTION='data'
-PKG_DATA_DESCRIPTION_GOG_ZUBMARINER="$PKG_DATA_DESCRIPTION (including Zubmariner DLC)"
-## Ensure smooth upgrades from packages generated with pre-20231020.1 scripts.
-PKG_DATA_PROVIDES="${PKG_DATA_PROVIDES:-}
-sunless-sea-zubmariner-data"
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -152,6 +143,16 @@ libz.so.1'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_ID_GOG_ZUBMARINER="${PKG_DATA_ID}-zubmariner"
+PKG_DATA_PROVIDES="
+$PKG_DATA_ID"
+PKG_DATA_DESCRIPTION='data'
+PKG_DATA_DESCRIPTION_GOG_ZUBMARINER="$PKG_DATA_DESCRIPTION (including Zubmariner DLC)"
+## Ensure smooth upgrades from packages generated with pre-20231020.1 scripts.
+PKG_DATA_PROVIDES="${PKG_DATA_PROVIDES:-}
+sunless-sea-zubmariner-data"
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -175,15 +176,20 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # humblebundle.com - Check that tools required to handle the inner archive are available.
 
 case "$(current_archive)" in
 	('ARCHIVE_BASE_HUMBLE_'*)
-		SCRIPT_DEPS="${SCRIPT_DEPS:-}
+		REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
 		$(archive_requirements_mojosetup_list)"
-		check_deps
+		requirements_check
 	;;
 esac
 
@@ -238,6 +244,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
