@@ -7,48 +7,66 @@ set -o errexit
 # The Elder Scrolls 3
 ###
 
-script_version=20240507.1
+script_version=20241121.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='the-elder-scrolls-3'
 GAME_NAME='The Elder Scrolls Ⅲ: Morrowind'
 
+ARCHIVE_BASE_EN_1_NAME='setup_the_elder_scrolls_iii_morrowind_goty_1.6.0.1820_gog_0.1_(77582).exe'
+ARCHIVE_BASE_EN_1_MD5='c3ea7739b81d457e4c7d91758b762f4e'
+## Do not convert file paths to lowercase, as it causes problems when importing morrowind.ini default settings
+ARCHIVE_BASE_EN_1_EXTRACTOR='innoextract'
+ARCHIVE_BASE_EN_1_EXTRACTOR_OPTIONS=' '
+ARCHIVE_BASE_EN_1_PART1_NAME='setup_the_elder_scrolls_iii_morrowind_goty_1.6.0.1820_gog_0.1_(77582)-1.bin'
+ARCHIVE_BASE_EN_1_PART1_MD5='1158ea779b50c704c17bedee0ad2612c'
+ARCHIVE_BASE_EN_1_SIZE='2209531'
+ARCHIVE_BASE_EN_1_VERSION='1.6.0.1820-gog77582'
+ARCHIVE_BASE_EN_1_URL='https://www.gog.com/game/the_elder_scrolls_iii_morrowind_goty_edition'
+
+ARCHIVE_BASE_FR_1_NAME='setup_the_elder_scrolls_iii_morrowind_goty_1.6.0.1820_gog_0.1_(french)_(77582).exe'
+ARCHIVE_BASE_FR_1_MD5='5f56a00e9256d930f63ab677c43c8b75'
+## Do not convert file paths to lowercase, as it causes problems when importing morrowind.ini default settings
+ARCHIVE_BASE_FR_1_EXTRACTOR='innoextract'
+ARCHIVE_BASE_FR_1_EXTRACTOR_OPTIONS=' '
+ARCHIVE_BASE_FR_1_PART1_NAME='setup_the_elder_scrolls_iii_morrowind_goty_1.6.0.1820_gog_0.1_(french)_(77582)-1.bin'
+ARCHIVE_BASE_FR_1_PART1_MD5='38571e142c67f9c8edd433902abe1454'
+ARCHIVE_BASE_FR_1_SIZE='2239754'
+ARCHIVE_BASE_FR_1_VERSION='1.6.0.1820-gog77582'
+ARCHIVE_BASE_FR_1_URL='https://www.gog.com/game/the_elder_scrolls_iii_morrowind_goty_edition'
+
 ARCHIVE_BASE_EN_0_NAME='setup_tes_morrowind_goty_2.0.0.7.exe'
 ARCHIVE_BASE_EN_0_MD5='3a027504a0e4599f8c6b5b5bcc87a5c6'
-## Do not convert file paths to lowercase, as it causes issues when importing morrowind.ini default settings.
+## Do not convert file paths to lowercase, as it causes problems when importing morrowind.ini default settings
 ARCHIVE_BASE_EN_0_EXTRACTOR='innoextract'
 ARCHIVE_BASE_EN_0_EXTRACTOR_OPTIONS=' '
 ARCHIVE_BASE_EN_0_SIZE='2300000'
 ARCHIVE_BASE_EN_0_VERSION='1.6.1820-gog2.0.0.7'
-ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/the_elder_scrolls_iii_morrowind_goty_edition'
 
 ARCHIVE_BASE_FR_0_NAME='setup_tes_morrowind_goty_french_2.0.0.7.exe'
 ARCHIVE_BASE_FR_0_MD5='2aee024e622786b2cb5454ff074faf9b'
-## Do not convert file paths to lowercase, as it causes issues when importing morrowind.ini default settings.
+## Do not convert file paths to lowercase, as it causes problems when importing morrowind.ini default settings
 ARCHIVE_BASE_FR_0_EXTRACTOR='innoextract'
 ARCHIVE_BASE_FR_0_EXTRACTOR_OPTIONS=' '
 ARCHIVE_BASE_FR_0_SIZE='2300000'
 ARCHIVE_BASE_FR_0_VERSION='1.6.1820-gog2.0.0.7'
-ARCHIVE_BASE_FR_0_URL='https://www.gog.com/game/the_elder_scrolls_iii_morrowind_goty_edition'
 
-CONTENT_PATH_DEFAULT='app'
+CONTENT_PATH_DEFAULT='.'
+CONTENT_PATH_DEFAULT_EN_0='app'
+CONTENT_PATH_DEFAULT_FR_0='app'
 CONTENT_GAME_L10N_FILES='
 Morrowind.ini
+Data Files/BookArt
 Data Files/Sound/Vo
 Data Files/Splash
 Data Files/Video
 Data Files/*.bsa
 Data Files/*.esm'
 CONTENT_GAME_DATA_FILES='
-Data Files/Fonts
-Data Files/Music
-Data Files/Sound/Cr
-Data Files/Sound/Fx
-Data Files/*.esp
-Data Files/*.txt
+Data Files
 Knife.ico'
-CONTENT_GAME_DATAFILES_DATA_PATH="${CONTENT_PATH_DEFAULT}/_OfficialPlugins/_unpacked_files"
+CONTENT_GAME_DATAFILES_DATA_RELATIVE_PATH='_OfficialPlugins/_unpacked_files'
 CONTENT_GAME_DATAFILES_DATA_FILES='
 Icons
 Meshes
@@ -61,8 +79,6 @@ CONTENT_DOC_L10N_FILES='
 CONTENT_DOC_DATA_FILES='
 *.pdf'
 
-APPLICATIONS_LIST='APP_MAIN'
-
 APP_MAIN_TYPE='custom'
 APP_MAIN_ICON='Morrowind.exe'
 
@@ -71,22 +87,24 @@ PKG_BIN
 PKG_L10N
 PKG_DATA'
 
-PKG_L10N_ID="${GAME_ID}-l10n"
-PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
-PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
+PKG_BIN_DEPENDENCIES_COMMANDS='
+openmw-iniimporter
+openmw-launcher'
+
+PKG_L10N_BASE_ID="${GAME_ID}-l10n"
+PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
+PKG_L10N_ID_FR="${PKG_L10N_BASE_ID}-fr"
 PKG_L10N_PROVIDES="
-$PKG_L10N_ID"
+$PKG_L10N_BASE_ID"
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
-PKG_BIN_DEPENDENCIES_COMMANDS='
-openmw-iniimporter
-openmw-launcher'
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -110,8 +128,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -185,6 +208,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
