@@ -11,9 +11,9 @@ set -o errexit
 # - Bastard's Wound
 ###
 
-script_version=20240718.1
+script_version=20241229.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='tyranny'
 GAME_NAME='Tyranny'
@@ -97,15 +97,20 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## Bastard's Wound - Delete duplicated files already provided by the base game.
+	# Bastard's Wound - Delete duplicated files already provided by the base game
 	case "$(current_archive)" in
 		('ARCHIVE_BASE_WOUND_'*)
 			rm \
@@ -337,6 +342,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
