@@ -7,9 +7,9 @@ set -o errexit
 # Unreal Tournament 2004
 ###
 
-script_version=20240528.1
+script_version=20250104.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='unreal-tournament-2004'
 GAME_NAME='Unreal Tournament 2004'
@@ -21,9 +21,9 @@ GAME_NAME='Unreal Tournament 2004'
 
 ARCHIVE_BASE_0_NAME='setup_unreal_tournament_2004_1.0_(18947).exe'
 ARCHIVE_BASE_0_MD5='243376d34413b830324c5879ac2f9cfd'
+## Do not convert file paths to lowercase
 ARCHIVE_BASE_0_EXTRACTOR='innoextract'
-## Do not convert file paths to lowercase.
-ARCHIVE_BASE_0_EXTRACTOR_OPTIONS='--progress=1 --silent'
+ARCHIVE_BASE_0_EXTRACTOR_OPTIONS=' '
 ARCHIVE_BASE_0_PART1_NAME='setup_unreal_tournament_2004_1.0_(18947)-1.bin'
 ARCHIVE_BASE_0_PART1_MD5='a211e2a6feed7334bb3b7deef6b858b5'
 ARCHIVE_BASE_0_SIZE='6000000'
@@ -43,7 +43,7 @@ CONTENT_PATH_DEFAULT='.'
 CONTENT_GAME_BIN_FILES='
 System
 ut2004.txt'
-CONTENT_GAME0_BIN_PATH="${CONTENT_PATH_DEFAULT}/__support/app"
+CONTENT_GAME0_BIN_PATH='__support/app'
 CONTENT_GAME0_BIN_FILES='
 *.ini'
 CONTENT_GAME_DATA_FILES='
@@ -57,10 +57,10 @@ Speech
 StaticMeshes
 Textures
 Web'
-CONTENT_DOC0_DATA_PATH="${CONTENT_PATH_DEFAULT}/Help"
+CONTENT_DOC0_DATA_RELATIVE_PATH='Help'
 CONTENT_DOC0_DATA_FILES='
 *.txt'
-CONTENT_DOC1_DATA_PATH="${CONTENT_PATH_DEFAULT}/Manual"
+CONTENT_DOC1_DATA_RELATIVE_PATH='Manual'
 CONTENT_DOC1_DATA_FILES='
 *.pdf'
 
@@ -82,21 +82,14 @@ CONTENT_DOC2_DATA_FILES='
 
 APP_MAIN_EXE='System/ut2004-bin-linux-amd64'
 APP_MAIN_ICON='System/Unreal.ico'
-## Run the game binary from its parent directory.
-APP_MAIN_PRERUN='# Run the game binary from its parent directory
-cd "$(dirname "$APP_EXE")"
-APP_EXE=$(basename "$APP_EXE")
-'
 
 PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -107,6 +100,9 @@ libpthread.so.0
 libSDL-1.2.so.0
 libstdc++.so.5'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -130,41 +126,34 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Check for the presence of required extra archives
+# Run the default initialization actions
+
+initialization_default "$@"
+
+# Chek for the presence of the required game engine
 
 archive_initialize_required \
 	'ARCHIVE_ENGINE' \
 	'ARCHIVE_REQUIRED_ENGINE_0'
 
-# Create required links for some libraries
-
-library_path=$(
-	set_current_package 'PKG_BIN'
-	path_libraries_system
-)
-APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
-# Create required link for libSDL-1.2.so.0
-ln --force --symbolic '${library_path}/libSDL-1.2.so.0' 'libSDL-1.2.so.0'
-# Create required link for openal.so
-ln --force --symbolic '${library_path}/libopenal.so.1' 'openal.so'"
-
 # Extract game data
 
 archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## Include required CD key.
-	grep --before=1 --fixed-strings 'CDKey' 'goggame-1207658691.script' | \
+	## Include required CD key
+	grep --before=1 --fixed-strings 'CDKey' 'goggame-1207658691.script' |
 		sed --silent 's/\s*"valueData": "\(.*\)",/\1/p' > 'System/CDKey'
 )
 archive_extraction 'ARCHIVE_ENGINE'
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path 'GAME_ENGINE_BIN')"
 
-	## Delete unwanted 32-bit binaries.
+	## Delete unwanted 32-bit binaries
 	rm --force \
 		'System/ucc-bin' \
 		'System/ut2004-bin'
@@ -175,8 +164,22 @@ archive_extraction 'ARCHIVE_ENGINE'
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
+## Create required links for some libraries
+path_libraries_source=$(path_libraries_system)
+path_libraries_destination="$(package_path 'PKG_BIN')$(path_game_data)/System"
+ln --symbolic "${path_libraries_source}/libSDL-1.2.so.0" "${path_libraries_destination}/libSDL-1.2.so.0"
+ln --symbolic "${path_libraries_source}/libopenal.so.1" "${path_libraries_destination}/openal.so"
+
 # Write launchers
 
+## Run the game binary from its parent directory
+game_exec_line() {
+	cat <<- 'EOF'
+	cd System
+	./ut2004-bin-linux-amd64 "$@"
+	EOF
+}
+
 launchers_generation 'PKG_BIN'
 
 # Build packages
@@ -186,6 +189,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
