@@ -9,9 +9,9 @@ set -o errexit
 # Unreal Tournament
 ###
 
-script_version=20240530.1
+script_version=20250104.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='unreal-tournament'
 GAME_NAME='Unreal Tournament'
@@ -23,7 +23,7 @@ GAME_NAME='Unreal Tournament'
 
 ARCHIVE_BASE_0_NAME='setup_ut_goty_2.0.0.5.exe'
 ARCHIVE_BASE_0_MD5='0d25ec835648710a098aff7106187f38'
-## Do not convert file paths to lowercase.
+## Do not convert file paths to lowercase
 ARCHIVE_BASE_0_EXTRACTOR='innoextract'
 ARCHIVE_BASE_0_EXTRACTOR_OPTIONS=' '
 ARCHIVE_BASE_0_SIZE='640000'
@@ -89,21 +89,14 @@ LICENSE.md'
 
 APP_MAIN_EXE='System64/ut-bin-amd64'
 APP_MAIN_ICON='System/Unreal.ico'
-## Run the game binary from its parent directory.
-APP_MAIN_PRERUN='# Run the game binary from its parent directory
-cd "$(dirname "$APP_EXE")"
-APP_EXE=$(basename "$APP_EXE")
-'
 
 PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -117,6 +110,9 @@ libSDL2-2.0.so.0
 libstdc++.so.6
 libxmp.so.4'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -140,37 +136,26 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Chek for the presence of required extra archives
+# Run the default initialization actions
+
+initialization_default "$@"
+
+# Chek for the presence of the required game engine
 
 archive_initialize_required \
 	'ARCHIVE_ENGINE' \
 	'ARCHIVE_REQUIRED_ENGINE_1' \
 	'ARCHIVE_REQUIRED_ENGINE_0'
-## Update the version string based on the engine build.
+
+## Update the version string based on the engine build
 current_archive=$(current_archive)
 engine_version=$(archive_name 'ARCHIVE_ENGINE' | sed 's/OldUnreal-UTPatch\([a-z0-9]\+\)-Linux-amd64.tar.bz2/\1/')
 archive_version_updated=$(get_value "${current_archive}_VERSION" | sed "s/^1.0-/${engine_version}-/")
 export "${current_archive}_VERSION=${archive_version_updated}"
 
-# The game engine looks for libmpg123.so instead of libmpg123.so.0
-
-case "$(option_value 'package')" in
-	('arch')
-		# Arch Linux already provides the unversioned .so
-	;;
-	('gentoo'|'egentoo')
-		# Gentoo already provides the unversioned .so
-	;;
-	('deb')
-		library_source="$(path_libraries_system)/libmpg123.so.0"
-		library_destination="$(package_path 'PKG_BIN')$(path_libraries)/libmpg123.so"
-		mkdir --parents "$(dirname "$library_destination")"
-		ln --symbolic "$library_source" "$library_destination"
-	;;
-esac
-
 # Extract game data
 
 archive_extraction_default
@@ -191,8 +176,31 @@ archive_extraction 'ARCHIVE_ENGINE'
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
+## The game engine looks for libmpg123.so instead of libmpg123.so.0
+case "$(option_value 'package')" in
+	('arch')
+		# Arch Linux already provides the unversioned .so
+	;;
+	('gentoo'|'egentoo')
+		# Gentoo already provides the unversioned .so
+	;;
+	('deb')
+		library_destination="$(package_path 'PKG_BIN')$(path_libraries)/libmpg123.so"
+		mkdir --parents "$(dirname "$library_destination")"
+		ln --symbolic "$(path_libraries_system)/libmpg123.so.0" "$library_destination"
+	;;
+esac
+
 # Write launchers
 
+## Run the game binary from its parent directory
+game_exec_line() {
+	cat <<- 'EOF'
+	cd System64
+	./ut-bin-amd64 "$@"
+	EOF
+}
+
 launchers_generation 'PKG_BIN'
 
 # Build packages
@@ -202,6 +210,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
