@@ -8,9 +8,9 @@ set -o errexit
 # Vampire: The Masquerade - Bloodlines
 ###
 
-script_version=20240712.1
+script_version=20250223.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='vampire-the-masquerade-bloodlines'
 GAME_NAME='Vampire: The Masquerade - Bloodlines'
@@ -22,6 +22,24 @@ ARCHIVE_BASE_DOTEMU_0_EXTRACTOR='unar'
 ARCHIVE_BASE_DOTEMU_0_SIZE='5013863'
 ARCHIVE_BASE_DOTEMU_0_VERSION='1.2-dotemu1'
 
+ARCHIVE_BASE_GOG_EN_6_NAME='setup_vampire_the_masquerade_-_bloodlines_1.2_(up_11.511.410.2)_(68368).exe'
+ARCHIVE_BASE_GOG_EN_6_MD5='553f6bdbd8b23fa143da22d9ea47a20b'
+ARCHIVE_BASE_GOG_EN_6_TYPE='innosetup'
+ARCHIVE_BASE_GOG_EN_6_PART1_NAME='setup_vampire_the_masquerade_-_bloodlines_1.2_(up_11.511.410.2)_(68368)-1.bin'
+ARCHIVE_BASE_GOG_EN_6_PART1_MD5='f0ca81565507da32075e6334a96a173f'
+ARCHIVE_BASE_GOG_EN_6_SIZE='4152647'
+ARCHIVE_BASE_GOG_EN_6_VERSION='1.2-gog68368'
+ARCHIVE_BASE_GOG_EN_6_URL='https://www.gog.com/game/vampire_the_masquerade_bloodlines'
+
+ARCHIVE_BASE_GOG_FR_6_NAME='setup_vampire_the_masquerade_-_bloodlines_1.2_(up_11.511.410.2)_(french)_(68368).exe'
+ARCHIVE_BASE_GOG_FR_6_MD5='5bb92c9507ef442ec95dade41f940c48'
+ARCHIVE_BASE_GOG_FR_6_TYPE='innosetup'
+ARCHIVE_BASE_GOG_FR_6_PART1_NAME='setup_vampire_the_masquerade_-_bloodlines_1.2_(up_11.511.410.2)_(french)_(68368)-1.bin'
+ARCHIVE_BASE_GOG_FR_6_PART1_MD5='c003bb4e2973fb7487bef0b50ed46c6a'
+ARCHIVE_BASE_GOG_FR_6_SIZE='4184265'
+ARCHIVE_BASE_GOG_FR_6_VERSION='1.2-gog68368'
+ARCHIVE_BASE_GOG_FR_6_URL='https://www.gog.com/game/vampire_the_masquerade_bloodlines'
+
 ARCHIVE_BASE_GOG_EN_5_NAME='setup_vampire_the_masquerade_-_bloodlines_1.2_(up_11.511.410.2)_(68368).exe'
 ARCHIVE_BASE_GOG_EN_5_MD5='b2c1eff2640a4b7c52922a3c1ce3f36b'
 ARCHIVE_BASE_GOG_EN_5_TYPE='innosetup'
@@ -29,7 +47,6 @@ ARCHIVE_BASE_GOG_EN_5_PART1_NAME='setup_vampire_the_masquerade_-_bloodlines_1.2_
 ARCHIVE_BASE_GOG_EN_5_PART1_MD5='96b585f441224ab5f8658815b74a0763'
 ARCHIVE_BASE_GOG_EN_5_SIZE='4209268'
 ARCHIVE_BASE_GOG_EN_5_VERSION='1.2-gog68368'
-ARCHIVE_BASE_GOG_EN_5_URL='https://www.gog.com/game/vampire_the_masquerade_bloodlines'
 
 ARCHIVE_BASE_GOG_FR_5_NAME='setup_vampire_the_masquerade_-_bloodlines_1.2_(up_11.511.410.2)_(french)_(68368).exe'
 ARCHIVE_BASE_GOG_FR_5_MD5='ea6cec86b0eb1986164eefb6ddf458ef'
@@ -38,7 +55,6 @@ ARCHIVE_BASE_GOG_FR_5_PART1_NAME='setup_vampire_the_masquerade_-_bloodlines_1.2_
 ARCHIVE_BASE_GOG_FR_5_PART1_MD5='01194704a7c9b1e7c67e4743bcdb81f7'
 ARCHIVE_BASE_GOG_FR_5_SIZE='4242068'
 ARCHIVE_BASE_GOG_FR_5_VERSION='1.2-gog68368'
-ARCHIVE_BASE_GOG_FR_5_URL='https://www.gog.com/game/vampire_the_masquerade_bloodlines'
 
 ARCHIVE_BASE_GOG_EN_4_NAME='setup_vampire_the_masquerade_-_bloodlines_1.2_(up_11.111.010.2)_hotfix_(55110).exe'
 ARCHIVE_BASE_GOG_EN_4_MD5='9a1c0824945008a3d520103002479fbc'
@@ -111,6 +127,7 @@ CONTENT_GAME_BIN_FILES='
 bin
 vampire/dlls
 vampire/cl_dlls
+loader.exe
 vampire.exe
 vampire.exe.12
 dbghelp.dll
@@ -166,8 +183,14 @@ vampire/vidcfg.bin'
 
 WINE_VIRTUAL_DESKTOP='auto'
 
-APP_MAIN_EXE='vampire.exe'
-## Work around the deletion of zlib1.dll.
+APP_MAIN_EXE_DOTEMU='vampire.exe'
+## Using vampire.exe directly with the GOG build leads to lingering processes
+## cf. https://bugs.winehq.org/show_bug.cgi?id=56713
+## Vampire: The Masquerade - Bloodlines Vampire.exe process keeps lingering
+APP_MAIN_EXE_GOG='loader.exe'
+APP_MAIN_ICON='vampire.exe'
+## Work around the deletion of zlib1.dll
+## TODO: Check if it is still required with current WINE
 APP_MAIN_PRERUN='
 # Work around the deletion of zlib1.dll
 system_library="${WINEPREFIX}/drive_c/windows/system32/zlib1.dll"
@@ -258,14 +281,20 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # DotEmu archive - unzip is required to extract the content of inner archives
 
 case "$(current_archive)" in
 	('ARCHIVE_BASE_DOTEMU_'*)
-		SCRIPT_DEPS="${SCRIPT_DEPS:-} unzip"
-		check_deps
+		REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
+		unzip"
+		requirements_check
 	;;
 esac
 
@@ -301,7 +330,13 @@ archive_extraction_default
 			rm "$(archive_path 'ARCHIVE_EN')"
 			## Localized paths are moved out of the way to prevent them from being overwritten.
 			mkdir 'l10n-en'
+			## Silence a ShellCheck false positive, word splitting is expected here
+			## SC2086 (info): Double quote to prevent globbing and word splitting.
+			# shellcheck disable=SC2086
 			cp --link --parents --recursive $localized_paths_en 'l10n-en'
+			## Silence a ShellCheck false positive, word splitting is expected here
+			## SC2086 (info): Double quote to prevent globbing and word splitting.
+			# shellcheck disable=SC2086
 			rm --recursive $localized_paths
 	
 			ARCHIVE_FR_PATH="${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/fr.zip"
@@ -309,7 +344,13 @@ archive_extraction_default
 			rm "$(archive_path 'ARCHIVE_FR')"
 			## Localized paths are moved out of the way to prevent them from being overwritten.
 			mkdir 'l10n-fr'
+			## Silence a ShellCheck false positive, word splitting is expected here
+			## SC2086 (info): Double quote to prevent globbing and word splitting.
+			# shellcheck disable=SC2086
 			cp --link --parents --recursive $localized_paths_fr 'l10n-fr'
+			## Silence a ShellCheck false positive, word splitting is expected here
+			## SC2086 (info): Double quote to prevent globbing and word splitting.
+			# shellcheck disable=SC2086
 			rm --recursive $localized_paths
 
 			tolower .
@@ -356,6 +397,6 @@ esac
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
