@@ -7,18 +7,23 @@ set -o errexit
 # War for the Overworld
 ###
 
-script_version=20240721.1
+script_version=20250103.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.30'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='war-for-the-overworld'
 GAME_NAME='War for the Overworld'
 
+ARCHIVE_BASE_8_NAME='war_for_the_overworld_v2_1_2_76431.sh'
+ARCHIVE_BASE_8_MD5='e834b2a81bff0a36dc50fcf7a061abec'
+ARCHIVE_BASE_8_SIZE='4814079'
+ARCHIVE_BASE_8_VERSION='2.1.2-gog76431'
+ARCHIVE_BASE_8_URL='https://www.gog.com/game/war_for_the_overworld'
+
 ARCHIVE_BASE_7_NAME='war_for_the_overworld_v2_1_1_73576.sh'
 ARCHIVE_BASE_7_MD5='d3095d210fda9c39cd2cec6c2d0a882f'
 ARCHIVE_BASE_7_SIZE='4792845'
 ARCHIVE_BASE_7_VERSION='2.1.1-gog73576'
-ARCHIVE_BASE_7_URL='https://www.gog.com/game/war_for_the_overworld'
 
 ARCHIVE_BASE_6_NAME='war_for_the_overworld_v2_1_0f4_55096.sh'
 ARCHIVE_BASE_6_MD5='97a9bd6ee2f88fa9c64a75cd578d3677'
@@ -82,7 +87,7 @@ USER_PERSISTENT_DIRECTORIES="
 GameData
 ${UNITY3D_NAME}_Data/GameData
 ${UNITY3D_NAME}_Data/uiresources/minimapSnapshot"
-## Work around the engine inability to play video files without write permissions.
+## Work around the engine inability to play video files without write permissions
 USER_PERSISTENT_DIRECTORIES="${USER_PERSISTENT_DIRECTORIES:-}
 ${UNITY3D_NAME}_Data/uiresources/wftoUI/menu/vids"
 
@@ -134,20 +139,12 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Link some Unity3D plugin libraries in the game data path as the game engine fails to find them otherwise.
+# Run the default initialization actions
 
-libraries_source=$(
-	set_current_package 'PKG_BIN'
-	path_libraries
-)
-libraries_destination="$(package_path 'PKG_BIN')$(path_game_data)/$(unity3d_name)_Data/Plugins/x86_64"
-mkdir --parents "$libraries_destination"
-ln --symbolic \
-	"${libraries_source}/libCoherentUIGT_Native.so" \
-	"${libraries_source}/libGameLogic.so" \
-	"$libraries_destination"
+initialization_default "$@"
 
 # Extract game data
 
@@ -155,11 +152,10 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 	
-	## Add required execution permissions (this is only required by some old builds of the game).
-	unity3d_name=$(unity3d_name)
+	## Add required execution permissions (this is only required by some old builds of the game)
 	for file in \
-		"${unity3d_name}_Data/CoherentUI_Host/linux/CoherentUI_Host" \
-		"${unity3d_name}_Data/CoherentUI_Host/linux/CoherentUI_Host.bin"
+		"$(unity3d_name)_Data/CoherentUI_Host/linux/CoherentUI_Host" \
+		"$(unity3d_name)_Data/CoherentUI_Host/linux/CoherentUI_Host.bin"
 	do
 		if [ -e "$file" ]; then
 			chmod 755 "$file"
@@ -172,6 +168,14 @@ archive_extraction_default
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
+## Link some Unity3D plugin libraries in the game data path as the game engine fails to find them otherwise
+libraries_destination="$(package_path 'PKG_BIN')$(path_game_data)/$(unity3d_name)_Data/Plugins/x86_64"
+mkdir --parents "$libraries_destination"
+ln --symbolic \
+	"$(path_libraries)/libCoherentUIGT_Native.so" \
+	"$(path_libraries)/libGameLogic.so" \
+	"$libraries_destination"
+
 # Write launchers
 
 launchers_generation 'PKG_BIN'
@@ -183,6 +187,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
