@@ -12,9 +12,9 @@ set -o errexit
 # - Soulstorm
 ###
 
-script_version=20240626.1
+script_version=20241021.5
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='warhammer-40k-dawn-of-war'
 GAME_NAME='Warhammer 40,000: Dawn of War'
@@ -73,25 +73,21 @@ ARCHIVE_BASE_WA_FR_1_SIZE='2769494'
 ARCHIVE_BASE_WA_FR_1_VERSION='1.51-gog64626'
 ARCHIVE_BASE_WA_FR_1_URL='https://www.gog.com/game/warhammer_40000_dawn_of_war'
 
-## Support for this archive can only be restored after ./play.it gains support for multiple archives with an identical name.
-## cf. https://forge.dotslashplay.it/play.it/scripts/-/issues/355
-#ARCHIVE_BASE_WA_EN_0_NAME='setup_warhammer_40000_dawn_of_war_-_winter_assault_0.19_(64626).exe'
-#ARCHIVE_BASE_WA_EN_0_MD5='a610066c44aee835f0ac608864c31ef9'
-#ARCHIVE_BASE_WA_EN_0_TYPE='innosetup'
-#ARCHIVE_BASE_WA_EN_0_PART1_NAME='setup_warhammer_40000_dawn_of_war_-_winter_assault_0.19_(64626)-1.bin'
-#ARCHIVE_BASE_WA_EN_0_PART1_MD5='fd954304b3f38cccf859edf7ca4e1dd5'
-#ARCHIVE_BASE_WA_EN_0_SIZE='2800000'
-#ARCHIVE_BASE_WA_EN_0_VERSION='1.51-gog64626'
+ARCHIVE_BASE_WA_EN_0_NAME='setup_warhammer_40000_dawn_of_war_-_winter_assault_0.19_(64626).exe'
+ARCHIVE_BASE_WA_EN_0_MD5='a610066c44aee835f0ac608864c31ef9'
+ARCHIVE_BASE_WA_EN_0_TYPE='innosetup'
+ARCHIVE_BASE_WA_EN_0_PART1_NAME='setup_warhammer_40000_dawn_of_war_-_winter_assault_0.19_(64626)-1.bin'
+ARCHIVE_BASE_WA_EN_0_PART1_MD5='fd954304b3f38cccf859edf7ca4e1dd5'
+ARCHIVE_BASE_WA_EN_0_SIZE='2800000'
+ARCHIVE_BASE_WA_EN_0_VERSION='1.51-gog64626'
 
-## Support for this archive can only be restored after ./play.it gains support for multiple archives with an identical name.
-## cf. https://forge.dotslashplay.it/play.it/scripts/-/issues/355
-#ARCHIVE_BASE_WA_FR_0_NAME='setup_warhammer_40000_dawn_of_war_-_winter_assault_0.19_(french)_(64626).exe'
-#ARCHIVE_BASE_WA_FR_0_MD5='9423b22d50f707d794e961aef63a9a44'
-#ARCHIVE_BASE_WA_FR_0_TYPE='innosetup'
-#ARCHIVE_BASE_WA_FR_0_PART1_NAME='setup_warhammer_40000_dawn_of_war_-_winter_assault_0.19_(french)_(64626)-1.bin'
-#ARCHIVE_BASE_WA_FR_0_PART1_MD5='b4a188c7ed2012a9c4fd300af07c831d'
-#ARCHIVE_BASE_WA_FR_0_SIZE='2800000'
-#ARCHIVE_BASE_WA_FR_0_VERSION='1.51-gog64626'
+ARCHIVE_BASE_WA_FR_0_NAME='setup_warhammer_40000_dawn_of_war_-_winter_assault_0.19_(french)_(64626).exe'
+ARCHIVE_BASE_WA_FR_0_MD5='9423b22d50f707d794e961aef63a9a44'
+ARCHIVE_BASE_WA_FR_0_TYPE='innosetup'
+ARCHIVE_BASE_WA_FR_0_PART1_NAME='setup_warhammer_40000_dawn_of_war_-_winter_assault_0.19_(french)_(64626)-1.bin'
+ARCHIVE_BASE_WA_FR_0_PART1_MD5='b4a188c7ed2012a9c4fd300af07c831d'
+ARCHIVE_BASE_WA_FR_0_SIZE='2800000'
+ARCHIVE_BASE_WA_FR_0_VERSION='1.51-gog64626'
 
 ## Winter Assault (free demo)
 
@@ -207,7 +203,6 @@ local.ini'
 
 WINE_WINEPREFIX_TWEAKS='mono'
 ## Mono is not required by the Winter Assault demo.
-## FIXME: ./play.it 2.29 has no context support for this variable, so the Mono archive is required anyway.
 WINE_WINEPREFIX_TWEAKS_WA_DEMO=' '
 
 APP_MAIN_EXE_DOW='w40k.exe'
@@ -231,83 +226,79 @@ PKG_DATA'
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
+
+PKG_DATA_DESCRIPTION='data'
 
 ## Dawn of War (base game)
 
-PKG_L10N_ID_DOW="${GAME_ID}-l10n"
-PKG_L10N_ID_DOW_EN="${PKG_L10N_ID_DOW}-en"
-PKG_L10N_ID_DOW_FR="${PKG_L10N_ID_DOW}-fr"
+PKG_L10N_BASE_ID_DOW="${GAME_ID}-l10n"
+PKG_L10N_ID_DOW_EN="${PKG_L10N_BASE_ID_DOW}-en"
+PKG_L10N_ID_DOW_FR="${PKG_L10N_BASE_ID_DOW}-fr"
 PKG_L10N_PROVIDES_DOW="
-$PKG_L10N_ID_DOW"
+$PKG_L10N_BASE_ID_DOW"
 PKG_L10N_DESCRIPTION_DOW_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_DOW_FR="$PKG_L10N_DESCRIPTION_FR"
 
 PKG_DATA_ID_DOW="${GAME_ID}-data"
 
-PKG_BIN_DEPS_DOW="$PKG_L10N_ID_DOW $PKG_DATA_ID_DOW"
-
 ## Winter Assault (full game)
 
-PKG_L10N_ID_WA="${GAME_ID_WA}-l10n"
-PKG_L10N_ID_WA_EN="${PKG_L10N_ID_WA}-en"
-PKG_L10N_ID_WA_FR="${PKG_L10N_ID_WA}-fr"
+PKG_L10N_BASE_ID_WA="${GAME_ID_WA}-l10n"
+PKG_L10N_ID_WA_EN="${PKG_L10N_BASE_ID_WA}-en"
+PKG_L10N_ID_WA_FR="${PKG_L10N_BASE_ID_WA}-fr"
 PKG_L10N_PROVIDES_WA="
-$PKG_L10N_ID_WA"
+$PKG_L10N_BASE_ID_WA"
 PKG_L10N_DESCRIPTION_WA_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_WA_FR="$PKG_L10N_DESCRIPTION_FR"
 
 PKG_DATA_ID_WA="${GAME_ID_WA}-data"
 
-PKG_BIN_DEPS_WA="$PKG_L10N_ID_WA $PKG_DATA_ID_WA"
-
 ## Winter Assault (free demo)
 
-PKG_L10N_ID_WA_DEMO="${GAME_ID_WA_DEMO}-l10n"
-PKG_L10N_ID_WA_DEMO_EN="${PKG_L10N_ID_WA_DEMO}-en"
+PKG_L10N_BASE_ID_WA_DEMO="${GAME_ID_WA_DEMO}-l10n"
+PKG_L10N_ID_WA_DEMO_EN="${PKG_L10N_BASE_ID_WA_DEMO}-en"
 PKG_L10N_PROVIDES_WA_DEMO="
-$PKG_L10N_ID_WA_DEMO"
+$PKG_L10N_BASE_ID_WA_DEMO"
 PKG_L10N_DESCRIPTION_WA_DEMO_EN="$PKG_L10N_DESCRIPTION_EN"
 
 PKG_DATA_ID_WA_DEMO="${GAME_ID_WA_DEMO}-data"
 
-PKG_BIN_DEPS_WA_DEMO="$PKG_L10N_ID_WA_DEMO $PKG_DATA_ID_WA_DEMO"
-
 ## Dark Crusade
 
-PKG_L10N_ID_DC="${GAME_ID_DC}-l10n"
-PKG_L10N_ID_DC_EN="${PKG_L10N_ID_DC}-en"
-PKG_L10N_ID_DC_FR="${PKG_L10N_ID_DC}-fr"
+PKG_L10N_BASE_ID_DC="${GAME_ID_DC}-l10n"
+PKG_L10N_ID_DC_EN="${PKG_L10N_BASE_ID_DC}-en"
+PKG_L10N_ID_DC_FR="${PKG_L10N_BASE_ID_DC}-fr"
 PKG_L10N_PROVIDES_DC="
-$PKG_L10N_ID_DC"
+$PKG_L10N_BASE_ID_DC"
 PKG_L10N_DESCRIPTION_DC_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_DC_FR="$PKG_L10N_DESCRIPTION_FR"
 
 PKG_DATA_ID_DC="${GAME_ID_DC}-data"
 
-PKG_BIN_DEPS_DC="$PKG_L10N_ID_DC $PKG_DATA_ID_DC"
-
 ## Soulstorm
 
-PKG_L10N_ID_SS="${GAME_ID_SS}-l10n"
-PKG_L10N_ID_SS_EN="${PKG_L10N_ID_SS}-en"
-PKG_L10N_ID_SS_FR="${PKG_L10N_ID_SS}-fr"
+PKG_L10N_BASE_ID_SS="${GAME_ID_SS}-l10n"
+PKG_L10N_ID_SS_EN="${PKG_L10N_BASE_ID_SS}-en"
+PKG_L10N_ID_SS_FR="${PKG_L10N_BASE_ID_SS}-fr"
 PKG_L10N_PROVIDES_SS="
-$PKG_L10N_ID_SS"
+$PKG_L10N_BASE_ID_SS"
 PKG_L10N_DESCRIPTION_SS_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_SS_FR="$PKG_L10N_DESCRIPTION_FR"
 
 PKG_DATA_ID_SS="${GAME_ID_SS}-data"
 
-PKG_BIN_DEPS_SS="$PKG_L10N_ID_SS $PKG_DATA_ID_SS"
-
 # Winter Assault (free demo)
 # - cabextract is required to extract the content of an inner archive
 # - unix2dos is required to generate a .ini file
 
-SCRIPT_DEPS_WA_DEMO="${SCRIPT_DEPS:-} cabextract unix2dos"
+## Warning: REQUIREMENTS_LIST has no support for contextual values as of ./play.it 3.31
+REQUIREMENTS_LIST_WA_DEMO="${REQUIREMENTS_LIST:-}
+cabextract
+unix2dos"
 
 # Load common functions
 
@@ -332,16 +323,30 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Prevent a presence check for the Mono archive if the current game build does not require it
+
+## FIXME: This is required because ./play.it 2.31 has no context support for the variable WINE_WINEPREFIX_TWEAKS
+init_extra_archives_required() {
+	WINE_WINEPREFIX_TWEAKS=$(context_value 'WINE_WINEPREFIX_TWEAKS')
+	if ! archives_required_extra_presence_check; then
+		# Delete temporary files
+		working_directory_cleanup
+
+		exit 1
+	fi
+}
+
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Check for the presence of archive-specific requirements
 
-SCRIPT_DEPS=$(context_value 'SCRIPT_DEPS')
-check_deps
-
-# FIXME: Work around ./play.it 2.29 lack of context support for WINE_WINEPREFIX_TWEAKS
-
-WINE_WINEPREFIX_TWEAKS=$(context_value 'WINE_WINEPREFIX_TWEAKS')
+REQUIREMENTS_LIST=$(context_value 'REQUIREMENTS_LIST')
+requirements_check
 
 # Extract game data
 
@@ -353,7 +358,7 @@ archive_extraction_default
 	## TODO: We should set a more explicit list of files to include to avoid that step.
 	case "$(current_archive)" in
 		('ARCHIVE_BASE_WA_DEMO_'*)
-			rm *.exe *.ini *.msi
+			rm -- *.exe *.ini *.msi
 		;;
 		(*)
 			rm --force --recursive \
@@ -478,6 +483,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
