@@ -8,9 +8,9 @@ set -o errexit
 # - Lord of Skulls
 ###
 
-script_version=20240627.2
+script_version=20241212.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='warhammer-40k-gladius'
 GAME_NAME='Warhammer 40,000: Gladius'
@@ -22,11 +22,11 @@ EXPANSION_NAME_LORDOFSKULLS='Lord of Skulls'
 
 ## Lord of Skulls
 
-ARCHIVE_BASE_LORDOFSKULLS_18_NAME='warhammer_40_000_gladius_relics_of_war_lord_of_skulls_1_14_00_73692.sh'
-ARCHIVE_BASE_LORDOFSKULLS_18_MD5='c5005b4ba055899457848a0cdfaa6fff'
-ARCHIVE_BASE_LORDOFSKULLS_18_SIZE=''
-ARCHIVE_BASE_LORDOFSKULLS_18_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_LORDOFSKULLS_18_URL='https://www.gog.com/game/warhammer_40000_gladius_relics_of_war_lord_of_skulls'
+ARCHIVE_BASE_LORDOFSKULLS_20_NAME='warhammer_40_000_gladius_relics_of_war_lord_of_skulls_1_14_03_77940.sh'
+ARCHIVE_BASE_LORDOFSKULLS_20_MD5='d175e20aa6d48a3ee6e06929b4c34ff2'
+ARCHIVE_BASE_LORDOFSKULLS_20_SIZE='1086'
+ARCHIVE_BASE_LORDOFSKULLS_20_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_LORDOFSKULLS_20_URL='https://www.gog.com/game/warhammer_40000_gladius_relics_of_war_lord_of_skulls'
 
 ARCHIVE_BASE_LORDOFSKULLS_17_NAME='warhammer_40_000_gladius_relics_of_war_lord_of_skulls_1_13_03_72014.sh'
 ARCHIVE_BASE_LORDOFSKULLS_17_MD5='4e14b2240bb38489dad212e05cbadba3'
@@ -46,12 +46,12 @@ ARCHIVE_BASE_LORDOFSKULLS_11_VERSION='1.11.4-gog64361'
 ARCHIVE_BASE_LORDOFSKULLS_6_NAME='warhammer_40_000_gladius_relics_of_war_lord_of_skulls_1_10_01_00_57375.sh'
 ARCHIVE_BASE_LORDOFSKULLS_6_MD5='ad8818e83aec830eb11385cfbf1c3d10'
 ARCHIVE_BASE_LORDOFSKULLS_6_SIZE='1400'
-ARCHIVE_BASE_LORDOFSKULLS_6_VERSION='1.10.01-gog57375'
+ARCHIVE_BASE_LORDOFSKULLS_6_VERSION='1.10.1-gog57375'
 
 ARCHIVE_BASE_LORDOFSKULLS_4_NAME='warhammer_40_000_gladius_relics_of_war_lord_of_skulls_v1_09_03_00_54377.sh'
 ARCHIVE_BASE_LORDOFSKULLS_4_MD5='a3e949e976d3248ea338a4555454c804'
 ARCHIVE_BASE_LORDOFSKULLS_4_SIZE='1400'
-ARCHIVE_BASE_LORDOFSKULLS_4_VERSION='1.9.3.0-gog54377'
+ARCHIVE_BASE_LORDOFSKULLS_4_VERSION='1.9.3-gog54377'
 
 ARCHIVE_BASE_LORDOFSKULLS_2_NAME='warhammer_40_000_gladius_relics_of_war_lord_of_skulls_1_08_04_01_49548.sh'
 ARCHIVE_BASE_LORDOFSKULLS_2_MD5='a5cad7f6b77e112e10172709f531bb76'
@@ -63,7 +63,9 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 Data/*.dlc'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
@@ -88,8 +90,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -105,6 +112,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
