@@ -12,9 +12,9 @@ set -o errexit
 # - Firepower
 ###
 
-script_version=20240627.2
+script_version=20241212.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='warhammer-40k-gladius'
 GAME_NAME='Warhammer 40,000: Gladius'
@@ -41,11 +41,11 @@ EXPANSION_NAME_FIREPOWER='Firepower Pack'
 
 ## Reinforcement
 
-ARCHIVE_BASE_REINFORCEMENT_19_NAME='warhammer_40_000_gladius_reinforcement_pack_1_14_00_73692.sh'
-ARCHIVE_BASE_REINFORCEMENT_19_MD5='5f06d70d46bae16ee09ae1f7239cb0fe'
-ARCHIVE_BASE_REINFORCEMENT_19_SIZE='1086'
-ARCHIVE_BASE_REINFORCEMENT_19_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_REINFORCEMENT_19_URL='https://www.gog.com/game/warhammer_40000_gladius_reinforcement_pack'
+ARCHIVE_BASE_REINFORCEMENT_21_NAME='warhammer_40_000_gladius_reinforcement_pack_1_14_03_77940.sh'
+ARCHIVE_BASE_REINFORCEMENT_21_MD5='901cae49f0ac57a2c39666e40f269c49'
+ARCHIVE_BASE_REINFORCEMENT_21_SIZE='1086'
+ARCHIVE_BASE_REINFORCEMENT_21_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_REINFORCEMENT_21_URL='https://www.gog.com/game/warhammer_40000_gladius_reinforcement_pack'
 
 ARCHIVE_BASE_REINFORCEMENT_18_NAME='warhammer_40_000_gladius_reinforcement_pack_1_13_03_72014.sh'
 ARCHIVE_BASE_REINFORCEMENT_18_MD5='f7d2e11be209a004bc4d1f666ab18875'
@@ -65,12 +65,12 @@ ARCHIVE_BASE_REINFORCEMENT_12_VERSION='1.11.4-gog64361'
 ARCHIVE_BASE_REINFORCEMENT_7_NAME='warhammer_40_000_gladius_reinforcement_pack_1_10_01_00_57375.sh'
 ARCHIVE_BASE_REINFORCEMENT_7_MD5='59ac7359ac72a1f40f5ba237fcee8698'
 ARCHIVE_BASE_REINFORCEMENT_7_SIZE='1400'
-ARCHIVE_BASE_REINFORCEMENT_7_VERSION='1.10.01-gog57375'
+ARCHIVE_BASE_REINFORCEMENT_7_VERSION='1.10.1-gog57375'
 
 ARCHIVE_BASE_REINFORCEMENT_5_NAME='warhammer_40_000_gladius_reinforcement_pack_v1_09_03_00_54377.sh'
 ARCHIVE_BASE_REINFORCEMENT_5_MD5='20cce6c9a3a012a4b2d3fda7101606f4'
 ARCHIVE_BASE_REINFORCEMENT_5_SIZE='1400'
-ARCHIVE_BASE_REINFORCEMENT_5_VERSION='1.9.3.0-gog54377'
+ARCHIVE_BASE_REINFORCEMENT_5_VERSION='1.9.3-gog54377'
 
 ARCHIVE_BASE_REINFORCEMENT_3_NAME='warhammer_40_000_gladius_reinforcement_pack_1_08_04_01_49548.sh'
 ARCHIVE_BASE_REINFORCEMENT_3_MD5='72e9d71403328df72d4505096c98c423'
@@ -84,11 +84,11 @@ ARCHIVE_BASE_REINFORCEMENT_0_VERSION='1.7.4-gog44200'
 
 ## Fortification
 
-ARCHIVE_BASE_FORTIFICATION_18_NAME='warhammer_40_000_gladius_fortification_pack_1_14_00_73692.sh'
-ARCHIVE_BASE_FORTIFICATION_18_MD5='2bf88e8ad8d905851467212e835afe2b'
-ARCHIVE_BASE_FORTIFICATION_18_SIZE='1086'
-ARCHIVE_BASE_FORTIFICATION_18_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_FORTIFICATION_18_URL='https://www.gog.com/game/warhammer_40000_gladius_fortification_pack'
+ARCHIVE_BASE_FORTIFICATION_20_NAME='warhammer_40_000_gladius_fortification_pack_1_14_03_77940.sh'
+ARCHIVE_BASE_FORTIFICATION_20_MD5='4c540595d9e2d42c330488cb091ba1fa'
+ARCHIVE_BASE_FORTIFICATION_20_SIZE='1086'
+ARCHIVE_BASE_FORTIFICATION_20_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_FORTIFICATION_20_URL='https://www.gog.com/game/warhammer_40000_gladius_fortification_pack'
 
 ARCHIVE_BASE_FORTIFICATION_17_NAME='warhammer_40_000_gladius_fortification_pack_1_13_03_72014.sh'
 ARCHIVE_BASE_FORTIFICATION_17_MD5='8c9b997c2dfb6e141db5e02f7b519c93'
@@ -108,12 +108,12 @@ ARCHIVE_BASE_FORTIFICATION_11_VERSION='1.11.4-gog64361'
 ARCHIVE_BASE_FORTIFICATION_6_NAME='warhammer_40_000_gladius_fortification_pack_1_10_01_00_57375.sh'
 ARCHIVE_BASE_FORTIFICATION_6_MD5='859c6d14d76a4b1a43880ea89e01ed27'
 ARCHIVE_BASE_FORTIFICATION_6_SIZE='1400'
-ARCHIVE_BASE_FORTIFICATION_6_VERSION='1.10.01-gog57375'
+ARCHIVE_BASE_FORTIFICATION_6_VERSION='1.10.1-gog57375'
 
 ARCHIVE_BASE_FORTIFICATION_4_NAME='warhammer_40_000_gladius_fortification_pack_v1_09_03_00_54377.sh'
 ARCHIVE_BASE_FORTIFICATION_4_MD5='4221b279557e7af587ec6207f8654071'
 ARCHIVE_BASE_FORTIFICATION_4_SIZE='1400'
-ARCHIVE_BASE_FORTIFICATION_4_VERSION='1.9.3.0-gog54377'
+ARCHIVE_BASE_FORTIFICATION_4_VERSION='1.9.3-gog54377'
 
 ARCHIVE_BASE_FORTIFICATION_2_NAME='warhammer_40_000_gladius_fortification_pack_1_08_04_01_49548.sh'
 ARCHIVE_BASE_FORTIFICATION_2_MD5='d485b048b4c1d391c7671ecc4c88e66d'
@@ -122,11 +122,11 @@ ARCHIVE_BASE_FORTIFICATION_2_VERSION='1.8.4.1-gog49548'
 
 ## Assault
 
-ARCHIVE_BASE_ASSAULT_15_NAME='warhammer_40_000_gladius_assault_pack_1_14_00_73692.sh'
-ARCHIVE_BASE_ASSAULT_15_MD5='13243c15668b4cbf6c1bbc3a7fc63b64'
-ARCHIVE_BASE_ASSAULT_15_SIZE='1086'
-ARCHIVE_BASE_ASSAULT_15_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_ASSAULT_15_URL='https://www.gog.com/game/warhammer_40000_gladius_assault_pack'
+ARCHIVE_BASE_ASSAULT_17_NAME='warhammer_40_000_gladius_assault_pack_1_14_03_77940.sh'
+ARCHIVE_BASE_ASSAULT_17_MD5='760deb0defe921b8875c99274be00bec'
+ARCHIVE_BASE_ASSAULT_17_SIZE='1086'
+ARCHIVE_BASE_ASSAULT_17_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_ASSAULT_17_URL='https://www.gog.com/game/warhammer_40000_gladius_assault_pack'
 
 ARCHIVE_BASE_ASSAULT_14_NAME='warhammer_40_000_gladius_assault_pack_1_13_03_72014.sh'
 ARCHIVE_BASE_ASSAULT_14_MD5='f0c6a21687fbcad8442f5bb1c835b1aa'
@@ -146,20 +146,20 @@ ARCHIVE_BASE_ASSAULT_8_VERSION='1.11.4-gog64361'
 ARCHIVE_BASE_ASSAULT_3_NAME='warhammer_40_000_gladius_assault_pack_1_10_01_00_57375.sh'
 ARCHIVE_BASE_ASSAULT_3_MD5='69d3d257e8caa70c7af8bd50b6963e0a'
 ARCHIVE_BASE_ASSAULT_3_SIZE='1400'
-ARCHIVE_BASE_ASSAULT_3_VERSION='1.10.01-gog57375'
+ARCHIVE_BASE_ASSAULT_3_VERSION='1.10.1-gog57375'
 
 ARCHIVE_BASE_ASSAULT_1_NAME='warhammer_40_000_gladius_assault_pack_v1_09_03_00_54377.sh'
 ARCHIVE_BASE_ASSAULT_1_MD5='8812a45df8fa62523f655ecc2a1dbd46'
 ARCHIVE_BASE_ASSAULT_1_SIZE='1400'
-ARCHIVE_BASE_ASSAULT_1_VERSION='1.9.3.0-gog54377'
+ARCHIVE_BASE_ASSAULT_1_VERSION='1.9.3-gog54377'
 
 ## Specialist
 
-ARCHIVE_BASE_SPECIALIST_13_NAME='warhammer_40_000_gladius_specialist_pack_1_14_00_73692.sh'
-ARCHIVE_BASE_SPECIALIST_13_MD5='9ba78294300ee82890e2f15121a6f5d5'
-ARCHIVE_BASE_SPECIALIST_13_SIZE='1086'
-ARCHIVE_BASE_SPECIALIST_13_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_SPECIALIST_13_URL='https://www.gog.com/game/warhammer_40000_gladius_specialist_pack'
+ARCHIVE_BASE_SPECIALIST_15_NAME='warhammer_40_000_gladius_specialist_pack_1_14_03_77940.sh'
+ARCHIVE_BASE_SPECIALIST_15_MD5='265a6aa1071eff6f5f7855f63278e61c'
+ARCHIVE_BASE_SPECIALIST_15_SIZE='1086'
+ARCHIVE_BASE_SPECIALIST_15_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_SPECIALIST_15_URL='https://www.gog.com/game/warhammer_40000_gladius_specialist_pack'
 
 ARCHIVE_BASE_SPECIALIST_12_NAME='warhammer_40_000_gladius_specialist_pack_1_13_03_72014.sh'
 ARCHIVE_BASE_SPECIALIST_12_MD5='065713713aaa72418d048a20dcd9203e'
@@ -179,15 +179,15 @@ ARCHIVE_BASE_SPECIALIST_6_VERSION='1.11.4-gog64361'
 ARCHIVE_BASE_SPECIALIST_1_NAME='warhammer_40_000_gladius_specialist_pack_1_10_01_00_57375.sh'
 ARCHIVE_BASE_SPECIALIST_1_MD5='b0b788d180a82919048621796f68fb1e'
 ARCHIVE_BASE_SPECIALIST_1_SIZE='1400'
-ARCHIVE_BASE_SPECIALIST_1_VERSION='1.10.01-gog57375'
+ARCHIVE_BASE_SPECIALIST_1_VERSION='1.10.1-gog57375'
 
 ## Escalation
 
-ARCHIVE_BASE_ESCALATION_6_NAME='warhammer_40_000_gladius_escalation_pack_1_14_00_73692.sh'
-ARCHIVE_BASE_ESCALATION_6_MD5='ace7d3fad7f621f27e6d12f7e7cdc584'
-ARCHIVE_BASE_ESCALATION_6_SIZE='1086'
-ARCHIVE_BASE_ESCALATION_6_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_ESCALATION_6_URL='https://www.gog.com/game/warhammer_40000_gladius_adeptus_mechanicus'
+ARCHIVE_BASE_ESCALATION_8_NAME='warhammer_40_000_gladius_escalation_pack_1_14_03_77940.sh'
+ARCHIVE_BASE_ESCALATION_8_MD5='847f3fbd0e977f2a944531cabd3efd30'
+ARCHIVE_BASE_ESCALATION_8_SIZE='1086'
+ARCHIVE_BASE_ESCALATION_8_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_ESCALATION_8_URL='https://www.gog.com/game/warhammer_40000_gladius_adeptus_mechanicus'
 
 ARCHIVE_BASE_ESCALATION_5_NAME='warhammer_40_000_gladius_escalation_pack_1_13_03_72014.sh'
 ARCHIVE_BASE_ESCALATION_5_MD5='5dba4c9a1719723682a2857b44dce0c5'
@@ -201,11 +201,11 @@ ARCHIVE_BASE_ESCALATION_2_VERSION='1.12.3-gog67548'
 
 ## Firepower
 
-ARCHIVE_BASE_FIREPOWER_5_NAME='warhammer_40_000_gladius_firepower_pack_1_14_00_73692.sh'
-ARCHIVE_BASE_FIREPOWER_5_MD5='d75e09b23b6d204e62c5f96dddcc371d'
-ARCHIVE_BASE_FIREPOWER_5_SIZE='1086'
-ARCHIVE_BASE_FIREPOWER_5_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_FIREPOWER_5_URL='https://www.gog.com/game/warhammer_40000_gladius_firepower_pack'
+ARCHIVE_BASE_FIREPOWER_7_NAME='warhammer_40_000_gladius_firepower_pack_1_14_03_77940.sh'
+ARCHIVE_BASE_FIREPOWER_7_MD5='1a81b99275d126cbbfcf1ee3c751cac7'
+ARCHIVE_BASE_FIREPOWER_7_SIZE='1086'
+ARCHIVE_BASE_FIREPOWER_7_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_FIREPOWER_7_URL='https://www.gog.com/game/warhammer_40000_gladius_firepower_pack'
 
 ARCHIVE_BASE_FIREPOWER_4_NAME='warhammer_40_000_gladius_firepower_pack_1_13_03_72014.sh'
 ARCHIVE_BASE_FIREPOWER_4_MD5='813f40d7fbce991eae9db43aad552a4e'
@@ -222,7 +222,9 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 Data/*.dlc'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
@@ -247,8 +249,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -264,6 +271,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
