@@ -14,9 +14,9 @@ set -o errexit
 # - Drukhari
 ###
 
-script_version=20240627.2
+script_version=20241212.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='warhammer-40k-gladius'
 GAME_NAME='Warhammer 40,000: Gladius'
@@ -46,11 +46,11 @@ EXPANSION_NAME_DRUKHARI='Drukhari'
 
 ## Tyranids
 
-ARCHIVE_BASE_TYRANIDS_19_NAME='warhammer_40_000_gladius_tyranids_1_14_00_73692.sh'
-ARCHIVE_BASE_TYRANIDS_19_MD5='0c29f27eef9ab4f90c8bc03a755fcbc7'
-ARCHIVE_BASE_TYRANIDS_19_SIZE=''
-ARCHIVE_BASE_TYRANIDS_19_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_TYRANIDS_19_URL='https://www.gog.com/game/warhammer_40000_gladius_tyranids'
+ARCHIVE_BASE_TYRANIDS_21_NAME='warhammer_40_000_gladius_tyranids_1_14_03_77940.sh'
+ARCHIVE_BASE_TYRANIDS_21_MD5='08a7490d398a7f36c600a84367b9dfb8'
+ARCHIVE_BASE_TYRANIDS_21_SIZE='1086'
+ARCHIVE_BASE_TYRANIDS_21_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_TYRANIDS_21_URL='https://www.gog.com/game/warhammer_40000_gladius_tyranids'
 
 ARCHIVE_BASE_TYRANIDS_18_NAME='warhammer_40_000_gladius_tyranids_1_13_03_72014.sh'
 ARCHIVE_BASE_TYRANIDS_18_MD5='1126da61c9bdc27a4c9c4cc9444ff87d'
@@ -70,12 +70,12 @@ ARCHIVE_BASE_TYRANIDS_12_VERSION='1.11.4-gog64361'
 ARCHIVE_BASE_TYRANIDS_7_NAME='warhammer_40_000_gladius_tyranids_1_10_01_00_57375.sh'
 ARCHIVE_BASE_TYRANIDS_7_MD5='30934475a2b0c8f794234d5e38f504cc'
 ARCHIVE_BASE_TYRANIDS_7_SIZE='1400'
-ARCHIVE_BASE_TYRANIDS_7_VERSION='1.10.01-gog57375'
+ARCHIVE_BASE_TYRANIDS_7_VERSION='1.10.1-gog57375'
 
 ARCHIVE_BASE_TYRANIDS_5_NAME='warhammer_40_000_gladius_tyranids_v1_09_03_00_54377.sh'
 ARCHIVE_BASE_TYRANIDS_5_MD5='ac2e7f57d90a405688304573e6332443'
 ARCHIVE_BASE_TYRANIDS_5_SIZE='1400'
-ARCHIVE_BASE_TYRANIDS_5_VERSION='1.9.3.0-gog54377'
+ARCHIVE_BASE_TYRANIDS_5_VERSION='1.9.3-gog54377'
 
 ARCHIVE_BASE_TYRANIDS_3_NAME='warhammer_40_000_gladius_tyranids_1_08_04_01_49548.sh'
 ARCHIVE_BASE_TYRANIDS_3_MD5='a6e5921db60b6a366619354b1eb47d23'
@@ -89,11 +89,11 @@ ARCHIVE_BASE_TYRANIDS_0_VERSION='1.7.4-gog44200'
 
 ## Chaos Space Marines
 
-ARCHIVE_BASE_CHAOS_18_NAME='warhammer_40_000_gladius_chaos_space_marines_1_14_00_73692.sh'
-ARCHIVE_BASE_CHAOS_18_MD5='51e52611615ec0bde7ad5a549c9cbc71'
-ARCHIVE_BASE_CHAOS_18_SIZE=''
-ARCHIVE_BASE_CHAOS_18_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_CHAOS_18_URL='https://www.gog.com/game/warhammer_40000_gladius_chaos_space_marines'
+ARCHIVE_BASE_CHAOS_20_NAME='warhammer_40_000_gladius_chaos_space_marines_1_14_03_77940.sh'
+ARCHIVE_BASE_CHAOS_20_MD5='4d3e181c0156ab28d81e4b8df4c3d1ba'
+ARCHIVE_BASE_CHAOS_20_SIZE='1086'
+ARCHIVE_BASE_CHAOS_20_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_CHAOS_20_URL='https://www.gog.com/game/warhammer_40000_gladius_chaos_space_marines'
 
 ARCHIVE_BASE_CHAOS_17_NAME='warhammer_40_000_gladius_chaos_space_marines_1_13_03_72014.sh'
 ARCHIVE_BASE_CHAOS_17_MD5='a7c63aa885dd1a5b51b2b5a3d55d4e21'
@@ -113,12 +113,12 @@ ARCHIVE_BASE_CHAOS_11_VERSION='1.11.4-gog64361'
 ARCHIVE_BASE_CHAOS_6_NAME='warhammer_40_000_gladius_chaos_space_marines_1_10_01_00_57375.sh'
 ARCHIVE_BASE_CHAOS_6_MD5='88542a8341638e1d51e2758c9886e2c6'
 ARCHIVE_BASE_CHAOS_6_SIZE='1400'
-ARCHIVE_BASE_CHAOS_6_VERSION='1.10.01-gog57375'
+ARCHIVE_BASE_CHAOS_6_VERSION='1.10.1-gog57375'
 
 ARCHIVE_BASE_CHAOS_4_NAME='warhammer_40_000_gladius_chaos_space_marines_v1_09_03_00_54377.sh'
 ARCHIVE_BASE_CHAOS_4_MD5='ed2c64df977669d9413648347c883a35'
 ARCHIVE_BASE_CHAOS_4_SIZE='1400'
-ARCHIVE_BASE_CHAOS_4_VERSION='1.9.3.0-gog54377'
+ARCHIVE_BASE_CHAOS_4_VERSION='1.9.3-gog54377'
 
 ARCHIVE_BASE_CHAOS_2_NAME='warhammer_40_000_gladius_chaos_space_marines_1_08_04_01_49548.sh'
 ARCHIVE_BASE_CHAOS_2_MD5='37894d5cd89aaa67dc841d2f5023ebf2'
@@ -127,11 +127,11 @@ ARCHIVE_BASE_CHAOS_2_VERSION='1.8.4.1-gog49548'
 
 ## T'au
 
-ARCHIVE_BASE_TAU_15_NAME='warhammer_40_000_gladius_t_au_1_14_00_73692.sh'
-ARCHIVE_BASE_TAU_15_MD5='8f6527c12166f5e70287c01915511bfd'
-ARCHIVE_BASE_TAU_15_SIZE=''
-ARCHIVE_BASE_TAU_15_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_TAU_15_URL='https://www.gog.com/game/warhammer_40000_gladius_tau'
+ARCHIVE_BASE_TAU_17_NAME='warhammer_40_000_gladius_t_au_1_14_03_77940.sh'
+ARCHIVE_BASE_TAU_17_MD5='e69fec137633403f9b37fa37d58da209'
+ARCHIVE_BASE_TAU_17_SIZE='1086'
+ARCHIVE_BASE_TAU_17_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_TAU_17_URL='https://www.gog.com/game/warhammer_40000_gladius_tau'
 
 ARCHIVE_BASE_TAU_14_NAME='warhammer_40_000_gladius_t_au_1_13_03_72014.sh'
 ARCHIVE_BASE_TAU_14_MD5='cc6b1b472357aafe1a92906dbac6ce56'
@@ -151,20 +151,20 @@ ARCHIVE_BASE_TAU_8_VERSION='1.11.4-gog64361'
 ARCHIVE_BASE_TAU_3_NAME='warhammer_40_000_gladius_t_au_1_10_01_00_57375.sh'
 ARCHIVE_BASE_TAU_3_MD5='1f7770a75d1c846aca32f905cd4ce51f'
 ARCHIVE_BASE_TAU_3_SIZE='1400'
-ARCHIVE_BASE_TAU_3_VERSION='1.10.01-gog57375'
+ARCHIVE_BASE_TAU_3_VERSION='1.10.1-gog57375'
 
 ARCHIVE_BASE_TAU_1_NAME='warhammer_40_000_gladius_t_au_v1_09_03_00_54377.sh'
 ARCHIVE_BASE_TAU_1_MD5='22b575c6ce8da35f7d57335662de4747'
 ARCHIVE_BASE_TAU_1_SIZE='1400'
-ARCHIVE_BASE_TAU_1_VERSION='1.9.3.0-gog54377'
+ARCHIVE_BASE_TAU_1_VERSION='1.9.3-gog54377'
 
 ## Craftworld Aeldari
 
-ARCHIVE_BASE_AELDARI_13_NAME='warhammer_40_000_gladius_craftworld_aeldari_1_14_00_73692.sh'
-ARCHIVE_BASE_AELDARI_13_MD5='ed2a02564d5f289dcb171cc65db63e06'
-ARCHIVE_BASE_AELDARI_13_SIZE=''
-ARCHIVE_BASE_AELDARI_13_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_AELDARI_13_URL='https://www.gog.com/game/warhammer_40000_gladius_craftworld_aeldari'
+ARCHIVE_BASE_AELDARI_15_NAME='warhammer_40_000_gladius_craftworld_aeldari_1_14_03_77940.sh'
+ARCHIVE_BASE_AELDARI_15_MD5='73a817b4990d66ea7f938d82d0ec4bbf'
+ARCHIVE_BASE_AELDARI_15_SIZE='1086'
+ARCHIVE_BASE_AELDARI_15_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_AELDARI_15_URL='https://www.gog.com/game/warhammer_40000_gladius_craftworld_aeldari'
 
 ARCHIVE_BASE_AELDARI_12_NAME='warhammer_40_000_gladius_craftworld_aeldari_1_13_03_72014.sh'
 ARCHIVE_BASE_AELDARI_12_MD5='18e5d21d0d2b202d746de192cc4370da'
@@ -184,15 +184,15 @@ ARCHIVE_BASE_AELDARI_6_VERSION='1.11.4-gog64361'
 ARCHIVE_BASE_AELDARI_1_NAME='warhammer_40_000_gladius_craftworld_aeldari_1_10_01_00_57375.sh'
 ARCHIVE_BASE_AELDARI_1_MD5='b3698a59f99611fb8431a76ea50ef35d'
 ARCHIVE_BASE_AELDARI_1_SIZE='1400'
-ARCHIVE_BASE_AELDARI_1_VERSION='1.10.01-gog57375'
+ARCHIVE_BASE_AELDARI_1_VERSION='1.10.1-gog57375'
 
 ## Adeptus Mechanicus
 
-ARCHIVE_BASE_MECHANICUS_6_NAME='warhammer_40_000_gladius_adeptus_mechanicus_1_14_00_73692.sh'
-ARCHIVE_BASE_MECHANICUS_6_MD5='bb01fdebd083135d288c4b25f7e79552'
-ARCHIVE_BASE_MECHANICUS_6_SIZE=''
-ARCHIVE_BASE_MECHANICUS_6_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_MECHANICUS_6_URL='https://www.gog.com/game/warhammer_40000_gladius_adeptus_mechanicus'
+ARCHIVE_BASE_MECHANICUS_8_NAME='warhammer_40_000_gladius_adeptus_mechanicus_1_14_03_77940.sh'
+ARCHIVE_BASE_MECHANICUS_8_MD5='ea312fa967f14ad4511bc178430aeda1'
+ARCHIVE_BASE_MECHANICUS_8_SIZE='1086'
+ARCHIVE_BASE_MECHANICUS_8_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_MECHANICUS_8_URL='https://www.gog.com/game/warhammer_40000_gladius_adeptus_mechanicus'
 
 ARCHIVE_BASE_MECHANICUS_5_NAME='warhammer_40_000_gladius_adeptus_mechanicus_1_13_03_72014.sh'
 ARCHIVE_BASE_MECHANICUS_5_MD5='7670878de137f0de17cdae93ded39f09'
@@ -206,11 +206,11 @@ ARCHIVE_BASE_MECHANICUS_2_VERSION='1.12.3-gog67548'
 
 ## Adepta Sororitas
 
-ARCHIVE_BASE_SORORITAS_5_NAME='warhammer_40_000_gladius_adepta_sororitas_1_14_00_73692.sh'
-ARCHIVE_BASE_SORORITAS_5_MD5='fa6c13cdbc344de227d2468f7fadfe42'
-ARCHIVE_BASE_SORORITAS_5_SIZE=''
-ARCHIVE_BASE_SORORITAS_5_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_SORORITAS_5_URL='https://www.gog.com/game/warhammer_40000_gladius_adepta_sororitas'
+ARCHIVE_BASE_SORORITAS_7_NAME='warhammer_40_000_gladius_adepta_sororitas_1_14_03_77940.sh'
+ARCHIVE_BASE_SORORITAS_7_MD5='2166533e2ed1efc020729e5b174a1721'
+ARCHIVE_BASE_SORORITAS_7_SIZE='1086'
+ARCHIVE_BASE_SORORITAS_7_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_SORORITAS_7_URL='https://www.gog.com/game/warhammer_40000_gladius_adepta_sororitas'
 
 ARCHIVE_BASE_SORORITAS_4_NAME='warhammer_40_000_gladius_adepta_sororitas_1_13_03_72014.sh'
 ARCHIVE_BASE_SORORITAS_4_MD5='6d588bac7b0e51c140f8cbb888b8de61'
@@ -224,11 +224,11 @@ ARCHIVE_BASE_SORORITAS_1_VERSION='1.12.3-gog67548'
 
 ## Drukhari
 
-ARCHIVE_BASE_DRUKHARI_2_NAME='warhammer_40_000_gladius_drukhari_1_14_00_73692.sh'
-ARCHIVE_BASE_DRUKHARI_2_MD5='119befb3c9614d3921d25627723a3765'
-ARCHIVE_BASE_DRUKHARI_2_SIZE=''
-ARCHIVE_BASE_DRUKHARI_2_VERSION='1.14.0-gog73692'
-ARCHIVE_BASE_DRUKHARI_2_URL='https://www.gog.com/game/warhammer_40000_gladius_drukhari'
+ARCHIVE_BASE_DRUKHARI_4_NAME='warhammer_40_000_gladius_drukhari_1_14_03_77940.sh'
+ARCHIVE_BASE_DRUKHARI_4_MD5='f8ad53fe2b0eba0ff16089e2840fdc40'
+ARCHIVE_BASE_DRUKHARI_4_SIZE='1086'
+ARCHIVE_BASE_DRUKHARI_4_VERSION='1.14.3-gog77940'
+ARCHIVE_BASE_DRUKHARI_4_URL='https://www.gog.com/game/warhammer_40000_gladius_drukhari'
 
 ARCHIVE_BASE_DRUKHARI_1_NAME='warhammer_40_000_gladius_drukhari_1_13_03_72014.sh'
 ARCHIVE_BASE_DRUKHARI_1_MD5='9f04c3d2b819a9865f853fcf184df6fe'
@@ -240,7 +240,9 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 Data/*.dlc'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
@@ -265,8 +267,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -282,6 +289,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
