@@ -8,9 +8,9 @@ set -o errexit
 # Wasteland 2
 ###
 
-script_version=20240601.2
+script_version=20241124.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='wasteland-2'
 GAME_NAME='Wasteland 2'
@@ -62,7 +62,8 @@ Wasteland 2 Ranger Field Manual.pdf
 Wasteland 2 Reference Guide.pdf'
 
 ## Work around the engine overuse of file descriptors.
-APP_MAIN_PRERUN='# Work around the engine overuse of file descriptors
+APP_MAIN_PRERUN='
+# Work around the engine overuse of file descriptors
 ## 4096 is an arbitrary value, 4 times the default (1024), that seems to work for all setups.
 if ! ulimit -n 4096; then
 	{
@@ -76,6 +77,9 @@ fi
 
 # Packages
 
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_DESCRIPTION='data'
 
 ## Wasteland 2 (classic)
@@ -86,18 +90,7 @@ PKG_DATA_SCENES_AZ
 PKG_DATA_SCENES_CA
 PKG_DATA'
 
-PKG_DATA_ID_CLASSIC="${GAME_ID_CLASSIC}-data"
-
-PKG_DATA_SCENES_AZ_ID="${PKG_DATA_ID_CLASSIC}-scenes-az"
-PKG_DATA_SCENES_AZ_DESCRIPTION="$PKG_DATA_DESCRIPTION - Arizona scenes"
-PKG_DATA_DEPS_CLASSIC="${PKG_DATA_DEPS_CLASSIC:-} $PKG_DATA_SCENES_AZ_ID"
-
-PKG_DATA_SCENES_CA_ID="${PKG_DATA_ID_CLASSIC}-scenes-ca"
-PKG_DATA_SCENES_CA_DESCRIPTION="$PKG_DATA_DESCRIPTION - California scenes"
-PKG_DATA_DEPS_CLASSIC="${PKG_DATA_DEPS_CLASSIC:-} $PKG_DATA_SCENES_CA_ID"
-
 PKG_BIN_ARCH_CLASSIC='32'
-PKG_BIN_DEPS_CLASSIC="$PKG_DATA_ID_CLASSIC"
 PKG_BIN_DEPENDENCIES_LIBRARIES_CLASSIC='
 libatk-1.0.so.0
 libcairo.so.2
@@ -128,6 +121,17 @@ libXcursor.so.1
 libXext.so.6
 libXrandr.so.2'
 
+PKG_DATA_ID_CLASSIC="${GAME_ID_CLASSIC}-data"
+PKG_DATA_DEPENDENCIES_SIBLINGS_CLASSIC='
+PKG_DATA_SCENES_AZ
+PKG_DATA_SCENES_CA'
+
+PKG_DATA_SCENES_AZ_ID="${PKG_DATA_ID_CLASSIC}-scenes-az"
+PKG_DATA_SCENES_AZ_DESCRIPTION="$PKG_DATA_DESCRIPTION - Arizona scenes"
+
+PKG_DATA_SCENES_CA_ID="${PKG_DATA_ID_CLASSIC}-scenes-ca"
+PKG_DATA_SCENES_CA_DESCRIPTION="$PKG_DATA_DESCRIPTION - California scenes"
+
 ## Wasteland 2 Director's Cut
 
 PACKAGES_LIST_DIRECTORSCUT='
@@ -135,17 +139,7 @@ PKG_BIN
 PKG_DATA_RESOURCES
 PKG_DATA'
 
-PKG_DATA_ID_DIRECTORSCUT="${GAME_ID_DIRECTORSCUT}-data"
-
-PKG_DATA_RESOURCES_ID="${PKG_DATA_ID_DIRECTORSCUT}-resources"
-PKG_DATA_RESOURCES_DESCRIPTION='resources'
-PKG_DATA_DEPS_DIRECTORSCUT="${PKG_DATA_DEPS_DIRECTORSCUT:-} $PKG_DATA_RESOURCES_ID"
-## Ensure smooth upgrades from packages generated with pre-20231021.1 scripts.
-PKG_DATA_RESOURCES_PROVIDES="${PKG_DATA_RESOURCES_PROVIDES:-}
-wasteland-2-directors-cut-resources"
-
 PKG_BIN_ARCH_DIRECTORSCUT='64'
-PKG_BIN_DEPS_DIRECTORSCUT="$PKG_DATA_ID_DIRECTORSCUT"
 PKG_BIN_DEPENDENCIES_LIBRARIES_DIRECTORSCUT='
 libc.so.6
 libdl.so.2
@@ -163,6 +157,16 @@ libX11.so.6
 libXcursor.so.1
 libXrandr.so.2'
 
+PKG_DATA_ID_DIRECTORSCUT="${GAME_ID_DIRECTORSCUT}-data"
+PKG_DATA_DEPENDENCIES_SIBLINGS_DIRECTORSCUT='
+PKG_DATA_RESOURCES'
+
+PKG_DATA_RESOURCES_ID="${PKG_DATA_ID_DIRECTORSCUT}-resources"
+PKG_DATA_RESOURCES_DESCRIPTION='resources'
+## Ensure smooth upgrades from packages generated with pre-20231021.1 scripts.
+PKG_DATA_RESOURCES_PROVIDES="${PKG_DATA_RESOURCES_PROVIDES:-}
+wasteland-2-directors-cut-resources"
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -186,8 +190,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -208,6 +217,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
