@@ -7,9 +7,9 @@ set -o errexit
 # Worms 2
 ###
 
-script_version=20240602.1
+script_version=20241125.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.31'
 
 GAME_ID='worms-2'
 GAME_NAME='Worms 2'
@@ -55,26 +55,27 @@ data/*.dat'
 WINE_VIRTUAL_DESKTOP='640x480'
 
 APP_MAIN_EXE='frontend.exe'
-## Play the introduction videos on launch.
-APP_MAIN_PRERUN='# Play the introduction videos on launch
-MPV_OPTIONS="--fs --no-osc"
+## Play the introduction videos on launch
+APP_MAIN_PRERUN='
+# Play the introduction videos on launch
 RANDOM_MOVIE=$(find . -mindepth 1 -maxdepth 1 -name "*.wmv" ! -name "intro.wmv" | shuf --head-count=1)
-mpv $MPV_OPTIONS intro.wmv
-mpv $MPV_OPTIONS "$RANDOM_MOVIE"
+mpv --fs --no-osc intro.wmv
+mpv --fs --no-osc "$RANDOM_MOVIE"
 '
 
 PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_COMMANDS='
 mpv'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -98,8 +99,13 @@ if [ -z "$PLAYIT_LIB2" ]; then
 	printf 'libplayit2.sh not found.\n'
 	exit 1
 fi
+# shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
+# Run the default initialization actions
+
+initialization_default "$@"
+
 # Extract game data
 
 archive_extraction_default
@@ -120,6 +126,6 @@ print_instructions
 
 # Clean up
 
-rm --recursive "$PLAYIT_WORKDIR"
+working_directory_cleanup
 
 exit 0
